package com.up.zpb.controller.api;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.service.AppEntrustService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * app求租求购列表
 */
@RestController
@RequestMapping("appEntrust")
public class AppEntrustController {

    private static final Logger logger = LoggerFactory.getLogger(AppEntrustController.class);

    @Autowired
    private AppEntrustService appEntrustService;

    /**
     * 求租求购信息列表展示
     *
     * @param request
     * @return
     */
    @PostMapping("/seekSelectPage")
    public ResultObject index(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("typeSeek"), "typeSeek")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
        Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
        Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
        resultObject = appEntrustService.seekSelectPage(parameters);
        resultObject.put("totalCount", startPage.getTotal());
        return resultObject;
    }

    /**
     * 求租求购详情
     * @param request
     * @return
     */
    @PostMapping("/detail")
    public ResultObject detail(HttpServletRequest request){
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            return appEntrustService.getDetail(parameters);
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

}
