package com.up.zpb.controller.api;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.up.zpb.controller.AbstractController;
import com.up.zpb.service.AppRentService;
import com.up.zpb.service.ShopService;
import com.up.zpb.service.customer.CustomerService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.Customer;
import com.up.zpb.vo.ResultObject;

@RestController
@RequestMapping("/rent")
public class AppRentController extends AbstractController {

    private static final Logger logger = LoggerFactory.getLogger(AppRentController.class);

    @Autowired
    private AppRentService appRentService;

    @Autowired
    private CustomerService customerService;

    /**
     * app客源发布字典
     *
     * @param cityId
     * @return
     */
    @PostMapping("/getJson")
    public ResultObject getJson(String cityId) {
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(cityId, "cityId")
                    .checkParameter();
            return appRentService.getJson(cityId);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }
    
    /**
     * 商办评估下拉json
     * andorid-独立接口
     * @param cityId
     * @return
     */
    @PostMapping("/getShangBanJson")
    public ResultObject getShangBanJson(String cityId) {
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(cityId, "cityId")
                    .checkParameter();
            return appRentService.getShangBanJson(cityId);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }
    

    /**
     * app提交提交客源发布  买商铺
     * @param request
     * @return
     */
    @PostMapping("/submitShop")
    public ResultObject submitShop(HttpServletRequest request, Customer customer) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        customer.setCreateId(parameters.get("authentication").toString());
        try {
            return customerService.saveAll(customer);
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }
    }

}
