/**
 * 
 */
package com.up.zpb.controller.api;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.up.zpb.controller.AbstractController;
import com.up.zpb.service.ShopAssessService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.LookOffice;
import com.up.zpb.vo.LookShop;
import com.up.zpb.vo.OfficeAssess;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.ShopAssess;
import com.up.zpb.vo.enums.OfficeEnum;
import com.up.zpb.vo.enums.ProjectEnum;
import com.up.zpb.vo.enums.ShopEnum;

/**
 * 
 *      
 * 商铺和写字楼评估控制层    
 * @author PJJ       
 * @version 1.0     
 * @created 2019年7月30日 上午9:15:35
 */
@RestController
@RequestMapping(value = "/assess")
public class AssessController extends AbstractController {
	private static final Logger logger = LoggerFactory.getLogger(AssessController.class);

	@Autowired
	private ShopAssessService shopAssessService;
	
	/**
	 * 商铺评估-提交
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/saveShopAssess")
	public ResultObject saveShopAssess(HttpServletRequest request,ShopAssess entity) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【saveShopAssess()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("cityId"), "cityId")
			.put(parameters.get("areaId"), "areaId")
			.put(parameters.get("regionsId"), "regionsId")			
			.put(parameters.get("address"), "address")
			.put(parameters.get("mianji"), "mianji")
			.put(parameters.get("linkman"), "linkman")
			.put(parameters.get("telephone"), "telephone")
			.put(parameters.get("vcode"), "vcode")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopAssessService.saveShopAssess(entity,parameters);
		logger.info("【saveShopAssess()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * 写字楼评估-提交  
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/saveOfficeAssess")
	public ResultObject saveOfficeAssess(HttpServletRequest request,OfficeAssess entity) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【saveOfficeAssess()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("cityId"), "cityId")
			.put(parameters.get("areaId"), "areaId")
			.put(parameters.get("regionsId"), "regionsId")			
			.put(parameters.get("linkman"), "linkman")
			.put(parameters.get("address"), "address")
			.put(parameters.get("mianji"), "mianji")
			.put(parameters.get("name"), "name")
			.put(parameters.get("telephone"), "telephone")
			.put(parameters.get("vcode"), "vcode")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopAssessService.saveOfficeAssess(entity,parameters);
		logger.info("【saveOfficeAssess()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	/**
	 * 商铺评估-提交
	 * @param request
	 * @return
	 * @throws Exception
	 */
	/*@PostMapping("/saveAllAssess")
	public ResultObject saveAllAssess(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【saveAllAssess()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("cityId"), "cityId")
			.put(parameters.get("areaId"), "areaId")
			.put(parameters.get("regionsId"), "regionsId")			
			.put(parameters.get("address"), "address")
			.put(parameters.get("mianji"), "mianji")
			.put(parameters.get("name"), "name")
			.put(parameters.get("telephone"), "telephone")
			.put(parameters.get("vcode"), "vcode")
			.put(parameters.get("projectType"), "projectType")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		if(ProjectEnum.ProjectType.SHOP.getValue().equals(parameters.get("projectType"))){
			//1-商铺
			resultObject=this.saveShopAssess(request);
		}else{
			//2-写字楼
			resultObject=this.saveOfficeAssess(request);
		}
		logger.info("【saveAllAssess()结束=========="+resultObject+"】");
		return resultObject;
	}*/
	
	
	/*@PostMapping("/selectPage")
	public ResultObject selectPage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("pageSize"), "pageSize")
		.put(parameters.get("pageNum"), "pageNum").checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		return this.shopAssessService.selectPage(parameters);
	}

	
	
	@PostMapping("/findEntityById")
	public ResultObject findEntityById(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("id"), "id")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		return this.shopAssessService.findEntityById(parameters.get("id")+"");
	}
	
	
	
	
	@PostMapping("/updateShopAssess")
	public Map<String, Object> updateShopAssess(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("id"), "id")
				.checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = this.shopAssessService.updateShopAssess(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("updateMsgStatus end");
		return resultObject;
	}*/
	
	
	/**
	 * 
	 * 帮我找-商铺   
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/saveLookShop")
	public ResultObject saveLookShop(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【saveLookShop()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("areaId"), "areaId")
			.put(parameters.get("regionsId"), "regionsId")
			.put(parameters.get("types"), "types")
			.put(parameters.get("userName"), "userName")
			.put(parameters.get("telephone"), "telephone")
			.put(parameters.get("userId"), "userId")
			.put(parameters.get("channel"), "channel")
			.checkParameter();
			
			
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		LookShop entity=(LookShop)ObjectHelpUtils.setValToObj2(new LookShop(), parameters);
		entity.setAreaId(Integer.valueOf(parameters.get("areaId")+""));
		entity.setRegionsId(Integer.valueOf(parameters.get("regionsId")+""));
		entity.setUserId(Integer.valueOf(parameters.get("userId")+""));
		if("3".equals(parameters.get("projectType")) && ("1".equals(parameters.get("channel")+"") || "2".equals(parameters.get("channel")+""))){
			//商业新盘 ,app
				if("1".equals(parameters.get("types"))){// child 1-求租 2-求购
					entity.setTypes(ShopEnum.RentType.NEWS_RENT.getValue());
				}else{
					entity.setTypes(ShopEnum.RentType.NEWS_SALE.getValue());
				}
		}
		resultObject=this.shopAssessService.saveLookShop(entity);
		logger.info("【saveLookShop()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * 
	 * 帮我找-写字楼
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/saveLookOffice")
	public ResultObject saveLookOffice(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【saveLookOffice()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("areaId"), "areaId")
			.put(parameters.get("regionsId"), "regionsId")
			.put(parameters.get("types"), "types")
			.put(parameters.get("userName"), "userName")
			.put(parameters.get("telephone"), "telephone")
			.put(parameters.get("userId"), "userId")
			.put(parameters.get("channel"), "channel")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		LookOffice entity=(LookOffice)ObjectHelpUtils.setValToObj2(new LookOffice(), parameters);
		entity.setAreaId(Integer.valueOf(parameters.get("areaId")+""));
		entity.setRegionsId(Integer.valueOf(parameters.get("regionsId")+""));
		entity.setUserId(Integer.valueOf(parameters.get("userId")+""));
		if("4".equals(parameters.get("projectType")) && ("1".equals(parameters.get("channel")+"") || "2".equals(parameters.get("channel")+""))){
			//4-写字楼新盘,app
			if("1".equals(parameters.get("types"))){// child 1-求租 2-求购
				entity.setTypes(OfficeEnum.TypeSale.NEWS_RENT.getValue());
			}else{
				entity.setTypes(OfficeEnum.TypeSale.NEWS_SALE.getValue());
			}
		}
		
		resultObject=this.shopAssessService.saveLookOffice(entity);
		logger.info("【saveLookOffice()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * 综合委托接口  -app用
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/saveLookAll")
	public ResultObject saveLookAll(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【saveLookAll()开始=========="+parameters+"】");
		if("1".equals(parameters.get("projectType")+"")
				|| "3".equals(parameters.get("projectType")+"")){//1-商铺 2-写字楼( 3-商业新盘 4-写字楼新盘)
			//商铺
			resultObject=this.saveLookShop(request);
		}else{
			//写字楼
			resultObject=this.saveLookOffice(request);
		}
		logger.info("【saveLookAll()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	
	
	
	@PostMapping("/findLookShopPage")
	public ResultObject findLookShopPage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findLookShopPage()开始=========="+parameters+"】");
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("pageSize"), "pageSize")
		.put(parameters.get("pageNum"), "pageNum")
		.put(parameters.get("userId"), "userId").checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopAssessService.findLookShopPage(parameters);
		logger.info("【findLookShopPage()结束=========="+resultObject+"】");
		return resultObject;
	}

	@PostMapping("/findLookOfficePage")
	public ResultObject findLookOfficePage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findLookOfficePage()开始=========="+parameters+"】");
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("pageSize"), "pageSize")
		.put(parameters.get("pageNum"), "pageNum")
		.put(parameters.get("userId"), "userId").checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopAssessService.findLookOfficePage(parameters);
		logger.info("【findLookOfficePage()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * app端综合查询-我的委托分页列表  
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/auth/findMyLookAllPage")
	public ResultObject findMyLookAllPage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findMyLookAllPage()开始=========="+parameters+"】");
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("pageSize"), "pageSize")
		.put(parameters.get("pageNum"), "pageNum")
		.put(parameters.get("userId"), "userId").checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopAssessService.findMyLookAllPage(parameters);
		logger.info("【findMyLookAllPage()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	@PostMapping("/findAppLookJson")
	public ResultObject findAppLookJson(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findAppHelpType()开始=========="+parameters+"】");
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("helpType"), "helpType")
		.put(parameters.get("cityId"), "cityId").checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopAssessService.findAppLookJson(parameters);
		logger.info("【findAppHelpType()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	
	
	
}
