package com.up.zpb.controller.api;

import com.up.zpb.hz.callback.ApproveCallBack;
import com.up.zpb.hz.callback.SignCallBack;
import com.up.zpb.hz.exception.DefineException;
import com.up.zpb.service.ContractService;
import com.up.zpb.service.UserService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.IpUtil;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.Contract;
import com.up.zpb.vo.ResultObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

/**
 * @author liuwei
 * E签宝合同调用API
 */
@RestController
@RequestMapping(value = "/contract")
public class ContractController {

    private static final Logger logger = LoggerFactory.getLogger(ContractController.class);

    @Autowired
    private ContractService contractService;

    @Autowired
    private UserService userService;

    /**
     * E签宝回调IP地址
     */
    private static final String CALLBLACKURL = "118.31.35.8";


    /**
     * e签宝 获取认证、签署
     * 该流程 先创建了模板，然后获取了签署地址，在认证地址的重定向地址中添加了签署地址，用户认证完成之后直接跳转签署页面
     * 该接口在生成 签署地址、认证地址的时候，会取user_app表中的主键ID作为主键向contract表中存储用户的数据
     * 包含 E签宝的整个签署流程的FlowId  认证的流程的agent_flowId  认证的短连接地址以及签署的短连接地址  串联我方业务流程
     *
     *  个人实名认证
     *          姓名 name
     *          身份证号  idNumber
     *
     *  企业实名认证
     *      1.法定代表人
     *          单位名称  companyName
     *          单位证件号 companyNumber
     *
     *          企业法人证件号  orgLegalIdNumber
         *          企业法人名称    orgLegalName
     *
     *      2.组织其他员工
     *          姓名 name
     *          身份证号  idNumber
     *
     *          单位名称  companyName
     *          单位证件号 companyNumber
     *
     *          企业法人证件号  orgLegalIdNumber
     *          企业法人名称    orgLegalName
     *
     * @param request 参数origin 为请求来源 PC固定传1  安卓固定传2  ios固定传3
     */
    @PostMapping("/start")
    public ResultObject contractStart(HttpServletRequest request) throws DefineException {
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        ResultObject resultObject = new ResultObject();
        logger.info("【ContractStartController】【contractStart()开始==========】" + parameters + "");
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("userAppId"), "userAppId")
                    .put(parameters.get("origin"), "origin")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }

        return contractService.contractStart(parameters);
    }

    /**
     * e签宝签署回调接口   异步通知
     * 根据创建签署流程时的flowId修改通知签署状态 保存签署时间 如果拒签保存签署状态
     * 签署回调 个人与企业参数一致
     *
     * @param signCallBack
     */
    @PostMapping("/signCallBack")
    public void signCallBack(@RequestBody SignCallBack signCallBack, HttpServletRequest req) {
        try {
            logger.info("【ContractStartController】【signCallBack()e签宝签署完成回调开始==========】" + signCallBack.toString() + "");
            String ipAddr = IpUtil.getIpAddr(req);
            logger.info("回调IP地址为：" + ipAddr);
            if (!CALLBLACKURL.equals(ipAddr))
                return;

            Contract contract = new Contract();
            //根据flowId修改
            contract.setFlowId(signCallBack.getFlowId());
            //签署结果
            contract.setSignStatus(signCallBack.getSignResult());
            //如果失败or拒绝，原因
            contract.setCause(signCallBack.getResultDescription());
            //格式化时间
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date time = sdf.parse(signCallBack.getSignTime());
            //签署或拒绝时间
            contract.setSignTime(time);
            //修改
            contractService.updateByPrimaryKeySelective(contract);
        } catch (ParseException e) {
            e.printStackTrace();
        }
    }

    /**
     * e签宝认证完成回调开始   异步通知  通知数据存储系统数据库contract表中
     * 根据E签宝创建认证流程之前的传给E签宝的contextId修改认证状态  contextId == userAppId
     * 认证回调 个人与企业认证回调接口参数不同，为了兼容企业回调与个人回调，ApproveCallBack中有冗余字段
     *
     * @param approveCallBack
     */
    @PostMapping("/approveCallBack")
    public void approveCallBack(@RequestBody ApproveCallBack approveCallBack, HttpServletRequest request) {
        try {
            logger.info("【ContractStartController】【approveCallBack()e签宝认证完成回调开始==========】" + approveCallBack.toString() + "");
            String ipAddr = IpUtil.getIpAddr(request);
            logger.info("回调IP地址为：" + ipAddr);
            if (!CALLBLACKURL.equals(ipAddr))
                return;

            Contract contract = new Contract();
            //根据contextId修改
            contract.setUserAppId(Integer.parseInt(approveCallBack.getContextId()));
            //认证状态
            contract.setApproveStatus(approveCallBack.isSuccess() ? 1 : 0);
            //修改
            int i = contractService.approveCallBack(contract);
            if (i > 0) {
                logger.info("【ContractStartController】【approveCallBack() e签宝认证完成回调结束，认证结果：{}】", approveCallBack.isSuccess());
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 查询e签宝签署状态
     * 状态说明
     * 0 ：没有认证签署过，调用接口获取认证签署地址
     * 1 ：认证签署成功
     * 2 ：认证签署接口以请求过，但认证或签署状态意外终止，有认证地址和签署地址，根据状态返回当前进度对应的url
     *
     * 如果用户是拒签用户，那么返回的也是0，满足业务需求，即使拒签过的用户仍然可以签合同
     * @param request
     * @return
     * @throws DefineException
     */
    @PostMapping("/selectApproveStatus")
    public ResultObject selectApproveStatus(HttpServletRequest request) throws DefineException {
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        logger.info("【ContractStartController】【selectApproveStatus()查询e签宝签署状态start==========】" + parameters.toString() + "");
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("userAppId"), "userAppId")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        String userAppId = parameters.get("userAppId") + "";
        Map<String, Object> status = contractService.selectApproveStatus(Integer.parseInt(userAppId));
        resultObject.put("signFlag", status.get("status"));
        resultObject.put("url", status.get("url"));
        logger.info("【ContractStartController】【selectApproveStatus()查询e签宝签署状态end==========】" + resultObject.toString() + "");
        return resultObject;
    }


    /**
     * e签宝合同签署流程撤销
     * 根据contract表中flowId撤销，撤销之后可在合同管理中的待签署列表中删除本条记录避免冗余数据太多不方便管理
     *
     * @param request
     * @return
     * @throws DefineException
     */
    @PostMapping("/revokeSignFlow")
    public ResultObject revokeSignFlow(HttpServletRequest request) throws DefineException {
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        logger.info("【ContractStartController】【revokeSignFlow()查询e签宝合同签署流程撤销start==========】"+parameters.toString()+"");
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("flowId"), "flowId")
                    .checkParameter();
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        resultObject = contractService.revokeSignFlow(parameters.get("flowId") + "");
        logger.info("【ContractStartController】【revokeSignFlow()查询e签宝合同签署流程撤销end==========】");
        return resultObject;
    }

    /**
     * 注销公司账户
     * @param request
     * @throws DefineException
     */
    @PostMapping("/qryOrgAcctByOrgId")
    public void qryOrgAcctByOrgId(HttpServletRequest request) throws DefineException {
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        contractService.qryOrgAcctByOrgId(parameters.get("orgId")+"");
    }

}

