/**
 *
 */
package com.up.zpb.controller.api;

import java.util.Map;
import java.util.Objects;

import javax.servlet.http.HttpServletRequest;

import com.google.common.collect.Maps;
import com.up.zpb.service.*;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.UserApp;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;

import com.up.zpb.controller.AbstractController;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ResultException;
import com.up.zpb.vo.ResultObject;
import org.springframework.web.bind.annotation.RestController;

/**
 *
 * @author gust
 *
 */
@RestController
@Controller
@RequestMapping
public class LoginController extends AbstractController {

    private static final Logger logger = LoggerFactory.getLogger(LoginController.class);

    @Autowired
    DictionaryService dictionaryService;

    @Autowired
    MemberService memberService;

    @Autowired
    RedisBaseDao redisBaseDao;

    @Autowired
    AsyncLoginLogService asyncLoginLogService;

    @Autowired
    LoginService loginService;

    @Autowired
    UserService userService;


    /**
     * 身份变更
     * @param accountName 姓名
     * @param corporateCity 公司城市名称
     * @param corporateName 公司名称
     * @param corporateImg 公司营业执照图片地址
     * @param userType 用户类别 2经纪人 3公司
     * @return
     */
    @PostMapping("/auth/identity")
    public ResultObject identity(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        parameters.put("account", parameters.get("paramPhone"));
        try {
            if (Objects.isNull(parameters.get("userType"))) {
                resultObject.setCode(Constant.CODE_PARAM_NULL);
                resultObject.setMessage("用户类别为必传");
                return resultObject;
            }
            if (parameters.get("userType").equals("2")) {
                try {
                    CheckParametersUtil.getInstance()
                            .put(parameters.get("accountName"), "accountName")
                            .checkParameter();
                } catch (Exception e) {
                    resultObject.setCode(Constant.CODE_PARAM_NULL);
                    resultObject.setMessage(e.getMessage());
                    logger.error(e.getMessage(), e);
                    return resultObject;
                }
                return loginService.updateUserTypePeople(parameters);
            } else if (parameters.get("userType").equals("3")) {
                try {
                    CheckParametersUtil.getInstance()
                            .put(parameters.get("corporateCity"), "corporateCity")
                            .put(parameters.get("corporateName"), "corporateName")
                            .put(parameters.get("corporateImg"), "corporateImg")
                            .put(parameters.get("accountName"), "accountName")
                            .checkParameter();
                } catch (Exception e) {
                    resultObject.setCode(Constant.CODE_PARAM_NULL);
                    resultObject.setMessage(e.getMessage());
                    logger.error(e.getMessage(), e);
                    return resultObject;
                }
                return loginService.updateUserTypeCorporate(parameters);
            }
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }


    /**
     * 找回密码
     * @param request
     * @param account 手机号码
     * @param validCode 验证码
     * @param password 新密码
     * @return
     */
    @PostMapping("/retrieve")
    public ResultObject retrieve(HttpServletRequest request, String account, String validCode, String password) {
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(account, "account")
                    .put(password, "password")
                    .put(validCode, "validCode")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        String token = request.getHeader(Constant.APP_HEADER_ACCESS_TOKEN);
		if(StringUtils.isBlank(token)) {
			token = request.getParameter(Constant.APP_HEADER_ACCESS_TOKEN);
		}
		//access_token = redisBaseDao.get("access_token").toString();
        return loginService.retrieve(request, account, password, validCode);
    }


    /**
     * 手机号密码登陆
     * @param request
     * @param account 手机号码
     * @param password 密码
     * @return
     */
    @PostMapping("/login")
    public ResultObject login(HttpServletRequest request, String account, String password) {
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(account, "account")
                    .put(password, "password")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return loginService.login(request, account, password);
    }

    /**
     *  注册提交
     * @param request
     * @param account 手机号
     * @param validCode 验证码
     * @param password 密码
     * @param cityId 城市Id
     * @param channel 渠道     0-PC；1-ios ；2-android；3-m站
     * @return
     */
    @PostMapping("/register")
    public ResultObject Register(HttpServletRequest request, String account, String validCode, String cityId, String password, String channel) {
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(account, "account")
                    .put(validCode, "validCode")
                    .put(password, "password")
                    .put(cityId, "cityId")
                    .put(channel, "channel")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        //检测登录来源
        String userAgent = request.getHeader("user-agent");
        logger.info("login userAgent:{}", userAgent);
        resultObject = loginService.register(account, validCode, password, userAgent, "1", cityId, channel);
        return resultObject;
    }

    /**
     * 验证码登陆
     * @param request
     * @param account 手机号
     * @param validCode 验证码
     * @return
     */
    @PostMapping("/loginCode")
    public ResultObject loginCode(HttpServletRequest request, String account, String validCode, String cityId) {
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(account, "account")
                    .put(validCode, "validCode")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return loginService.loginCode(request, account, validCode, cityId);
    }


    /**
     * 发送验证码
     * @param phoneNumber 手机号码
     * @param type 验证码类型 0 注册时验证码，1 找回密码时验证码 2 手机登陆时验证码
     * @return
     */
    @PostMapping("/sendsms")
    public ResultObject sendSMS(String phoneNumber, String type) {
        logger.info("sendsms phoneNumber:{}", phoneNumber);
        ResultObject resultObject = new ResultObject();
        try {
            CheckParametersUtil.getInstance()
                    .put(phoneNumber, "phoneNumber")
                    .put(type, "type")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        try {
            if (type.equals("0")) {
                //用户为注册时获取验证码，查询是否已注册
                Map<String, Object> mapParam = Maps.newHashMap();
                mapParam.put("account", phoneNumber);
                UserApp userApp = userService.selectUserByAccount(mapParam);
                if (null != userApp) {
                    resultObject.setCode(Constant.CODE_EXCEPTION);
                    resultObject.setMessage("用户已注册，请前往登陆");
                    return resultObject;
                }
                return sendCode(phoneNumber);
            } else if (type.equals("1")) {
                Map<String, Object> mapParam = Maps.newHashMap();
                mapParam.put("account", phoneNumber);
                UserApp user = userService.selectUserByAccount(mapParam);
                if (null == user) {
                    resultObject.setCode(Constant.RETRIEVE_ERROR);
                    resultObject.setMessage("用户未注册，请前往注册");
                    return resultObject;
                }
                return sendCode(phoneNumber);
            } else {
                return sendCode(phoneNumber);
            }
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }


    /**
     * 发送短信
     * @param phoneNumber 手机号码
     * @return
     */
    public ResultObject sendCode(String phoneNumber) {
        ResultObject resultObject = new ResultObject();
        try {
            Map<String, Object> sendSms2 = loginService.sendSms(phoneNumber);
            boolean sendSms = (boolean) sendSms2.get("flag");
            if (!sendSms) {
                resultObject.setCode(Constant.CODE_EXCEPTION);
                resultObject.setMessage("发送短信失败");
                return resultObject;
            }
        } catch (ResultException e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("发送短信异常");
            logger.error(e.getMessage(), e);
        }
        logger.info("sendsms end");
        return resultObject;
    }

    /**
     * 邀请注册
     * @return
     */
    @PostMapping("/invitationRegister")
    public ResultObject invitationRegister(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("account"), "account")
                    .put(parameters.get("validCode"), "validCode")
                    .put(parameters.get("parentId"), "parentId")
                    .put(parameters.get("cityId"), "cityId")
                    .put(parameters.get("name"), "name")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        resultObject = loginService.invitationRegister(parameters);
        return resultObject;
    }

    /**
     * 修改用户密码
     *
     * type 1为修改密码 2为新增密码
     * @return
     */
    @PostMapping("/auth/updatePassword")
    public ResultObject updatePassword(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        if (String.valueOf(parameters.get("type")).equals("1")){
            try {
                CheckParametersUtil.getInstance()
                        .put(parameters.get("oldPassword"), "oldPassword")
                        .put(parameters.get("newPassword"), "newPassword")
                        .checkParameter();
            } catch (Exception e) {
                resultObject.setCode(Constant.CODE_PARAM_NULL);
                resultObject.setMessage(e.getMessage());
                logger.error(e.getMessage(), e);
                return resultObject;
            }
            return loginService.updatePassword(parameters);
        }else{
            try {
                CheckParametersUtil.getInstance()
                        .put(parameters.get("newPassword1"), "newPassword1")
                        .put(parameters.get("newPassword2"), "newPassword2")
                        .checkParameter();
            } catch (Exception e) {
                resultObject.setCode(Constant.CODE_PARAM_NULL);
                resultObject.setMessage(e.getMessage());
                logger.error(e.getMessage(), e);
                return resultObject;
            }
            return loginService.addPassword(parameters);
        }
    }

}

