package com.up.zpb.controller.api;

import java.util.Map;
import java.util.Objects;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.controller.AbstractController;
import com.up.zpb.service.AsyncLoginLogService;
import com.up.zpb.service.MemberService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserLoginLog;


@RestController
@RequestMapping("member")
public class MemberController extends AbstractController{
	
	private static final Logger logger = LoggerFactory.getLogger(MemberController.class);
	
	@Autowired
	MemberService memberService;
	
	@Autowired
	AsyncLoginLogService asyncLoginLogService;
	
	/**
	 * 创建收藏记录
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/saveCollection")
	public Map<String, Object> createShopCollection(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("shopId"), "shopId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			memberService.createShopCollection(parameters);
			resultObject.put("shopCollId", parameters.get("shopId"));
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("saveCollection end");
		return resultObject;
	}
	
	
	/**
	 * 我的收藏列表
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/selectCollectionList")
	public Map<String, Object> selectCollectionList(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("pageSize"), "pageSize")
				.put(parameters.get("pageNum"), "pageNum")
				.put(parameters.get("userId"), "userId")
				.put(parameters.get("rentType"), "rentType")
				.put(parameters.get("projectType"), "projectType")
				.checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
			Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			resultObject=memberService.selectCollectionList(parameters);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		return resultObject;
	}
	
	
	/**
	 * 删除收藏
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/deleteCollection")
	public Map<String, Object> deleteCollection(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("shopId"), "shopId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=memberService.deleteCollection(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("deleteCollection end");
		return resultObject;
	}
	
	/**
	 * 取消收藏
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/cancelCollection")
	public Map<String, Object> cancelCollection(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("shopId"), "shopId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=memberService.cancelCollection(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("getShopExponential end");
		return resultObject;
	}
	
	/**
	 * 获取会员服务信息
	 * @param request
	 * @return
	 */
	@PostMapping("/selectProductList")
	public Map<String, Object> selectProductList(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId")
				.put(parameters.get("type"), "type").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject.put("productList", memberService.selectProductList(parameters));
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("selectProductList end");
		return resultObject;
	}
	
	/**
	 * 获取会员服务信息
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/getMyOrders")
	public Map<String, Object> getMyOrders(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("pageSize"), "pageSize")
				.put(parameters.get("pageNum"), "pageNum").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
			Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			resultObject = memberService.getMyOrders(parameters);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("selectProductList end");
		return resultObject;
	}
	
	/**
	 * 获取会员信息
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/getMyMember")
	public Map<String, Object> getMyMember(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("pageSize"), "pageSize")
				.put(parameters.get("pageNum"), "pageNum").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = memberService.getMyMember(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("selectProductList end");
		return resultObject;
	}
	
	/**
	 * 获取是否有未读消息
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/getMsgStatus")
	public Map<String, Object> getMsgStatus(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = memberService.getMsgStatus(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("getMsgStatus end");
		return resultObject;
	}
	
	/**
	 * 获取消息列表
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/selectMsgList")
	public Map<String, Object> selectMsgList(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId")
				.put(parameters.get("pageSize"), "pageSize")
				.put(parameters.get("pageNum"), "pageNum").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
			Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			resultObject = memberService.selectMsgList(parameters);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("getMsgStatus end");
		return resultObject;
	}
	
	
	/**
	 * 获取消息列表
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/updateMsgStatus")
	public Map<String, Object> updateMsgStatus(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = ServletUtils.getParameters(request);
		try {
			try {
				CheckParametersUtil.getInstance().put(parameters.get("id"), "id")
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = memberService.updateMsgStatus(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("updateMsgStatus end");
		return resultObject;
	}
	
	/**
	 * 微信分享
	 * @param request
	 * @return
	 */
	@PostMapping("/weChatShare")
	public ResultObject weChatShare(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("url"), "url").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = memberService.weChatShare(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 判断是否微信登录过
	 */
	@PostMapping("/isWeChatLogin")
	public ResultObject isWeChatLogin(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("openId"), "openId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = memberService.isWeChatLogin(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}

	/**
	 * 微信授权
	 * 微信登陆绑定手机号
	 * @param request
	 * @return
	 */
	@PostMapping("/weChatLogin")
	public ResultObject weChatLogin(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("openId"), "openId")
				.put(parameters.get("account"), "account").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			String userAgent = request.getHeader("user-agent");
			parameters.put("userAgent", userAgent);
			resultObject = memberService.weChatLogin(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 记录登录后当日首次分享次数
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/shareRecords")
	public ResultObject shareRecords(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject = memberService.shareRecords(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 获取用户操作记录表
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/selectUserOperList")
	public ResultObject selectUserOperList(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId")
				.put(parameters.get("pageSize"), "pageSize")
				.put(parameters.get("pageNum"), "pageNum").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
			Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			resultObject = memberService.selectUserOperList(parameters);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	
}
