package com.up.zpb.controller.api;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.controller.AbstractController;
import com.up.zpb.service.MsgService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

/***
 * 站内消息控制器
 */
@RestController
@RequestMapping("msg")
public class MsgController extends AbstractController {

    private static final Logger logger = LoggerFactory.getLogger(MsgController.class);

    @Autowired
    private MsgService msgService;

    /**
     * 消息列表
     *
     * @param request
     * @return
     */
    @PostMapping("/auth/list")
    public ResultObject list(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        try {
            Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
            Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
            Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
            resultObject = msgService.selectList(parameters);
            resultObject.put("totalCount", startPage.getTotal());
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

    /**
     * 消息已读
     * id 消息id or 当前登录人id
     * type 1-单条已读 2-全部已读；3-单条删除 4-全部删除
     *
     * @param request
     * @return
     */
    @PostMapping("/auth/readAndDelete")
    public ResultObject alreadyRead(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("type"), "type")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        //单条删除或者单条已读，id为必传参数
        if (StringUtils.equals(String.valueOf(parameters.get("type")), "1") || StringUtils.equals(String.valueOf(parameters.get("type")), "3")) {
            try {
                CheckParametersUtil.getInstance()
                        .put(parameters.get("id"), "id")
                        .checkParameter();
            } catch (Exception e) {
                resultObject.setCode(Constant.CODE_PARAM_NULL);
                resultObject.setMessage(e.getMessage());
                logger.error(e.getMessage(), e);
                return resultObject;
            }
        }
        try {
            resultObject = msgService.alreadyRead(parameters);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

    /**
     * 获取当前用户未读消息数量
     *
     * @param request
     * @return
     */
    @PostMapping("/auth/count")
    public ResultObject count(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            resultObject = msgService.selectCount(parameters);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

    /**
     * 消息详情页接口
     * type 1-用户在列表中点击的消息  2-用户点击友盟推送消息返回的消息数据
     * @param request
     * @return
     */
    @PostMapping("/detail")
    public ResultObject detail(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("id"), "id")
                    .put(parameters.get("type"), "type")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        try {
            resultObject = msgService.selectDetail(parameters);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

}
