package com.up.zpb.controller.api;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.controller.AbstractController;
import com.up.zpb.service.ContractService;
import com.up.zpb.service.ShopService;
import com.up.zpb.service.UserService;
import com.up.zpb.service.customer.CustomerService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

@RestController
@RequestMapping("myCreate")
public class MyCreateController extends AbstractController {

    private static final Logger logger = LoggerFactory.getLogger(MyCreateController.class);
    @Autowired
    private CustomerService customerService;

    @Autowired
    private ShopService shopService;

    @Autowired
    private UserService userService;

    @Autowired
    private ContractService contractService;

    /**
     * 我的发布-客源
     *
     * @return
     */
    @PostMapping("/auth/myCustomer")
    public ResultObject myCustomer(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("id"), "id")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
        Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
        Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
        resultObject = customerService.selectPage(parameters);
        resultObject.put("totalCount", startPage.getTotal());
        return resultObject;
    }


    /**
     * 我的发布-房源
     *
     * @return
     */
    @PostMapping("/auth/myShop")
    public ResultObject myShop(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("id"), "id")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
        Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
        Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
        resultObject = shopService.selectPage(parameters);
        resultObject.put("totalCount", startPage.getTotal());
        return resultObject;
    }

    
    /**
     * 我发布的房源-pc
     *
     * @return
     */
    @PostMapping("/findMyPublishAll")
    public ResultObject findMyPublishAll(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("agentId"), "agentId")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
        Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
        Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
        resultObject = shopService.findMyPublishAll(parameters);
        resultObject.put("totalCount", startPage.getTotal());
        return resultObject;
    }

    /**
     * 我的委托
     *
     * @param request
     * @return
     */
    @PostMapping("/auth/myHomeEntrust")
    public ResultObject myHomeEntrust(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("id"), "id")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
        Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
        Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
        resultObject = shopService.selectMyHomeEntrustPage(parameters);
        resultObject.put("totalCount", startPage.getTotal());
        return resultObject;
    }

    /**
     * App我的委托
     *
     * @param request
     * @return
     */
    @PostMapping("/myAppHomeEntrust")
    public ResultObject myAppHomeEntrust(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("pageSize"), "pageSize")
                    .put(parameters.get("pageNum"), "pageNum")
                    .put(parameters.get("id"), "id")
                    .put(parameters.get("type"), "type")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        Integer pageSize = Integer.valueOf((String) parameters.get("pageSize"));
        Integer pageNum = Integer.valueOf((String) parameters.get("pageNum"));
        Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
        resultObject = shopService.selectMyAppHomeEntrustPage(parameters);
        resultObject.put("totalCount", startPage.getTotal());
        return resultObject;
    }

    /**
     * 更改我的委托 已联系 未联系操作
     * @param request
     * @return
     */
    @PostMapping("/updateTel")
    public ResultObject updateTel(HttpServletRequest request){
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("id"), "id")
                    .checkParameter();
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        shopService.updateTel(parameters);
        return resultObject;
    }

    /**
     * 修改用户名
     *
     * @param request
     * @return
     */
    @PostMapping("/auth/updateUserName")
    public ResultObject updateUserName(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            CheckParametersUtil.getInstance()
                    .put(parameters.get("userName"), "userName")
                    .checkParameter();
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_PARAM_NULL);
            resultObject.setMessage(e.getMessage());
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return shopService.updateUserName(parameters);
    }

    /**
     * 获取用户信息
     *
     * @param request
     * @return
     */
    @PostMapping("/auth/getUserInfo")
    public ResultObject getUserInfo(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            resultObject.put("data", userService.selectUserByAccount(parameters));
            resultObject.put("url", contractService.selectUserContractUrl(Integer.parseInt(parameters.get("authentication")+"")));
            Map<String, Object> status = contractService.selectApproveStatus(Integer.parseInt(parameters.get("authentication") + ""));
            resultObject.put("signStatus",status.get("status"));
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

    /**
     * 用户基本信息
     * @param request
     * @return
     */
    @PostMapping("/auth/getUser")
    public ResultObject getUser(HttpServletRequest request) {
        ResultObject resultObject = new ResultObject();
        Map<String, Object> parameters = ServletUtils.getParameters(request);
        try {
            resultObject.put("data", userService.getUser(parameters));
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }
}
