package com.up.zpb.controller.api;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageHelper;
import com.up.zpb.service.PhotoService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ResultException;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;

/**
 * 拍店模块
 * @author gust
 */
@RestController
@RequestMapping("photo")
public class PhotoController {

	private static final Logger logger = LoggerFactory.getLogger(PhotoController.class);

	@Autowired
	private PhotoService photoService;


	/**
	 * 校验手机号
	 * @param phone 店主手机号
	 * @param cityId 城市id
	 * @return
	 */
	@PostMapping("/auth/verifyPhone")
	public Map<String, Object> verifyPhone(HttpServletRequest request){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance()
						.put(parameters.get("phone"), "phone")
						.put(parameters.get("cityId"), "cityId")
						.checkParameter();
			  } catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			 }
			resultObject=photoService.verifyPhone(parameters);
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_EXCEPTION);
				resultObject.setMessage("系统异常");
				logger.error(e.getMessage(), e);
			}
		return resultObject;
	}
	
	/**
	 * 保存拍店提交的信息
	 * @param cityId 城市
	 * @param phone 店主手机号
	 * @param imgs 拍店照片用逗号拼接
	 * @param address 详细地址
	 * @param location 定位用逗号拼接
	 * @return
	 */
	@PostMapping("/auth/savePhotoInfo")
	public Map<String, Object> getPublishInfo(HttpServletRequest request){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			logger.info("savePhotoInfo  parameters:{}",parameters);
			try {
					CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId")
					.put(parameters.get("phone"), "phone")
					.put(parameters.get("address"), "address")
					.put(parameters.get("imgs"), "imgs")
					.put(parameters.get("location"), "location").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=photoService.savePhotoInfo(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	/**
	 * 获取拍店记录列表
	 * @param cityId 城市id
	 * @param type 审核状态
	 * @return
	 */
	@PostMapping("/auth/getPhotoList")
	public Map<String, Object> getPhotoList(HttpServletRequest request){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() 
				.put(parameters.get("pageSize"), "pageSize")
				.put(parameters.get("pageNum"), "pageNum")
				.put(parameters.get("cityId"), "cityId")
				.put(parameters.get("type"), "type").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
			Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
			PageHelper.startPage(pageNum, pageSize,false);
			resultObject=photoService.getPhotoList(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 获取拍店奖励规则
	 * @param cityId 城市id
	 * @return
	 */
	@PostMapping("/getPhotoRules")
	public Map<String, Object> getPhotoRules(HttpServletRequest request){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId").checkParameter();
			  } catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			 }
			resultObject=photoService.getPhotoRules(parameters);
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_EXCEPTION);
				resultObject.setMessage("系统异常");
				logger.error(e.getMessage(), e);
			}
		return resultObject;
	}

}
