package com.up.zpb.controller.api;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.ShopService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ResultException;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.enums.ProjectEnum;
import com.up.zpb.vo.enums.ShopEnum;

/**
 * 商铺相关
 * @author gust
 *
 */
@RestController
@RequestMapping("shop")
public class ShopController {

	private static final Logger logger = LoggerFactory.getLogger(ShopController.class);
	
	@Autowired
	private ShopService shopService;

	@Autowired
	RedisBaseDao redisBaseDao;
	
	
	/**
	 * 一键纠错(获取纠错信息)
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/getCorrectionInfo")
	public Map<String, Object> getCorrectionInfo(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("shopId"), "shopId")
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopService.getCorrectionInfo(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 保存提交的纠错信息
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/submitCorrectionInfo")
	public Map<String, Object> submitCorrectionInfo(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("shopId"), "shopId")
				.put(parameters.get("cityId"), "cityId")
				.put(parameters.get("reason"), "reason").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			shopService.submitCorrectionInfo(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 每个账号每日查看套数
	 * 
	 * @param account
	 *            手机号
	 * @param shopId
	 *            商铺Id
	 * @param type
	 *            0 首次 不减 1 减值 APP端用于判断该商铺是否被查看过
	 * @param roof
	 *            0 M站 1 PC官网 
	 * @return checkedStatus 查看过 true. 没查看过 false
	 */
	@PostMapping("/shopCheckedRecords")
	public Map<String, Object> shopCheckedRecords(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("shopId"), "shopId")
				.put(parameters.get("cityId"), "cityId")
				.put(parameters.get("type"), "type").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopService.shopCheckedRecords(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	/**
	 * 获取店主电话
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/selectPhone")
	public Map<String, Object> selectPhone(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("shopId"), "shopId")
				.put(parameters.get("type"), "type").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopService.selectPhone(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 求租列表
	 * @param request
	 * @return
	 */
	/*@PostMapping("/selectSolicit")
	public Map<String, Object> selectSolicit(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() .put(parameters.get("pageSize"), "pageSize")
				.put(parameters.get("pageNum"), "pageNum")
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
			Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			resultObject=shopService.selectSolicit(parameters);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}*/
	
	
	/**
	 * 求租详情
	 * @param request
	 * @return
	 */
	/*@PostMapping("/selectSolicitDetail")
	public Map<String, Object> selectSolicitDetail(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() .put(parameters.get("id"), "id").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopService.selectSolicitDetail(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}*/
	
	/**
	 * 判断是否为转店会员
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/isVip")
	public Map<String, Object> isVip(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance().put(parameters.get("id"), "id")
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopService.isVip(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	/**
	 * 下拉框-区域-商圈-街道  
	 * @param request
	 * @return
	 */
	@PostMapping("/findShangBanSearch")
	public Map<String, Object> findShangBanSearch(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopService.findShangBanSearch(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	
	//=========================================================================start
	/**
	 * 商铺出售主页-搜索条件
	 * 区域-面积-总价-类型
	 * @param request
	 * @return
	 */
	@PostMapping("/findShopSaleSearch")
	public Map<String, Object> findShopSaleSearch(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			logger.info("【findShopSaleSearch()开始=========="+parameters+"】");
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			parameters.put("belongs", "1");
			resultObject=this.shopService.findShopSaleSearch(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【findShopSaleSearch()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * 商铺出租主页-搜索条件
	        区域-行业-面积-月租-转让费-类型
	 * @param request
	 * @return
	 */
	@PostMapping("/findShopRentSearch")
	public Map<String, Object> findShopRentSearch(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			parameters.put("belongs", "1");
			resultObject=this.shopService.findShopRentTitle(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	
	/**
	 * 商铺新盘主页-搜索条件
	        区域-均价-类型
	 * @param request
	 * @return
	 */
	@PostMapping("/findShopNewSearch")
	public Map<String, Object> findShopNewSearch(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			logger.info("【findShopNewSearch()开始=========="+parameters+"】");
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			parameters.put("belongs", "1");
			resultObject=this.shopService.findShopNewSearch(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【findShopNewSearch()结束=========="+resultObject+"】");
		return resultObject;
	}
	//==============================================================================end
	
	@PostMapping("/selectShopPage")
	public ResultObject selectShopPage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【selectShopPage()开始=========="+parameters+"】");
		try{
		CheckParametersUtil.getInstance() 
		.put(parameters.get("pageSize"), "pageSize")
		.put(parameters.get("pageNum"), "pageNum")
		.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		parameters.put("sortColumn","1");
		resultObject=this.shopService.selectShopPage(parameters);
		logger.info("【selectShopPage()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	
	/**
	 * 推荐
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/selectHotShop")
	public ResultObject selectHotShop(HttpServletRequest request) throws Exception{
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		parameters.put("limit", 5);
		return this.shopService.selectHotShop(parameters);
	}
	
	
	/**
	 * 我跟进的商铺
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/findMyFollowShopPage")
	public ResultObject findMyFollowShopPage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findMyFollowShopPage()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance() 
			/*.put(parameters.get("pageSize"), "pageSize")
			.put(parameters.get("pageNum"), "pageNum")*/
			.put(parameters.get("agentId"), "agentId")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopService.findMyFollowShopPage(parameters);
		logger.info("【findMyFollowShopPage()结束=========="+resultObject+"】");
		return resultObject;
	}

	
	@PostMapping("/myPublishSearch")
	public ResultObject myPublishSearch(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【myPublishSearch()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
					.put(parameters.get("cityId"), "cityId")
					.put(parameters.get("projectType"), "projectType")
					.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopService.myPublishSearch(parameters);
		logger.info("【myPublishSearch()结束=========="+resultObject+"】");
		return resultObject;
	}

	/**
	 * 我发布的商铺 app
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/findMyPublishShopPage")
	public ResultObject findMyPublishShopPage(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【findMyPublishShopPage()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
					.put(parameters.get("pageSize"), "pageSize")
					.put(parameters.get("pageNum"), "pageNum")
					.put(parameters.get("agentId"), "agentId")
					/*.put(parameters.get("auditStatus"), "auditStatus")*/
					.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopService.findMyPublishShopPage(parameters);
		logger.info("【findMyPublishShopPage()结束=========="+resultObject+"】");
		return resultObject;
	}


	/**
	 * 个人管理-跟进的商铺
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/selectShopManager")
	public ResultObject selectShopManager(HttpServletRequest request) throws Exception {
		//TODO 缺少查看信息 数量
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【ShopController】【selectShopManager()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
					.put(parameters.get("projectType"), "projectType")
					.put(parameters.get("type"), "type")
					.put(parameters.get("pageNum"), "pageNum")
					.put(parameters.get("pageSize"), "pageSize")
					.put(parameters.get("agentId"), "agentId")
					.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopService.selectShopManager(parameters);
		logger.info("【ShopController】【selectShopManager()结束=========="+resultObject+"】");
		return resultObject;
	}

	/**
	 * 获取 我的页面  跟进管理中  城市搜索区域下拉
	 * 根据城市ID获取城市下的区域
	 * @param request cityId 城市ID
	 * @return
	 * @throws Exception
	 */
	@PostMapping("/getFollowSearchArea")
	public ResultObject getFollowSearch(HttpServletRequest request)throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【ShopController】【getFollowSearch()开始=========="+parameters+"】");
		try{
			CheckParametersUtil.getInstance()
					.put(parameters.get("cityId"), "cityId")
					.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject=this.shopService.getFollowSearch(parameters);
		logger.info("【ShopController】【getFollowSearch()结束=========="+resultObject+"】");
		return resultObject;
	}



	/**
	 * 获取 我的页面  跟进管理中  订单状态下拉
	 * @param request
	 * @return
	 * @throws Exception
	 */
	@GetMapping("/getOrderStatusSearch")
	public ResultObject getOrderStatusSearch()throws Exception{
		ResultObject resultObject=new ResultObject();
		logger.info("【ShopController】【getOrderStatusSearch()开始==========】");
		try {
            ProjectEnum.OrderStatus[] orderStatuses = ProjectEnum.OrderStatus.values();
            HashMap<String, Object> map = new HashMap<>();
            map.put("stauts_name","全部状态");
            map.put("id",null);
            ArrayList<Object> list = new ArrayList<>();
            list.add(map);
            for (ProjectEnum.OrderStatus orderStatus : orderStatuses) {
                HashMap<String, Object> map2 = new HashMap<>();
                map2.put("stauts_name",orderStatus.getName());
                map2.put("id",orderStatus.getValue());
                list.add(map2);
            }
            resultObject.put("orderStatus",list);
        }catch (Exception e){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		logger.info("【ShopController】【getOrderStatusSearch()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	@PostMapping("/pcShopDetail")
	public Map<String, Object> pcShopDetail(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			logger.info("【pcShopDetail()开始=========="+parameters+"】");
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("projectId"), "projectId")
				.checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			/*String redisKey=ProjectEnum.ProjectTypeRedis.codeOf(parameters.get("projectType")+"").getName() + parameters.get("projectId");
			if(redisBaseDao.exists(redisKey)){
				resultObject.putAll(redisBaseDao.hMGetMap(redisKey));
			}else {
				resultObject=this.officeService.findProjectDetail(parameters);
			}*/
			resultObject=this.shopService.pcShopDetail(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【pcShopDetail()结束=========="+resultObject+"】");
		return resultObject;
	}


	/**
	 * app 商铺出售 出租 新盘 详情接口
	 * @param request
	 * @return
	 */
	@PostMapping("/appShopDetail")
	public Map<String, Object> appShopDetail(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			logger.info("【appShopDetail()开始=========="+parameters+"】");
			try {
				CheckParametersUtil.getInstance()
				.put(parameters.get("projectId"), "projectId")
				.checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=this.shopService.appShopDetail(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【appShopDetail()结束=========="+resultObject+"】");
		return resultObject;
	}
	
	/**
	 * 下架
	 */
	@PostMapping("/shopOut")
	public  ResultObject shopOut(HttpServletRequest request) throws Exception{
		ResultObject resultObject=new ResultObject();
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		try{
			CheckParametersUtil.getInstance()
			.put(parameters.get("id"), "id")
			.put(parameters.get("onlineStatus"), "onlineStatus")
			.checkParameter();
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_PARAM_NULL);
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
			return resultObject;
		}
		resultObject= this.shopService.shopOut(parameters);
		return resultObject;
	}


}
