package com.up.zpb.controller.api;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.codec.binary.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.up.zpb.controller.AbstractController;
import com.up.zpb.service.ShopPublishService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ResultException;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;

@RestController
@RequestMapping("publish")
public class ShopPublishController  extends AbstractController {

	private static final Logger logger = LoggerFactory.getLogger(ShopPublishController.class);
	
	@Autowired
	private ShopPublishService shopPublishService;

	/**
	 * 手机号查询是否可以发布商铺(当月小于3次可以发布)
	 * @param phone
	 * @param type 0:商铺出租 1:商铺转让 2:商铺求租
	 * @return
	 */
	@PostMapping("/auth/isPublish")
	public Map<String, Object> isPublish(HttpServletRequest request){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() 
				.put(parameters.get("cityId"), "cityId")
				.put(parameters.get("type"), "type").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopPublishService.getPublishCount(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 存储发布商铺信息
	 * @param cityId
	 * @param areaId
	 * @param businessAreaId
	 * @param address
	 * @param area
	 * @param monthlyRent
	 * @param transfee
	 * @param transfeeFlag
	 * @param linkMan
	 * @param imgs
	 * @param type
	 * @return
	 */
	@PostMapping("/auth/getPublishInfo")
	public Map<String, Object> getPublishInfo(HttpServletRequest request){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
		
				if(StringUtils.equals("2", parameters.get("type").toString())) {
					CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId")
					.put(parameters.get("areaId"), "areaId")
					.put(parameters.get("businessAreaId"), "businessAreaId")
					.put(parameters.get("areaUpper"), "areaUpper")
					.put(parameters.get("areaLower"), "areaLower")
					.put(parameters.get("linkMan"), "linkMan")
					.put(parameters.get("monthlyRentLower"), "monthlyRentLower")
					.put(parameters.get("monthlyRentUpper"), "monthlyRentUpper")
					.put(parameters.get("parentManageType"), "parentManageType")
					.put(parameters.get("sonManageType"), "sonManageType")
					.put(parameters.get("shopType"), "shopType")
					.put(parameters.get("type"), "type").checkParameter();
				}else {
					CheckParametersUtil.getInstance().put(parameters.get("cityId"), "cityId")
					.put(parameters.get("areaId"), "areaId")
					.put(parameters.get("businessAreaId"), "businessAreaId")
					.put(parameters.get("address"), "address")
					.put(parameters.get("monthlyRent"), "monthlyRent")
					.put(parameters.get("linkMan"), "linkMan")
					.put(parameters.get("imgs"), "imgs")
					.put(parameters.get("type"), "type").checkParameter();
				}
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopPublishService.createShop(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 获取发布页面下拉筛选值
	 * @param request
	 * @return
	 */
	@PostMapping("getAreas")
	public Map<String, Object> getAreas(HttpServletRequest request){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() 
				.put(parameters.get("cityId"), "cityId")
				.put(parameters.get("type"), "type").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopPublishService.getAreas(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
		
	}
	
	/**
	 * 获取发布列表
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/getPublishList")
	public Map<String, Object> getPublishList(HttpServletRequest request){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() 
				.put(parameters.get("pageSize"), "pageSize")
				.put(parameters.get("pageNum"), "pageNum")
				.put(parameters.get("cityId"), "cityId")
				.put(parameters.get("type"), "type").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopPublishService.getPublishList(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	/**
	 * 获取发布列表
	 * @param request
	 * @return
	 */
	@PostMapping("/auth/delShop")
	public Map<String, Object> delShop(HttpServletRequest request){
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() 
				.put(parameters.get("shopId"), "shopId")
				.put(parameters.get("type"), "type").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=shopPublishService.delShop(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
}
