package com.up.zpb.controller.api;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.controller.AbstractController;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.AreasService;
import com.up.zpb.service.ArticleService;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.ShowInfoService;
import com.up.zpb.util.CheckParametersUtil;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ResultException;
import com.up.zpb.util.ServletUtils;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;

@RestController
@RequestMapping("show")
public class ShowInfoController  extends AbstractController {

	
	private static final Logger logger = LoggerFactory.getLogger(ShowInfoController.class);
	@Autowired
	ShowInfoService showInfoService;
	@Autowired
	AreasService areaService;
	@Autowired
	private ArticleService articleService;
	@Autowired
	RedisBaseDao redisBaseDao;
	@Autowired
	private DictionaryService dictionaryService;
	
	
	
	
	/**
	 * 官网首页接口
	 * @param request
	 * 	cityId：所在城市
	 * @return
	 */
	@PostMapping("/showInfoPC")
	public ResultObject showInfoPC(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		String userAgent = request.getHeader("user-agent");
		logger.info("userAgent:{}", userAgent);
		Map<String,Object> parameters = ServletUtils.getParameters(request);
		logger.info("【showInfoPC()开始=========="+parameters+"】");
		try {
			//检测登录来源
			try {
				CheckParametersUtil.getInstance() .put(parameters.get("cityId"), "cityId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			String userType="1";
			UserApp loginUserEn=this.dictionaryService.getLoginUser(request);
			if(loginUserEn!=null && StringUtils.isNotEmpty(loginUserEn.getUserType()) && Integer.valueOf(loginUserEn.getUserType())>1 ){
				userType="2";
			}
			String indexKey=Constant.SHOW_INFO_PC + parameters.get("cityId").toString()+Constant.JOIN+userType;
			if(redisBaseDao.exists(indexKey)){
				resultObject.putAll(redisBaseDao.hMGetMap(indexKey));
			}else {
				parameters.put("userType", userType);
				resultObject=showInfoService.showInfoPC(parameters,indexKey);
			}
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【showInfoPC()结束=========="+resultObject+"】");
		return resultObject;
    } 
	
	
	/**
	 * 获取文章详情内容
	 * @param request
	 * 	titleId
	 * @return
	 */
	@PostMapping("/findArticeDetail")
	public ResultObject findArticeDetail(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() .put(parameters.get("titleId"), "titleId").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject=this.articleService.findArticeDetail(parameters);
		}  catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    }
	
	
	
	/**
	 * 官网获取文章列表分页展示
	 * @param request
	 * @return
	 */
	@PostMapping("findAticlePage")
	public Map<String, Object> findAticlePage(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() .put(parameters.get("pageSize"), "pageSize")
				.put(parameters.get("pageNum"), "pageNum")
				.put(parameters.get("cityId"), "cityId").checkParameter();
				
				parameters.put("userType", this.dictionaryService.getLoginUserType(request));
				parameters.put("adress",this.dictionaryService.getLoginChannel(request));
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
			Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			resultObject = articleService.getAticleList(parameters);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		logger.info("getAticleList end");
		return resultObject;
	}   


	/**
	 * 资讯右侧热门推荐
	 * @param request
	 * @return
	 */
	@PostMapping("findHotAticleList")
	public Map<String, Object> findHotAticleList(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> parameters = ServletUtils.getParameters(request);
			resultObject = articleService.findHotAticleList(parameters);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		} 
		return resultObject;
	} 
	
	
	/**
	 * 开通城市列表
	 * @return
	 */
	@PostMapping("/getOpenedCitiesList")
	public ResultObject getOpenedCitiesList(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			resultObject.put("data", areaService.selectOpenedCities());
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    } 
	
	/**
	 * 获取定位城市信息
	 * @return
	 *//*
	@PostMapping("/changeCity")
	public ResultObject changeCity(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() .put(parameters.get("cityName"), "cityName").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject= showInfoService.changeCity(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    } 
	
	/**
	 * 获取升级信息
	 * @return
	 */
	@PostMapping("/getUpgradeVersionInfo")
	public ResultObject getUpgradeVersionInfo(HttpServletRequest request) {
		ResultObject resultObject = new ResultObject();
		try {
			Map<String,Object> parameters = ServletUtils.getParameters(request);
			try {
				CheckParametersUtil.getInstance() .put(parameters.get("platform"), "platform").checkParameter();
			} catch (Exception e) {
				resultObject.setCode(Constant.CODE_PARAM_NULL);
				resultObject.setMessage(e.getMessage());
				logger.error(e.getMessage(), e);
				return resultObject;
			}
			resultObject= showInfoService.getUpgradeVersionInfo(parameters);
		} catch (ResultException e) {
			resultObject.setCode(e.getCode());
			resultObject.setMessage(e.getMessage());
			logger.error(e.getMessage(), e);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    }


	
	
}
