package com.up.zpb.service.impl;

import java.io.IOException;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;
import java.util.Objects;

import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alipay.api.AlipayApiException;
import com.google.common.collect.Maps;
import com.up.zpb.mapper.MemberOrderMapper;
import com.up.zpb.mapper.MemberServiceMapper;
import com.up.zpb.mapper.ProductMapper;
import com.up.zpb.pay.ali.AliPay;
import com.up.zpb.service.AliPayService;
import com.up.zpb.util.ConfigurationUtils;
import com.up.zpb.vo.MemberOrder;
import com.up.zpb.vo.Product;
import com.up.zpb.vo.ResultObject;

@Service
public class AliPayServiceImpl implements AliPayService{

	@Autowired
	MemberServiceMapper memberServiceMapper;
	
	@Autowired
	MemberOrderMapper memberOrderMapper;
	
	@Autowired
	ProductMapper productMapper;
	
	
	
	public final static String notifyUrl = ConfigurationUtils.getStringValue("ALI_NOTIFY_URL");
	public final static String appID = ConfigurationUtils.getStringValue("ALI_APP_ID");
	public final static String privateKey = ConfigurationUtils.getStringValue("ALI_APP_PRIVATE_KEY");
	public final static String publicKey = ConfigurationUtils.getStringValue("ALI_PAY_PUBLIC_KEY");
	public final static String returnUrl = ConfigurationUtils.getStringValue("ALI_H5_RETURN_URL");
	public final static String returnUrlPC = ConfigurationUtils.getStringValue("ALI_RETURN_URL");
	public final static String CHARSET = ConfigurationUtils.getStringValue("ALI_CHARSET");

	@Override
	public ResultObject aliPay(Map<String, Object> parameters) throws AlipayApiException {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> map = dealparameters(parameters);
		String orderNo = (String) map.get("orderNo");
		String subject = (String) map.get("subject");
		Double payAmount = (Double) map.get("payAmount");
		String appPay = AliPay.appPay(orderNo, subject, null, payAmount, notifyUrl, appID, privateKey, publicKey);
		resultObject.put("data", appPay);
		return resultObject;
	}

	//1、创建订单
	@Override
	public synchronized  MemberOrder createOrder(Integer memberId,Integer orderSource,Integer id,Double payAmount,
			Integer catgory,Integer productId,Integer cityId,String commissionNo) {
		MemberOrder mo = new MemberOrder();
		try {
			if(StringUtils.isNotEmpty(commissionNo)){
				//结佣订单
				mo.setOrderNo(commissionNo);
				mo.setOrderType(4);
			}else{
				mo.setOrderNo(getOrderNo(catgory,cityId));//订单号
			}
			mo.setUserId(memberId);//用户id
			mo.setOrderSource(orderSource);//订单来源
			mo.setOrderType(catgory);//会员类型
			mo.setOrderFee(BigDecimal.valueOf(payAmount));//订单金额
			mo.setStatus(0);//未支付
			mo.setCreateTime(new Date());
			mo.setProductId(productId);//产品id
			mo.setCityId(cityId);//市id
			memberOrderMapper.insertSelective(mo);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return mo;
	}

	@Override
	public ResultObject h5Pay(Map<String, Object> parameters) throws AlipayApiException {
		ResultObject resultObject = new ResultObject();	
		Map<String, Object> map = dealparameters(parameters);
		String orderNo = (String) map.get("orderNo");
		String subject = (String) map.get("subject");
		Double payAmount = (Double) map.get("payAmount");
		String h5Pay = AliPay.pageExecute(appID,privateKey,publicKey, orderNo,payAmount,subject,notifyUrl, returnUrl);
		resultObject.put("data", h5Pay);
		return resultObject;
	}
	
	/**
	 * 创建订单/获取已有订单
	 * @param parameters
	 * @return 订单编号、订单名称、订单金额
	 */
	public Map<String, Object> dealparameters(Map<String, Object> parameters) {
		Map<String, Object> map = Maps.newHashMap();
		//首次支付 id 二次支付 orderNo
		String orderNo =StringUtils.EMPTY;
		String subject = StringUtils.EMPTY;
		Integer catgory= 0;
		Double amount = null;
		if(Objects.isNull(parameters.get("orderNo")) && Objects.nonNull(parameters.get("id")) ) {
			ResultObject result = getPayAmount(parameters);
			System.out.println("qq "+result.get("amount"));
			amount =Double.valueOf(result.get("amount").toString());
			Product product = productMapper.selectProduct(parameters);
			catgory=product.getCatgory();
			Integer productId=product.getId();
			MemberOrder createOrder = createOrder(Integer.valueOf(parameters.get("authentication").toString()),Integer.valueOf(parameters.get("orderSource").toString()),
					Integer.valueOf(parameters.get("id").toString()),amount,catgory,productId,Integer.valueOf(parameters.get("cityId").toString()),null);
			orderNo=createOrder.getOrderNo();
		}else {
			orderNo=parameters.get("orderNo").toString();
			Map<String, Object> order = memberOrderMapper.selectByOrderNo(parameters);
			catgory= Integer.valueOf(order.get("catgory").toString());
			amount = Double.valueOf(order.get("amount").toString());
		}
		//0 品牌会员, 4 项目佣金
		if(0 == catgory) {
			subject="品牌会员服务费";
		}else {
			subject="CBMLS平台服务费";
		}
		map.put("orderNo", orderNo);
		map.put("subject", subject);
		map.put("payAmount", amount);
		return map;
	}
	
	public Double parseDouble(int val) {
		BigDecimal b = new BigDecimal(val);
		Double d = b.doubleValue();
		return d;
	}

	@Override
	public ResultObject getPayAmount(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		if(Objects.nonNull(parameters.get("id"))) {
			resultObject.put("amount", productMapper.selectById(parameters));
		}else if(Objects.nonNull(parameters.get("orderNo"))) {
			Map<String, Object> order = memberOrderMapper.selectByOrderNo(parameters);
			resultObject.put("amount", order.get("amount"));
		}
		return resultObject;
	}
	
	
	public String getOrderNo(Integer catgory,Integer cityId) {
		StringBuilder orderNo = new StringBuilder();
		//生成订单第一部分（订单类别）
		if(0== catgory|| 4==catgory) {
			orderNo.append("HY");
		}else if(3==catgory) {
			orderNo.append("ZD");
		}else {
			orderNo.append("VIP");
		}
		//生成订单第二部分（当前日期）
//		SimpleDateFormat sdf = new SimpleDateFormat("yyyMMdd");
//		Date d = new Date();
//		String dstr = sdf.format(d);
//		String orderNo2 = CodeGeneration.getOrderNo();
//		orderNo.append(orderNo2);
		
		//生成订单第二部分（当前日期）
		SimpleDateFormat sdf = new SimpleDateFormat("yyyMMdd");
		Date d = new Date();
		String dstr = sdf.format(d);
		orderNo.append(dstr);
		String id=cityId+"";
		orderNo.append(id);
		// 生成订单第三部分 （当天订单编号）
		DecimalFormat df = new DecimalFormat("0000");
		Integer i=memberOrderMapper.selectMemberOrderList(cityId);
		String newStr = df.format(i+1);
		orderNo.append(newStr);
		
		return orderNo.toString();
	}
	
//	public static void main(String[] args) {
//		String orderNo = getOrderNo(0);
//		System.out.println(orderNo);
//	}

	@Override
	public ResultObject aliPayPC(Map<String, Object> parameters,HttpServletResponse response) throws AlipayApiException {
		ResultObject resultObject = new ResultObject();	
		Map<String, Object> map = dealparameters(parameters);
		String orderNo = (String) map.get("orderNo");
		String subject = (String) map.get("subject");
		Double payAmount = (Double) map.get("payAmount");
		String aliPayPC = AliPay.pagePcExecute(appID, privateKey, publicKey, orderNo, payAmount, notifyUrl, returnUrlPC, subject);
		response.setContentType("text/html;charset=" + CHARSET);
		try {
			response.getWriter().write(aliPayPC);//直接将完整的表单html输出到页面
			response.getWriter().flush();
			response.getWriter().close();
		} catch (IOException e) {
			e.printStackTrace();
		}
		resultObject.put("data", aliPayPC);
		return resultObject;
	}

	@Override
	public ResultObject createPCOrder(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> map = dealparameters(parameters);
		String orderNo = (String) map.get("orderNo");
		resultObject.put("orderNo", orderNo);
		return resultObject;
	}

	@Override
	public ResultObject isPay(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		MemberOrder mo = memberOrderMapper.selectMemberOrderByOrderNo(parameters);
		Integer status = mo.getStatus();//0 未支付 1 已支付
		boolean isPay = false;//默认未支付
		if(1==status) {
			isPay=true;
		}
		resultObject.put("status", isPay);
		return resultObject;
	}
}
