package com.up.zpb.service.impl;

import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.up.zpb.mapper.AppEntrustMapper;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.BusinessAreaMapper;
import com.up.zpb.service.AppEntrustService;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.FourHundredService;
import com.up.zpb.util.Constant;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.fourhundred.IvrKeyShow;

@Service
public class AppEntrustServiceImpl implements AppEntrustService {

    private static final Logger logger = LoggerFactory.getLogger(AppEntrustServiceImpl.class);

    @Autowired
    private AppEntrustMapper appEntrustMapper;
    @Autowired
    private AreasMapper areasMapper;
    @Autowired
    private BusinessAreaMapper businessAreaMapper;
    @Autowired
    private DictionaryService dictionaryService;
    @Autowired
    private FourHundredService fourHundredService;

    @Override
    public ResultObject seekSelectPage(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        String area = StringUtils.EMPTY;
        String region = StringUtils.EMPTY;
        try {
            List<Map<String, Object>> mapList = appEntrustMapper.seekSelectPage(parameters);
            for (Map<String, Object> item : mapList) {
                if (String.valueOf(item.get("want_area")).contains(",")) {
                    area = areasMapper.selectById(String.valueOf(item.get("want_area")).substring(0, String.valueOf(item.get("want_area")).indexOf(",")));
                } else {
                    area = areasMapper.selectById(String.valueOf(item.get("want_area")));
                }
                if (String.valueOf(item.get("want_region")).contains(",")) {
                    region = businessAreaMapper.selectByIds(String.valueOf(item.get("want_region")).substring(0, String.valueOf(item.get("want_region")).indexOf(",")));
                } else {
                    region = businessAreaMapper.selectByIds(String.valueOf(item.get("want_region")));
                }
                item.put("want_area", area + "|" + region);
                item.remove("want_region");
                item.put("title",  area + region + item.get("d_name"));
                if (Integer.valueOf(item.get("type")+"") >= 3){
                    item.put("status","2");//商铺或者写字楼类型，前端做判断, 1写字楼 2商铺
                }else{
                    item.put("status","1");
                }
                item.remove("type");

            }
            resultObject.put("data", mapList);
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }

    }

    @Override
    public ResultObject getDetail(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        String area = StringUtils.EMPTY;
        String region = StringUtils.EMPTY;
        try {
            Map<String,Object> map = appEntrustMapper.getDetail(parameters);
            if (String.valueOf(map.get("want_area")).contains(",")) {
                area = areasMapper.selectById(String.valueOf(map.get("want_area")).substring(0, String.valueOf(map.get("want_area")).indexOf(",")));
            } else {
                area = areasMapper.selectById(String.valueOf(map.get("want_area")));
            }
            if (String.valueOf(map.get("want_region")).contains(",")) {
                region = businessAreaMapper.selectByIds(String.valueOf(map.get("want_region")).substring(0, String.valueOf(map.get("want_region")).indexOf(",")));
            } else {
                region = businessAreaMapper.selectByIds(String.valueOf(map.get("want_region")));
            }
            map.put("want_area", area + "|" + region);
            map.remove("want_region");
            map.put("title",  area + region + map.get("d_name"));
            //判断数据是求租还是求购
            map.put("seekType",Integer.valueOf(map.get("type")+"") > 3 ? 2 : 1);
            if (Integer.valueOf(map.get("type")+"") > 3){
                map.put("type",map.get("shopType"));
            }else{
                map.put("type",map.get("officeType"));
            }
            map.remove("officeType");
            map.remove("shopType");
            String sjType=this.dictionaryService.findByKey("549");
			if("2".equals(sjType)){
				//查找外显号
				IvrKeyShow ivrEn=this.fourHundredService.findIvrKeyShow(map.get("create_tel")+"");
				map.put("ivrType", ivrEn==null?"":ivrEn.getIvrType());
				map.put("ivrPhone", ivrEn==null?"":ivrEn.getIvrPhone());
				map.put("ivrKey", ivrEn==null?"":ivrEn.getIvrKey());
			}
            resultObject.put("data",map);
            return resultObject;
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

}
