package com.up.zpb.service.impl;

import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.up.zpb.controller.api.AppController;
import com.up.zpb.mapper.ArticleMapper;
import com.up.zpb.mapper.BannerMapper;
import com.up.zpb.mapper.ShopMapper;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.AppService;
import com.up.zpb.service.ShowInfoService;
import com.up.zpb.util.Constant;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.enums.OfficeEnum;
import com.up.zpb.vo.enums.ShopEnum;

@Service
@Transactional(propagation = Propagation.SUPPORTS)
public class AppServiceImpl implements AppService {

	private static final Logger logger = LoggerFactory.getLogger(AppController.class);
	@Autowired
	private ShopMapper shopMapper;
	@Autowired
	private BannerMapper bannerMapper;
	@Autowired
	private ShowInfoService showInfoService;
	@Autowired
	RedisBaseDao redisBaseDao;
	@Autowired
	private ArticleMapper articleMapper;
	
	@Override
	public ResultObject showInfoApp(Map<String, Object> parameters,String indexKey) {
		ResultObject resultObj = new ResultObject();
		try {
			
			//商业资讯
			parameters.put("limit", 6);
			parameters.put("top",2);
			parameters.put("adress","1");
			List<Map<String, Object>> kuaiXunList=articleMapper.getIndexAticleList(parameters);
			resultObj.put("articleInfo",kuaiXunList);
			
			//品牌列表
			parameters.put("type", "1");
			resultObj.put("bannerList", bannerMapper.selectBannerMapperPC(parameters));
			//房源发布数量+客源发布数量
			resultObj.put("houseNumber", this.shopMapper.sumIndexhouseNumber(parameters));
			resultObj.put("customerNumber", this.shopMapper.sumIndexCustomerNumber(parameters));
			
			//买商铺
			resultObj.put("shopSaleList",this.showInfoService.findShopList(parameters.get("cityId")+"", ShopEnum.RentType.SALE.getValue()));		
			//租商铺
			resultObj.put("shopRentList", this.showInfoService.findShopList(parameters.get("cityId")+"", ShopEnum.RentType.RENT.getValue()));
			//商业新盘出售
			resultObj.put("shopNewList", this.showInfoService.findShopList(parameters.get("cityId")+"", "-1"));
			
			
			//买写字楼
			resultObj.put("officeSaleList", this.showInfoService.findOfficeList(parameters.get("cityId")+"",OfficeEnum.TypeSale.SALE.getValue()));
			//租写字楼
			resultObj.put("officeRentList", this.showInfoService.findOfficeList(parameters.get("cityId")+"",OfficeEnum.TypeSale.RENT.getValue()));
			//写字楼新盘出售
			resultObj.put("officeNewList", this.showInfoService.findOfficeList(parameters.get("cityId")+"", "-1"));
		
			redisBaseDao.hMSet(indexKey, resultObj);
			redisBaseDao.expire(indexKey,Constant.CACHE_EXP_ONE_HOUR);	
		} catch (Exception e) {
			resultObj.setCode(Constant.CODE_EXCEPTION);
			resultObj.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		//放入缓存
		redisBaseDao.hMSet(Constant.SHOW_INFO_APP + parameters.get("cityId").toString(), resultObj);
		//指定过期时间
		redisBaseDao.expire(Constant.SHOW_INFO_APP + parameters.get("cityId").toString(), 60*5);	
		return resultObj;
	}
	
	
	
	
	
	
	
	
}

	
