/**
 * 
 */
package com.up.zpb.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.up.zpb.annotation.Cacheable;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.RegionsMapper;
import com.up.zpb.mapper.SysCompanyMapper;
import com.up.zpb.service.AreasService;


/**
 * @author zmg
 *
 */
@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class AreasServiceImpl implements AreasService {

	private static final Logger logger = LoggerFactory.getLogger(AreasServiceImpl.class);
	
	@Autowired
	private AreasMapper areasMapper;
	@Autowired
	private RegionsMapper regionsMapper;
	
	@Autowired
	private SysCompanyMapper sysCompanyMapper;
	
	@Override
	@Cacheable(expireTime=60*60)
	public List<Map<String,Object>> selectByParentId(String parentid) {
		return areasMapper.selectByParentId(parentid);
	}
	
	/**
	 * 区域不带“全部”
	 */
	@Override
	@Cacheable(expireTime=60*60)
	public List<Map<String,Object>> selectAreasNoQuanBu(String parentid) {
		List<Map<String,Object>> parentList = areasMapper.selectByParentId(parentid);
		parentList.remove(0);
		return parentList;
	}
	
	
	@Override
	public List<Map<String,Object>> selectOpenedCities() {
		return sysCompanyMapper.selectOpenedCities();
	}
	
	
	@Override
	public List<Map<String,Object>> findRegionsListApp() {
		List<Map<String,Object>> parentList = regionsMapper.findRegionsList();
		if(parentList!=null && parentList.size()>0){
			for(Map<String,Object> temp : parentList) {
				String pid=temp.get("id")+"";
				if(StringUtils.isEmpty(pid)){
					pid="-1";//当父级为全部，子集有且仅有一个节点叫“全部”
				}
				List<Map<String,Object>> aList = areasMapper.findAreaByRid(pid);
				for(Map<String,Object> chilTemp:aList){
					if("全部".equals(chilTemp.get("area_name")+"")){
						chilTemp.put("id", pid);
					}
				}
				temp.put("childrenList", aList);
			}
		}
		return parentList;
	}
	
	
	@Override
	public List<Map<String,Object>> findBrandYeTaiList() {
		Map<String,Object> pMap=new HashMap<String,Object>();
		pMap.put("brandTypeLevel", "1");
		List<Map<String,Object>> parentList = areasMapper.findYeTaiByPid(pMap);
		if(parentList!=null && parentList.size()>0){
			for(Map<String,Object> temp : parentList) {
				//二级
				String pid=temp.get("id")+"";
				if(StringUtils.isEmpty(pid)){
					pid="-1";//当父级为全部，子集有且仅有一个节点叫“全部”
				}
				Map<String,Object> cMap=new HashMap<String,Object>();
				cMap.put("pid", pid);
				cMap.put("brandTypeLevel", "2");
				List<Map<String,Object>> aList = areasMapper.findYeTaiByPid(cMap);
				temp.put("childrenList", aList);
			}
		}
		return parentList;
	}
	
	@Override
	public List<Map<String,Object>> findBrandYeTaiListApp() {
		Map<String,Object> pMap=new HashMap<String,Object>();
		pMap.put("brandTypeLevel", "1");
		List<Map<String,Object>> parentList = areasMapper.findYeTaiByPid(pMap);
		if(parentList!=null && parentList.size()>0){
			for(Map<String,Object> temp : parentList) {
				//二级
				String pid=temp.get("id")+"";
				if(StringUtils.isEmpty(pid)){
					pid="-1";//当父级为全部，子集有且仅有一个节点叫“全部”
				}
				Map<String,Object> cMap=new HashMap<String,Object>();
				cMap.put("pid", pid);
				cMap.put("brandTypeLevel", "2");
				List<Map<String,Object>> aList = areasMapper.findYeTaiByPid(cMap);
				for(Map<String,Object> chilItem:aList){
					if("全部".equals(chilItem.get("name")+"")){
						chilItem.put("id", pid);
					}
				}
				temp.put("childrenList", aList);
			}
		}
		return parentList;
	}
	
}
