/**
 * 
 */
package com.up.zpb.service.impl;

import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.up.zpb.annotation.Cacheable;
import com.up.zpb.mapper.ArticleMapper;
import com.up.zpb.mapper.BrandMapper;
import com.up.zpb.service.ArticleService;
import com.up.zpb.util.ConfigurationUtils;
import com.up.zpb.util.Constant;
import com.up.zpb.vo.OneHandShop;
import com.up.zpb.vo.ResultObject;

/**
 * 
 * @author gust
 *
 */
@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class ArticleServiceImpl implements ArticleService {

	private static final Logger logger = LoggerFactory.getLogger(ArticleServiceImpl.class);
	public final static String img = ConfigurationUtils.getStringValue("img_domain");
	@Autowired
	private ArticleMapper articleMapper;
	@Autowired
	private BrandMapper brandMapper;
	
	/**
	 * 资讯推荐到首页
	 * 1-商业快讯 2-热点人物 3-行业活动 4-商业专题 5-商业数据
	 */
	@Override
	public ResultObject findArticleIndex(Map<String, Object> parameters) {
		ResultObject  resultObject=new ResultObject();
		parameters.put("top",2);
		parameters.put("limit", 5);
		try {
			parameters.put("type",1);
			List<Map<String, Object>> kuaiXunList=articleMapper.getIndexAticleList(parameters);
			resultObject.put("kuaiXunList", kuaiXunList);
			
			parameters.put("type",2);
			List<Map<String, Object>> reDianList=articleMapper.getIndexAticleList(parameters);
			resultObject.put("reDianList", reDianList);
			
			parameters.put("type",3);
			List<Map<String, Object>> hangYeList=articleMapper.getIndexAticleList(parameters);
			resultObject.put("hangYeList", hangYeList);
			
			parameters.put("type",4);
			List<Map<String, Object>> zhuanTiList=articleMapper.getIndexAticleList(parameters);
			resultObject.put("zhuanTiList", zhuanTiList);
			
			parameters.put("type",5);
			List<Map<String, Object>> shuJuList=articleMapper.getIndexAticleList(parameters);
			resultObject.put("shuJuList", shuJuList);
		}  catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    }
	

	
	@Override
	public ResultObject getAticleList(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		parameters.put("img", img);
		resultObject.put("articleList", articleMapper.getAticleList(parameters));
		return resultObject;
	}
	
	
	@Override
	public ResultObject findArticeDetail(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		try {
			this.articleMapper.updateViews(parameters.get("titleId")+"");
			Map<String, Object> enitty=articleMapper.selectDetailById(parameters);
			resultObject.put("article", enitty);
			
			//推荐商铺
			parameters.put("limit", 4);
			parameters.put("cityId", enitty.get("city_id"));
			List<OneHandShop> one=this.articleMapper.selectOneHandShop(parameters);
			resultObject.put("shopNewList", one);
			List<OneHandShop> two=this.articleMapper.selectTwoHandShop(parameters);
			resultObject.put("shopTwoList", two);
			//推荐品牌
			parameters.put("limit", 3);
			List<Map<String, Object>> brandList = brandMapper.getHotBrandList(parameters);
			resultObject.put("brandList", brandList);
		}  catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    }


	@Override
	@Cacheable(expireTime=60*60)
	public ResultObject findHotAticleList(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		try {
			//推荐商铺
			parameters.put("limit", 4);
			List<OneHandShop> one=this.articleMapper.selectOneHandShop(parameters);
			resultObject.put("shopNewList", one);
			List<OneHandShop> two=this.articleMapper.selectTwoHandShop(parameters);
			resultObject.put("shopTwoList", two);
		}  catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
    }



}
