package com.up.zpb.service.impl;

import java.util.Date;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.up.zpb.mapper.UserLoginLogMapper;
import com.up.zpb.mapper.UserRegisterLogMapper;
import com.up.zpb.service.AsyncLoginLogService;
import com.up.zpb.util.CodeGeneration;
import com.up.zpb.util.IpAddressUtils;
import com.up.zpb.vo.UserLoginLog;
import com.up.zpb.vo.UserRegisterLog;

/** 
 * @author SJLv587
 * @version 2018年3月26日 上午11:20:41 
 */
@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class AsyncLoginLogServiceImpl implements AsyncLoginLogService {
	
	private static final Logger logger = LoggerFactory.getLogger(AsyncLoginLogServiceImpl.class);
	
	@Autowired
	UserRegisterLogMapper userRegisterLogMapper;
	
	@Autowired
	UserLoginLogMapper userLoginLogMapper;

	@Async
	public void saveUserRegisterLog(UserRegisterLog userRegisterLog) {
		try {
		Map<String, String> address = IpAddressUtils.getAddress(userRegisterLog.getIpAddress(), "utf-8");
		userRegisterLog.setCreateTime(new Date());
		userRegisterLog.setCountry(address.get("country"));
		userRegisterLog.setCountryId(address.get("countryId"));
		userRegisterLog.setArea(address.get("area"));
		userRegisterLog.setAreaId(address.get("areaId"));
		userRegisterLog.setRegion(address.get("region"));
		userRegisterLog.setRegionId(address.get("regionId"));
		userRegisterLog.setCounty(address.get("county"));
		userRegisterLog.setCountyId(address.get("countyId"));
		userRegisterLog.setIsp(address.get("isp"));
		userRegisterLog.setIspId(address.get("ispId"));
		userRegisterLog.setCity(address.get("city"));
		userRegisterLog.setCityId(address.get("cityId"));
		userRegisterLogMapper.insertSelective(userRegisterLog);
	} catch (Exception e) {
		logger.error(e.getMessage(), e);
	}
	}

	@Async
	public void saveUserLoginLog(UserLoginLog userLoginLog) {
		try {
			Map<String, String> address = IpAddressUtils.getAddress(userLoginLog.getIpAddress(), "utf-8");
			userLoginLog.setCreateTime(new Date());
			userLoginLog.setId(CodeGeneration.getID());
			userLoginLog.setCountry(address.get("country"));
			userLoginLog.setCountryId(address.get("countryId"));
			userLoginLog.setArea(address.get("area"));
			userLoginLog.setAreaId(address.get("areaId"));
			userLoginLog.setRegion(address.get("region"));
			userLoginLog.setRegionId(address.get("regionId"));
			userLoginLog.setCounty(address.get("county"));
			userLoginLog.setCountyId(address.get("countyId"));
			userLoginLog.setIsp(address.get("isp"));
			userLoginLog.setIspId(address.get("ispId"));
			userLoginLog.setCity(address.get("city"));
			userLoginLog.setCityId(address.get("cityId"));
			userLoginLogMapper.insertSelective(userLoginLog);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
	}
}
