package com.up.zpb.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.annotation.Cacheable;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.BrandContactsErrorAreaMapper;
import com.up.zpb.mapper.BrandContactsErrorMapper;
import com.up.zpb.mapper.BrandMapper;
import com.up.zpb.mapper.DictionaryMapper;
import com.up.zpb.mapper.PhoneRecordMapper;
import com.up.zpb.service.BrandService;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.vo.Brand;
import com.up.zpb.vo.BrandBrandArea;
import com.up.zpb.vo.BrandContactsError;
import com.up.zpb.vo.BrandContactsErrorArea;
import com.up.zpb.vo.BrandLinkman;
import com.up.zpb.vo.BrandLinkmanShow;
import com.up.zpb.vo.PhoneRecord;
import com.up.zpb.vo.ResultObject;

/**
 * 品牌服务类
 * @author PJJ
 *
 */
@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class BrandServiceImpl implements BrandService {


	private static final Logger logger = LoggerFactory.getLogger(BrandServiceImpl.class);
	
	/*@Autowired
	private BrandBusinessMapper brandBusinessMapper;*/
	@Autowired
	private BrandMapper brandMapper;
	@Autowired
	private BrandContactsErrorMapper brandContactsErrorMapper;
	@Autowired
	private BrandContactsErrorAreaMapper brandContactsErrorAreaMapper;
	@Autowired
	private AreasMapper areasMapper;
	@Autowired
	private DictionaryService  dictionaryService;
	@Autowired
	private PhoneRecordMapper phoneRecordMapper;
	
	
	/**
	 * 初始化品牌业态等下拉框选项
	 * @param isAll
	 * @return
	 */
	@Override
	@Cacheable(expireTime=60*60*24)
	public List<Map<String,Object>> getBrandBusinessList() {
		List<Map<String,Object>> selectLevelOne=new ArrayList<Map<String,Object>>();
		//一级
		Map<String,Object> pMap=new HashMap<String,Object>();
		pMap.put("brandTypeLevel", "1");
		List<Map<String,Object>> parentList = areasMapper.findYeTaiByPid(pMap);
		if(parentList!=null && parentList.size()>0){
			for(Map<String,Object> temp : parentList) {
				Map<String,Object> oneEn=new HashMap<String,Object>();
				oneEn.put("id", temp.get("id")+"");
				oneEn.put("businessName", temp.get("name"));
				
				//二级
				List<Map<String,Object>> selectLevelTwo=new ArrayList<Map<String,Object>>();
				Map<String,Object> cMap=new HashMap<String,Object>();
				cMap.put("pid", temp.get("id")+"");
				cMap.put("brandTypeLevel", "2");
				List<Map<String,Object>> childList = areasMapper.findYeTaiByPid(cMap);
				for(Map<String,Object> chilItem:childList){
					Map<String,Object> twoEn=new HashMap<String,Object>();
					twoEn.put("id", chilItem.get("id")+"");
					twoEn.put("p_id", temp.get("id")+"");
					twoEn.put("businessName", chilItem.get("name"));
					if(!"全部".equals(twoEn.get("businessName")+"")){
						selectLevelTwo.add(twoEn);
					}
				}
				oneEn.put("levelTwoList", selectLevelTwo);
				if(!"全部".equals(oneEn.get("businessName")+"")){
					selectLevelOne.add(oneEn);
				}
			}
		}
		return selectLevelOne;
	}
	

	/**
	 * 我要成为品牌联系人
	 */
	@Override
	@Transactional(propagation=Propagation.REQUIRED)
	public void createContact(BrandLinkman entity) {
		entity.setName(entity.getUserName());
		entity.setPhone(entity.getMobile());
		entity.setBrandId(Integer.valueOf(entity.getBrandDatabaseId()));
		entity.setLinkAreasKey(entity.getBrandContactsArea());
		//区域汉字
		String[] aKey=entity.getBrandContactsArea().split(";");
		String cityStrAll="";
		for(String a:aKey){
			String cityStr=this.findCityName(a.split("-")[1]);
			cityStrAll=cityStrAll+cityStr+",";
		}
		entity .setLinkAreas(cityStrAll==null?"北京":cityStrAll);
		entity.setDuty(this.dictionaryService.selectByDValue("546", entity.getPost()));
		this.brandMapper.saveLinkman(entity);
	}
	/**
	 * 品牌联系人纠错
	 * @param brandContactsError
	 */
	@Override
	@Transactional(propagation=Propagation.REQUIRED)
	public void createContactError(BrandContactsError brandContactsError) {
		brandContactsError.setCreateTime(new Date());
		brandContactsError.setFlag(1);
		this.brandContactsErrorMapper.insertSelective(brandContactsError);
		for(BrandContactsErrorArea brandContactsErrorArea : brandContactsError.getBrandContactsErrorAreaList()) {
			brandContactsErrorArea.setBrandContactsErrorId(brandContactsError.getId());
			this.brandContactsErrorAreaMapper.insertSelective(brandContactsErrorArea);
		}
	}
	
	
	/**
	 * 发布品牌
	 */
	@Override
	@Transactional(propagation=Propagation.REQUIRED)
	public ResultObject publishBrand(Brand entity) {
		ResultObject resultObject = new ResultObject();
		try {
			entity.setName(entity.getBrandName());
			entity.setImgPath(entity.getLogo());
			if(!ObjectHelpUtils.isMyNull(entity.getBrandPositioning())){
				String position=this.dictionaryService.selectByDValue("123", entity.getBrandPositioning());
				entity.setPosition(position);
			}
			resultObject = this.valideBrandName(entity.getName());
			String status = resultObject.get("status").toString();
			if (StringUtils.equals("false", status)) {
				return resultObject;
			}

			//业态一二级
			if (StringUtils.isNotBlank(entity.getBrandBusiness())) {
				String[] bbs = StringUtils.split(entity.getBrandBusiness(), "-");
				if (StringUtils.isNotBlank(bbs[0])) {
					entity.setBrandTypeId(Integer.valueOf(bbs[0]));
				}
				if (bbs.length > 1 && StringUtils.isNotBlank(bbs[1])) {
					entity.setBrandTypeTwo(Integer.valueOf(bbs[1]));
				}
			}
			this.brandMapper.saveBrandEntity(entity);
			Integer brandId=entity.getId();

			//拓展区域 brand_area; eg:[东北id-黑龙江id;华北id-北京id;]
			if (StringUtils.isNotBlank(entity.getBrandContactsArea())) {
				String[] beas = StringUtils.split(entity.getBrandContactsArea(), ";");
				for (String bea : beas) {
					String[] rp = StringUtils.split(bea, "-");
					BrandBrandArea bbA = new BrandBrandArea();
					Integer dongbeiId=Integer.valueOf(rp[0]);//东北
					Integer provinceId=Integer.valueOf(rp[1]);//省份
					bbA.setBrandAreaId(provinceId);
					bbA.setBrandId(brandId);
					this.brandMapper.saveBrandBrandArea(bbA);
				}
			}
			
			//联系人1 brand_linkman
			if (StringUtils.isNotBlank(entity.getMobile1()) && StringUtils.isNotBlank(entity.getBrandContactsArea1())) {
					BrandLinkman man = new BrandLinkman();
					man.setLinkAreasKey(entity.getBrandContactsArea1());//编码
					//区域汉字
					String cityStrAll="";
					String[] aKey=entity.getBrandContactsArea().split(";");
					for(String a:aKey){
						String cityStr=this.findCityName(a.split("-")[1]);
						cityStrAll=cityStrAll+cityStr+",";
					}
					man.setLinkAreas(cityStrAll);//汉字
					man.setName(entity.getUserName1());
					man.setPhone(entity.getMobile1());
					man.setDuty(this.dictionaryService.selectByDValue("546", entity.getPost1()));
					man.setBrandId(entity.getId());
					man.setCreateBy(Integer.valueOf(entity.getCreateBy()));
					this.brandMapper.saveLinkman(man);
			}
			
			//联系人2
			if (StringUtils.isNotBlank(entity.getMobile2()) && StringUtils.isNotBlank(entity.getBrandContactsArea2())) {
					BrandLinkman man = new BrandLinkman();
					man.setLinkAreasKey(entity.getBrandContactsArea2());//编码
					//区域汉字
					String cityStrAll="";
					String[] aKey=entity.getBrandContactsArea().split(";");
					for(String a:aKey){
						String cityStr=this.findCityName(a.split("-")[1]);
						cityStrAll=cityStrAll+cityStr+",";
					}
					man.setLinkAreas(cityStrAll);//汉字
					man.setPhone(entity.getMobile2());
					man.setName(entity.getUserName2());
					man.setBrandId(entity.getId());
					man.setDuty(this.dictionaryService.selectByDValue("546", entity.getPost2()));
					man.setCreateBy(Integer.valueOf(entity.getCreateBy()));
					this.brandMapper.saveLinkman(man);
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	

	public ResultObject valideBrandName(String brandName) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> parameters = new HashMap<String, Object>();
		parameters.put("brandName", brandName);
		int count = this.brandMapper.valideBrandName(parameters);
		if(count!=0) {
			resultObject.put("status", false);
		}else {
			resultObject.put("status", true);
		}
		return resultObject;
	}
	
	
	/**
	 * 回显经纪人负责品牌的区域信息
	 * @param brandLinkmanId 对应brand_linkman表主键
	 * @param memberId
	 * @return
	 */
	@Override
	public ResultObject getContactError(Integer brandLinkmanId, Integer loginUserId) {
		ResultObject resultObject = new ResultObject();
		try {
			BrandLinkmanShow entity=new BrandLinkmanShow();
			//经纪人信息
			BrandLinkman  manEn=this.brandMapper.findLinkmanEntityById(brandLinkmanId+"");
			if(manEn==null){
				resultObject.setCode(Constant.CODE_EXCEPTION);
				resultObject.setMessage("联系人ID-brandLinkmanId["+brandLinkmanId+"]有误，查无数据");
				return resultObject;
			}
			Map<String,Object> pMap=new HashMap<String,Object>();
			pMap.put("userId", loginUserId);
			pMap.put("brandId", manEn.getBrandId());
			pMap.put("phone", manEn.getPhone());
			//当前登录人对这个经纪人的联系次数(当前登录用户-品牌id-经纪人手机号)
			PhoneRecord  phoneEn=this.phoneRecordMapper.findEntity(pMap);
			if(phoneEn !=null && manEn!=null) {
				//查看过联系人电话-可以回显
				entity.setFlag("true");
				entity.setMobile(manEn.getPhone());//电话
				entity.setPost(manEn.getDuty());//职位-数字
				entity.setPost_text(this.dictionaryService.selectByDValue("546", manEn.getDuty()));//职位-汉字
				String linkAreasKey=manEn.getLinkAreasKey();
				if( !ObjectHelpUtils.isMyNull(linkAreasKey)){
					if(",".equals(linkAreasKey.substring(linkAreasKey.length()-1, linkAreasKey.length())) ){
						linkAreasKey=linkAreasKey.substring(0,linkAreasKey.length()-1);
					}else{
						entity.setBrandContactsArea(linkAreasKey);//区域-数字
					}
				}
				entity.setBrandContactsArea_text(manEn.getLinkAreas());//区域-汉字
				entity.setUser_name(manEn.getName());//名称
				//处理导过来的数据，区域汉字有，区域数字没有
				if(StringUtils.isBlank(entity.getBrandContactsArea()) && !StringUtils.isBlank(entity.getBrandContactsArea_text())){
					String areaCode="";
					String[] cityNameArr=entity.getBrandContactsArea_text().split(",");
					for(String cityName:cityNameArr){
						String cityId=this.findCityIdByCityName(cityName);
						String cityIdStr="1-"+cityId;
						areaCode=areaCode+cityIdStr+";";
					}
					areaCode=areaCode.substring(0, areaCode.length()-1);//去掉最后一个逗号
					entity.setBrandContactsArea(areaCode);
				}
			}
			resultObject.put("entity", entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Cacheable(expireTime=60*60*24)
	public String findCityName(String cityId){
		return this.brandMapper.findCityNameByCityId(cityId);
	}
	@Cacheable(expireTime=60*60*24)
	public String findCityIdByCityName(String cityName){
		return this.brandMapper.findCityIdByCityName(cityName);
	}
	
	
	@Override
	public ResultObject findMyPublishBrand(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		List<String> statusList=new ArrayList<>();
		statusList.add("其他");//1-待审核；2-已审核；3-未通过审核
		statusList.add("审核中");
		statusList.add("审核成功");
		statusList.add("审核失败");
		try {
			List<Map<String, Object>> brandList = brandMapper.findMyPublishBrand(parameters);
			if(brandList !=null && brandList.size()>0){
				for(Map<String,Object> temp:brandList){
					//审核状态
					temp.put("isError", temp.get("audit_status"));
					temp.put("isErrorText", statusList.get(Integer.valueOf(temp.get("audit_status")+"")));
					temp.put("reasons",  temp.get("reasons")+"");
				}
			}
			resultObject.put("brandList", brandList);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	
	
}
