package com.up.zpb.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Lists;
import com.up.zpb.hz.exception.DefineException;
import com.up.zpb.hz.helper.*;
import com.up.zpb.mapper.ContractMapper;
import com.up.zpb.mapper.UserMapper;
import com.up.zpb.service.ContractService;
import com.up.zpb.util.Constant;
import com.up.zpb.vo.Contract;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;


/**
 * @author liuwei
 */
@Service
public class ContractServiceImpl implements ContractService {

    private static final Logger LOGGER = LoggerFactory.getLogger(ContractServiceImpl.class);


    @Autowired
    private ContractMapper contractMapper;
    @Autowired
    private UserMapper userMapper;


    /**
     * 满足E签宝业务需求，要求个人与公司都具有唯一不可重复标识
     * 个人标识使用userAppId     公司标识使用userAppId+“corp”
     */
    private static final String CORP = "corp";
    /**
     * 合同上 本公司使用印章ID
     * 在E签宝 顶部导航栏 用户中心下
     * 左侧导航栏 印章管理 中  印章编号
     */
    private static final String CORPORATESEALID = "f6df11b8-5401-48f4-8791-6f8c32e38948";

    /**
     * E签宝图形管理界面中，企业模板中，如果是正在使用中的模板需要先停止使用
     * 然后设置模板  控件设置中左上角  文件列表后有个 小图标，复制文件标识 点击复制模板ID
     * 模板Id
     */
    private static final String TEMPLATE = "9bc50fdeb79a48baa2c8fe61b7e92b97";

    /**
     * 认证成功回调地址
     * 创建认证流程的时候填写
     */
    private static final String APPROVE_CALLBACK = "http://39.106.34.107:8081/contract/approveCallBack";


    /**
     * 签署成功回调地址
     * 创建签署流程的时候设置
     */
    private static final String SIGN_CALLBACK = "http://39.106.34.107:8081/contract/signCallBack";

    /**
     * APP 签署成功回调地址
     */
    private static final String REDIRECTURL = "https://www.baidu.com";

    /**
     * 合同签署底部甲方名称
     */
    private static final String PARTYNAME = "北京优铺网络科技有限公司";

    @Override
    public Contract selectByPrimaryKey(Integer userAppId) {
        return contractMapper.selectByPrimaryKey(userAppId);
    }

    @Override
    public int replaceFallClient(Contract contract) {
        return contractMapper.replaceFallClient(contract);
    }

    @Override
    public int deleteByUserAppId(Integer userAppId) {
        return contractMapper.deleteByUserAppId(userAppId);
    }

    @Override
    public List<Contract> selectAll() {
        return contractMapper.selectAll();
    }

    @Override
    public void updateByPrimaryKeySelective(Contract contract) {
        contractMapper.updateByPrimaryKeySelective(contract);
    }

    @Override
    public void insertSelective(Contract contract) {
        contractMapper.insertSelective(contract);
    }

    @Override
    public int approveCallBack(Contract contract) {
        int i = contractMapper.approveCallBack(contract);
        return i;
    }

    /**
     * 获取用户的认证、签署地址
     *
     *          姓名 name
     *          身份证号  idNumber
     *
     *          单位名称  companyName
     *          单位证件号 companyNumber
     *
     *          企业法人证件号  orgLegalIdNumber
     *          企业法人名称    orgLegalNamee
     * @return
     * @throws DefineException
     */
    @Override
    public ResultObject contractStart(Map<String, Object> parameters){

        try {
            //参数处理
            Integer userAppId = Integer.parseInt(parameters.get("userAppId") + "");
            Integer origin = Integer.parseInt(parameters.get("origin") + "");

            String name = parameters.get("name") + "";
            String idNumber = parameters.get("idNumber") + "";

            String companyName = parameters.get("companyName") + "";
            String companyNumber = parameters.get("companyNumber") + "";

            String orgLegalIdNumber = parameters.get("orgLegalIdNumber") + "";
            String orgLegalName = parameters.get("orgLegalName") + "";

            LOGGER.info("---------------------获取token start------------------------------");
            TokenHelper.getTokenData();

            //结果集
            ResultObject resultObject = new ResultObject();

            //根据当前登录用户查询用户信息  获取本平台个人信息与E签宝交互  主要使用Id（唯一表示） 个人名称与企业名称
            //如果在创建个人账号的时候 填写mobile参数，在创建签署流程的时候会自动向参数手机号 发送邀请签署信息
            UserApp userApp = userMapper.selectById(userAppId);

            //满足 拒签、用户姓名填写错误业务需求
            delLocalUserInfo(userAppId,userApp.getUserType());

            //生成E签宝账号
            String acctId = "";
            String orgId = "";
            try {
                LOGGER.info("---------------------创建个人账号start-------------------------------");
                JSONObject personAcctJson = AccountHelper.createPersonAcct(String.valueOf(userApp.getId())+"T", name == null || name.equals("null") || name.equals("") ? orgLegalName : name, null, idNumber == null || idNumber.equals("null") || idNumber.equals("") ? orgLegalIdNumber : idNumber, null, null);
                //获取创建临时账号的E 签宝系统唯一标识
                acctId = personAcctJson.getString("accountId");

                //判断如果是企业，创建企业待认证账号
                if(userApp.getUserType().equals("3")){
                      LOGGER.info("---------------------创建机构账号start----------------------------------");
                      JSONObject orgAcctJson = AccountHelper.createOrgAcct(userApp.getId()+CORP, acctId, companyName == null || companyName.equals("null") || companyName.equals("") ? userApp.getCorporateName() : companyName, null, companyNumber,orgLegalIdNumber,orgLegalName);
                      orgId += orgAcctJson.getString("orgId");

                      LOGGER.info("---------------------创建机构印章start----------------------------------");
                      SealHelper.createOrgTemplateSeal(orgId, StringUtils.isEmpty(companyName) ? userApp.getCorporateName() : companyName, "RED", null, null, null, null, "TEMPLATE_ROUND", "STAR");
                }
            } catch (DefineException e) {
                LOGGER.error("创建个人账号或机构账号失败！请检查个人或企业信息",e);
                ResultObject error = new ResultObject();
                error.setCode(Constant.CODE_EXCEPTION);
                error.setMessage("创建个人账号或机构账号失败！请检查个人或企业信息");
                return error;
            }

            //获取模板，填充模板数据，生成签署连接
            String flowId = "";
            String qianshuURL = "";
            String longUrl = "";
            try {
                LOGGER.info("---------------------通过模板创建文件 start---------------------------------");
                String fileId = buildFile(userApp,name,companyName);

                LOGGER.info("---------------------签署流程创建 start---------------------------------");
                //可通过SignParamUtil.createSignFlowStart()进行组装入参，具体使用中根据实际情况传参
                JSONObject flowJson = SignHelper.createSignFlow(SIGN_CALLBACK,"中国商办联卖联租平台信息服务协议",origin == 2?REDIRECTURL:null);
                flowId = flowJson.getString("flowId");

                LOGGER.info("---------------------流程文档添加 start---------------------------------");
                SignHelper.addFlowDoc(flowId, fileId);

                LOGGER.info("---------------------添加平台自动盖章签署区 start---------------------------");
                SignHelper.addPlatformAutoSignArea(flowId, Lists.newArrayList(fileId), Lists.newArrayList(CORPORATESEALID));

                //添加第三方签署盖章区域
                addSingArea(userApp.getUserType(),flowId,fileId,acctId,orgId);

                LOGGER.info("---------------------签署流程开启 start-----------------------------");
                SignHelper.startSignFlow(flowId);
                LOGGER.info("---------------------获取签署连接 start-----------------------------");
                JSONObject jsonObject1 = SignHelper.qrySignUrl(flowId, acctId, orgId.equals("") ? null : orgId, null);
                qianshuURL = jsonObject1.getString("shortUrl");
                longUrl = jsonObject1.getString("url");
            } catch (DefineException e) {
                LOGGER.error("创建模板流程失败！",e);
                ResultObject error = new ResultObject();
                error.setCode(Constant.CODE_EXCEPTION);
                error.setMessage("创建模板流程失败！");
                return error;
            }

            //ios需要
            if(origin.equals(2)){ //ios
                qianshuURL += "?esignAppSchem=common://close";
            }

            //调起认证
            Contract contract = identity(userApp.getUserType(), userAppId, orgId, acctId, null, qianshuURL);
            String identityUrl = contract.getIdentityUrl();
            resultObject.put("url",identityUrl);

            //存储用户信息
            contract.setUserAppId(userAppId);
            contract.setFlowId(flowId);
            contract.setAccountId(acctId);
            contract.setShortUrl(longUrl);
            contract.setOrgId(orgId);

            contractMapper.insertSelective(contract);

            return resultObject;
        } catch (Exception e) {
            ResultObject error = new ResultObject();
            error.setCode(Constant.CODE_EXCEPTION);
            error.setMessage("系统异常");
            return error;
        }
    }


    /**
     * @param userAppId
     * @return
     *
     *  状态说明
     *  0 ：没有认证签署过，调用接口获取认证签署地址
     *  1 ：认证签署成功
     *  2 ：认证签署接口以请求过，但认证或签署状态意外终止，有认证地址和签署地址，根据状态返回当前进度对应的url
     *
    */
    @Override
    public Map<String,Object> selectApproveStatus(Integer userAppId) throws DefineException {
        HashMap<String, Object> map = new HashMap<>();
        map.put("status","0");
        map.put("url",null);
        UserApp userApp = userMapper.selectById(userAppId);

        //如果该用户是公司旗下的，直接查询公司是否签署
        Contract contract = contractMapper.selectApproveStatus(userApp.getParentId() > 0 ? userApp.getParentId() : userAppId);
        if(Objects.isNull(contract)){
            return map;
        }
        if(contract.getApproveStatus().equals(1) && contract.getSignStatus().equals(2)){
            map.put("status","1");
            map.put("url",null);
            return map;
        }
        if(contract.getApproveStatus().equals(1) && contract.getSignStatus().equals(0)){
            //已认证、未签署
            map.put("status","2");
            map.put("url",contract.getShortUrl());
            return map;
        }
        return map;
    }


    /**
     * E签宝流程撤销
     * @param flowId
     * @return
     */
    @Override
    public ResultObject revokeSignFlow(String flowId){
        ResultObject resultObject = new ResultObject();
        try {
            LOGGER.info("---------------------获取token start------------------------------");
            JSONObject tokenData = TokenHelper.getTokenData();

            LOGGER.info("---------------------撤销签署流程------------------------------");
            SignHelper.revokeSignFlow(flowId);
        }catch (DefineException e){
            LOGGER.error("签署合同撤销异常!",e);
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            return resultObject;
        }
        return null;
    }


    /**
     * 获取签署合同成功之后的查看地址
     * @param userAppId
     * @return  返回长链接  永久有效
     * @throws DefineException
     */
    @Override
    public String selectUserContractUrl(Integer userAppId) throws DefineException {
        Contract contract = contractMapper.selectByPrimaryKey(userAppId);
        if(Objects.isNull(contract) || !contract.getSignStatus().equals(2)){
            return null;
        }else{
            return contract.getShortUrl();
        }
    }


    /**
     * 注销公司账户
     * @param orgId
     * @throws DefineException
     */
    @Override
    public void qryOrgAcctByOrgId(String orgId) throws DefineException {
        LOGGER.info("---------------------获取token start------------------------------");
        JSONObject tokenData = TokenHelper.getTokenData();
        try {
            LOGGER.info("---------------------查询机构账号是否存在------------------------------");
            JSONObject jsonObject = AccountHelper.qryOrgAcctByOrgId(orgId);

            LOGGER.info("---------------------注销公司账户-------------------------------");
            AccountHelper.delOrgAcctByOrgId(orgId);
        } catch (DefineException e) {
            LOGGER.error("查询机构账号异常，账号异常！");
        }
    }


    /**
     * 合同模板填充数据生成
     * @param userApp
     * @return
     */
    private static String buildFile(UserApp userApp,String name, String companyName) throws DefineException {
        //生成填充数据map
        HashMap<String, Object> map = new HashMap<>();
        //顶部填充框
        if(userApp.getUserType().equals("3")){
            //    如果是公司填充公司姓名
            map.put("df641da5f5f14baeb1ad7039a1b34761", companyName == null || companyName.equals("null") || companyName.equals("") ? userApp.getCorporateName() : companyName);
        }else{
            //    如果为个人的话，填充个人姓名
            map.put("df641da5f5f14baeb1ad7039a1b34761",name == null || name.equals("null") || name.equals("") ? userApp.getAccountName() : name);
        }
        //获取当前时间
        Calendar cal = Calendar.getInstance();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy年MM月dd日");
        String startTime = sdf.format(cal.getTime());
        //从什么时间开始
        map.put("a3afd276fc854bd08363a31d46e4f429",startTime);
        //到什么时候结束
        cal.setTime(new Date());
        cal.add(Calendar.YEAR, 1);
        cal.add(Calendar.DATE, -1);
        String endTime = sdf.format(cal.getTime());
        map.put("9cb6e5529455405e8b92f3de622c8e7d",endTime);

        //底部填充
        //两个时间
        map.put("ecdee51151b745cea43604dc5251a3f0",PARTYNAME);
        map.put("a35f862f3a9b4c1193b8f3af21bb7355",startTime);
        map.put("2e5e8e77643b46e3a32351017dc1dc1a",startTime);
        JSONObject fileByTemplate = FileTemplateHelper.createFileByTemplate("中国商办联卖联租平台信息服务协议", TEMPLATE, map);
        String fileId = fileByTemplate.getString("fileId");
        return fileId;
    }


    /**
     * 添加签署区域
     * 区分公司个人
     * @param userType
     */
    private static void addSingArea(String userType,String flowId,String fileId,String acctId,String orgId) throws DefineException {
        if(userType.equals("3")){  //公司
            LOGGER.info("---------------------添加手动盖章签署区 start-----------------------------");
            SignHelper.addSignerHandSignArea(flowId, Lists.newArrayList(fileId), Lists.newArrayList(acctId), Lists.newArrayList(orgId),360f,160f,"2","1","4");
            LOGGER.info("---------------------添加手动签字签署区 start-----------------------------");
            SignHelper.addSignerHandSignArea(flowId, Lists.newArrayList(fileId), Lists.newArrayList(acctId), Lists.newArrayList(acctId),420f,148f,null,"0","4");
        }else {     //个人
            LOGGER.info("---------------------添加手动签字签署区 start-----------------------------");
            SignHelper.addSignerHandSignArea(flowId, Lists.newArrayList(fileId), Lists.newArrayList(acctId), Lists.newArrayList(acctId),420f,148f,null,"0","4");
        }
    }


    /**
     * 调起认证连接
     * @return
     */
    private static Contract identity(String usetType,Integer userAppId, String orgId, String acctId,String originType,String qianshuURL ) throws DefineException {
        Contract contract = new Contract();
        try {
            if (usetType.equals("3")) {
                LOGGER.info("---------------------发起企业刷脸-------------------------------");
                JSONObject faceJson = IdentityHelper.orgIdentity(orgId, acctId, String.valueOf(userAppId), APPROVE_CALLBACK, originType, qianshuURL);
                Map url = (Map<String, String>) faceJson.get("data");
                Object shortLink = url.get("shortLink");
                Object agentFlowId = url.get("flowId");
                contract.setIdentityUrl(shortLink.toString());
                contract.setAgentFlowId(agentFlowId.toString());
            } else {
                LOGGER.info("---------------------发起个人刷脸-------------------------------");
                JSONObject faceJson = IdentityHelper.face(String.valueOf(userAppId), true, APPROVE_CALLBACK, originType, qianshuURL, acctId);
                Map url = (Map<String, String>) faceJson.get("data");
                Object shortLink = url.get("shortLink");
                Object agentFlowId = url.get("flowId");
                contract.setIdentityUrl(shortLink.toString());
                contract.setAgentFlowId(agentFlowId.toString());
            }
        } catch (DefineException e) {
            LOGGER.error("获取实名认证地址失败!",e);
            return null;
        }
        return contract;
    }

    /**
     * 删除本地保存用户注销 个人/公司账户 未签署情况下撤销签署流程
     * @param userAppId  我方业务中的userId
     */
    private void delLocalUserInfo(Integer userAppId,String userType) {
        Contract flag = contractMapper.selectApproveStatus(userAppId);
        if(!Objects.isNull(flag)){
            //删除数据库本地记录
            contractMapper.deleteByUserAppId(userAppId);
            //注销个人用户
            LOGGER.info("---------------------注销个人用户-------------------------------");
            try {
                AccountHelper.delPersonAcctByAcctId(flag.getAccountId());
            } catch (DefineException e) {
                e.printStackTrace();
                LOGGER.error("注销个人账户失败");
            }
            if(userType.equals("3")){
                //注销公司账户
                LOGGER.info("---------------------注销公司账户-------------------------------");
                try {
                    AccountHelper.delOrgAcctByOrgId(flag.getOrgId());
                } catch (DefineException e) {
                    e.printStackTrace();
                    LOGGER.error("注销公司账户失败");
                }
            }
            //失败或者拒签 流程结束，结束流程不可撤回
            if(flag.getSignStatus().equals(0)){
                //撤销签署流程
                try {
                    SignHelper.revokeSignFlow(flag.getFlowId());
                } catch (DefineException e) {
                    e.printStackTrace();
                }
            }
        }
    }


}
