package com.up.zpb.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import com.up.zpb.vo.Dictionary;
import com.up.zpb.vo.UserApp;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.google.common.collect.Maps;
import com.up.zpb.annotation.Cacheable;
import com.up.zpb.mapper.DictionaryMapper;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.util.ConfigurationUtils;
import com.up.zpb.util.Constant;
import com.up.zpb.util.JWTUtil;


@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class DictionaryServiceImpl implements DictionaryService {

	@Autowired
	private DictionaryMapper dictionaryMapper;

	public final static String img_head = ConfigurationUtils.getStringValue("bank_img");

	@Cacheable(expireTime=60*60)
	public List<Map<String,Object>> selectMapByParentKey(String parentKey){
		return this.dictionaryMapper.selectMapByParentKey(parentKey);
	}
	
	//没有子集的,缓存一天
	@Override
	@Cacheable(expireTime=3600 * 24)
	public String findByKey(String parentKey){
		return this.dictionaryMapper.findByKey(parentKey);
	}
	
	
	@Override
	@Cacheable(expireTime=60*60)
	public String selectByDValue(String parentKey,String dValue){
		Map<String,Object> map=new HashMap<String,Object>();
		map.put("dValue", dValue);
		map.put("parentKey", parentKey);
		return this.dictionaryMapper.selectByDValue(map);
	}
	
	@Override
	@Cacheable(expireTime=60*60)
	public List<Map<String,Object>> selectMapByParentKeyD(String parentKey){
		return this.dictionaryMapper.selectMapByParentKeyD(parentKey);
	}
	

	@Override
	@Cacheable(expireTime=60*60)
	public List<Map<String, Object>> selectBankList(String parentKey) {
		// TODO Auto-generated method stub
		Map<String,Object> map = Maps.newHashMap();
		map.put("parentKey", parentKey);
		map.put("img", img_head);
		return dictionaryMapper.selectBankList(map);
	}

	@Override
	public Dictionary selectParentAndSon(Dictionary dictionary) {
		return dictionaryMapper.selectParentAndSon(dictionary);
	}
	@Override
	public String findAskPhone() {
		Map<String,Object> map=new HashMap<String, Object>();
		map.put("dValue", "400");
		map.put("parentKey", "1");
		return dictionaryMapper.selectByDValue(map);
	}
	
	
	@Override
	public UserApp getLoginUser(HttpServletRequest request) {
		String token = request.getHeader(Constant.APP_HEADER_ACCESS_TOKEN);
		if (StringUtils.isBlank(token)) {
			token = request.getParameter(Constant.APP_HEADER_ACCESS_TOKEN);
		}
		UserApp userEn=JWTUtil.unsign(token, UserApp.class);
		return userEn;
	}
	
	
	@Override
	public String getLoginUserType(HttpServletRequest request) {
		String userType="1";
		UserApp loginUserEn=this.getLoginUser(request);
		if(loginUserEn!=null && StringUtils.isNotEmpty(loginUserEn.getUserType()) && Integer.valueOf(loginUserEn.getUserType())>1 ){
			userType="2";
		}
		return userType;
	}
	
	/**
	 * 获取head里面的channel参数
	 * 1、优先从头里取
	 * 2、没有，再从参数里取
	 */
	@Override
	public String getLoginChannel(HttpServletRequest request) {
		String loginChannel="0";
		String headC = request.getHeader(Constant.HEADER_CHANNEL);
		if (StringUtils.isBlank(headC)) {
			loginChannel = request.getParameter(Constant.HEADER_CHANNEL);
		}
		return loginChannel;
	}
	
}
