package com.up.zpb.service.impl;

import java.text.ParseException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.up.zpb.fourhundred.FourCallClient;
import com.up.zpb.fourhundred.FourRecordClient;
import com.up.zpb.mapper.FourHundredMapper;
import com.up.zpb.mapper.LoanMapper;
import com.up.zpb.mapper.UserMapper;
import com.up.zpb.service.FourHundredService;
import com.up.zpb.service.NewsService;
import com.up.zpb.util.Constant;
import com.up.zpb.vo.CallRecording;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;
import com.up.zpb.vo.fourhundred.Answered;
import com.up.zpb.vo.fourhundred.Department;
import com.up.zpb.vo.fourhundred.DeptDetail;
import com.up.zpb.vo.fourhundred.FourHundred;
import com.up.zpb.vo.fourhundred.IvrKeyShow;
import com.up.zpb.vo.fourhundred.ResultFour;
import com.up.zpb.vo.fourhundred.UserA;
import com.up.zpb.vo.fourhundred.ZuoXiInfo;

/**
 * 商客通400小号对接业务逻辑类
 * @author PJJ
 *
 */
@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class FourHundredServiceImpl implements FourHundredService {
	
	private static final Logger logger = LoggerFactory.getLogger(FourHundredServiceImpl.class);
	@Autowired
	private FourHundredMapper fourHundredMapper;
	@Autowired
	private LoanMapper  loanMapper;
	@Autowired
	private NewsService  newsService;
	@Autowired
	private UserMapper userMapper;
	

	@Override
	public ResultObject findEntityByLinkPhone(String linkPhone){
		ResultObject resultObject=new ResultObject();
		try {
			FourHundred entity=this.fourHundredMapper.findEntityByLinkPhone(linkPhone);
			resultObject.put("data", entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}

	@Override
	public ResultObject saveFourHundred(){
		ResultObject resultObject = new ResultObject();
		try {
			FourHundred fhEntity=new FourHundred();
			//TODO
			fhEntity.setCreateTime(new Date());
			this.fourHundredMapper.saveFourHundred(fhEntity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}

	
	@Override
	public ResultObject deleteByLinkPhone(String linkPhone){
		ResultObject resultObject = new ResultObject();
		try {
			this.fourHundredMapper.deleteByLinkPhone(linkPhone);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	//绑定某一个手机号
	@Override
	public void bangDingOne(String linkPhone){
		FourCallClient fc=new FourCallClient();
		UserA userA=fc.findUserEntityByPhone(linkPhone);
		if(userA !=null){
			//如果已经绑定了，先删掉
			fc.delUserByUserId(userA.getUserId());
			//删掉表
			FourHundred  fhEn=this.fourHundredMapper.findEntityByLinkPhone(linkPhone);
			if(fhEn !=null){
				this.fourHundredMapper.deleteByLinkPhone(linkPhone);
			}
		}
		String ivrKey = this.fourHundredMapper.findIvrKeyMax();//导航键自定义6位数字
		this.toCreate(ivrKey.equals("0")?"100001":ivrKey, linkPhone);
	}
	
	
	/**
	 *  1、定时服务程序要查询出需要分配分机号（即坐席工号）的房源联系人（轮询间隔期间上架的房客源联系人手机号，如果没有分机号则分配一个空闲的），还要查询出要释放分机号的（即坐席工号）的房源联系人（下架房客源且没有上架房源了的联系人）；
		2、将要绑定或释放的手机号和分机号通过接口传给400平台，但前提是本地要维护一个手机号分机号的对应表；
		3、勾搭管理还要能查询录音，而且能看到哪些通话是通了的，哪些是没有接通的。
		4、服务程序前期暂时是凌晨3点执行一次，中午12点执行一次。
		5、服务执行间隔期间的需要分配分机号的房客源记录，先显示总机号。等到服务程序执行后分配了分机号后再显示总机+分机号。
		6、由于分机号目前只采购了1000个，所以要充分利用，所以需要把CBMLS和租铺宝一起考虑，也就是要确保同一手机号需要分配分机号的话只能分配一个。
		7、为了保证通话都录音，被叫来显设置为取消来显，也就是不显示主叫手机号，而是显示为一个固定的座机号。
		8、对于被叫拒绝接听或漏接的，需要分别给主叫和被叫发送短信，1、被叫模板如下：刚刚您已拒绝或遗漏接听来自优铺平台的客户或经纪人的来电，可将未接来电保存为【优铺平台中继号码】防止再次漏接。2、主叫模板如下：您拨打的电话暂时无人接听，请5分钟后再试。
	 */
	@Override
	public void taskBinding() {
		try {
			FourCallClient fc = new FourCallClient();
			// 1)查询有上架的房源（或客源）且未绑定坐席的联系人（电话）
			List<String> listOn = this.fourHundredMapper.listOnlinePhone();
			if (listOn != null && listOn.size() > 0) {
				// 绑定：给每个联系人手机号绑定一个导航按键
				for (String linkPhone : listOn) {
					String ivrKey = this.fourHundredMapper.findIvrKeyMax();//导航键自定义6位数字
					String ifEnd=this.toCreate(ivrKey.equals("0")?"100001":ivrKey, linkPhone);
					if(StringUtils.isNotEmpty(ifEnd) && "end".equals(ifEnd)){
						//跳出循环
						break;
					}
				}
			}
			
			this.synDeptListDatas();//同步商客通数据
			
			// 2)查询房源且客源全部已下架的联系人; &call_four_hundred已绑定记录
			List<String> listOff = this.fourHundredMapper.listOfflinePhone();
			if(listOff==null || listOff.size()==0){
				return;
			}
			for (String linkPhone : listOff) {
				// 解绑：将下架的房源的手机号解绑
				FourHundred  entity=this.fourHundredMapper.findEntityByLinkPhone(linkPhone);
				if(entity !=null && StringUtils.isNotEmpty(entity.getIvrKey())){
					//删除坐席
					Boolean flag= fc.delUserByAgentId(entity.getSktAgentId());
					//删除固话 
					//flag=fc.delOnlyAgent(entity.getDeptId(), fc.findGuAgentId());
					if(flag){
						//删除部门
						flag= fc.delDept(entity.getDeptId());
						if(flag){
							this.fourHundredMapper.deleteByLinkPhone(linkPhone);
							logger.info("=========【成功解除导航键（" + entity.getIvrKey() + "）与手机号（" + linkPhone + "）的绑定】");
						}
					}
				}
			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	
	
	//同步一遍数据：查询商客通的部门坐席列表，且把call_four_hundred表缺的字段补齐
	public Boolean synDeptListDatas() throws Exception{
		logger.info("【同步一遍数据：查询商客通的部门坐席列表 start】");
		FourCallClient fc=new FourCallClient();
		//【1】从商客通同步下来导航列表，判断系统表是否有这条导航。没有则删除；
		List<Department>  listD=fc.getIvrTree();
		if(listD !=null && listD.size()>0){
			for(Department temp:listD){
				String deptId=temp.getId();
				String deptName=temp.getText();
				if((temp.getZxList() ==null || temp.getZxList().size()==0)){
					if(FourCallClient.guDeptName.equals(deptName)){
						continue;
					}
					//有部门但没坐席，则删掉这个部门
					fc.delDept(deptId);
					this.fourHundredMapper.deleteByDept(deptId);
				}else{
					ZuoXiInfo zxEntity=temp.getZxList().get(0);
					if(deptName.contains("[")){
						String ivrKey=deptName.substring(deptName.indexOf("[")+1,deptName.indexOf("]"));
						FourHundred  ff=this.fourHundredMapper.findEntityByIvrKey(ivrKey);
						if(ff==null){
							//同步数据
							FourHundred entity=new FourHundred();
							entity.setFourPhone(FourCallClient.fourPhone);
							entity.setDeptId(deptId);
							entity.setDeptName(deptName);
							entity.setIvrKey(ivrKey);
							entity.setSktAgentId(zxEntity.getAgentId());
							entity.setGongHao(zxEntity.getUserCode());
							entity.setGongHaoName(zxEntity.getUserName());
							entity.setGongHaoPwd(FourCallClient.zuoXiPwd);
							entity.setLinkPhone(zxEntity.getBindPhone());
							entity.setPlatform("1");
							entity.setCreateTime(new Date());
							this.fourHundredMapper.saveFourHundred(entity);
						}
					}
				}
				
			}
		}
		//【2】从本地表查询导航列表，判断商客通是否有，没有则删除；防止冗余数据留在表里
		List<FourHundred>  list=this.fourHundredMapper.findList();
		if(list !=null && list.size()>0){
			for(FourHundred temp:list){
				String deptId=temp.getDeptId();
				DeptDetail  deptEn=fc.getDeptDetailById(deptId);
				if(deptEn==null){
					this.fourHundredMapper.deleteByDept(deptId);
				}
			}
		}
		
		//【3】判断固话是否也被删掉了，如果被删掉了，则重新绑上去
		String userIdGu=fc.findGuUserId();
		if(StringUtils.isEmpty(userIdGu)){
			fc.initGuHuaPhone();
		}
		logger.info("【同步一遍数据：查询商客通的部门坐席列表 end】");
		return true;
	}
	
	//创建导航+创建坐席
	public String toCreate(String ivrKey,String linkPhone){
		FourCallClient fc=new FourCallClient();
		String deptId=null;
		String deptName=null;
		try {
			ResultFour resultF=fc.saveDept(ivrKey);
			if("false".equals(resultF.getResult()) || StringUtils.isEmpty(resultF.getDeptId())){
				if(resultF.getMessage().contains("重复的导航按键")){
					this.synDeptListDatas();//同步一遍商客通导航数据
					return "end";//结束循环
				}
				return null;
			}
			deptId=resultF.getDeptId();
			deptName=resultF.getDeptName();
			
			resultF=fc.saveUserAgentBindIvr(linkPhone,deptId);
			if("true".equals(resultF.getResult())){
				this.insertFourInfo(deptId, deptName, ivrKey, linkPhone, resultF);
				logger.info("=========【成功绑定导航键（" + ivrKey + "）到手机号（" + linkPhone + "）】");
				return null;
			}
				
			if(resultF.getMessage().contains("不能重复绑定号码")){//手机号码已经绑定了某个工号;固话不可能重复绑定的。
				UserA  user=fc.findUserEntityByPhone(linkPhone);
				if(StringUtils.isEmpty(user.getDeptIds())){
					fc.delUserByUserId(user.getUserId());//删掉用户
					fc.delDept(deptId);//删掉导航
				}else{
					DeptDetail  ddEn=fc.getDeptDetailById(user.getDeptIds());
					if(user!=null && ddEn !=null){
						FourHundred  ff=this.fourHundredMapper.findEntityByLinkPhone(linkPhone);
						if(ff !=null){
							this.fourHundredMapper.deleteByLinkPhone(linkPhone);
						}
						resultF.setAgentId(user.getUserId());
						resultF.setFourPhone(ddEn.getNum());
						resultF.setGongHao(user.getUserCode());
						resultF.setGongHaoName(user.getUserName());
						resultF.setGongHaoPwd(FourCallClient.zuoXiPwd);
						this.insertFourInfo(ddEn.getDeptId(), ddEn.getDeptName(), ddEn.getIvrKey(), linkPhone, resultF);
					}
				}
			}else{
				//其他的false错误
				fc.delDept(deptId);//删掉导航
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return null;
	}
	
	//保存商客通400导航按键绑定手机号关系
	public void insertFourInfo(String deptId,String deptName,String ivrKey,String linkPhone,
			ResultFour resultF){
		FourHundred  entity=new FourHundred();
		entity.setDeptId(deptId);
		entity.setDeptName(deptName);
		entity.setIvrKey(ivrKey);
		entity.setLinkPhone(linkPhone);
		entity.setPlatform("1");
		entity.setSktAgentId(resultF.getAgentId()==null?"-1":resultF.getAgentId());
		entity.setFourPhone(resultF.getFourPhone()==null?"-1":resultF.getFourPhone());
		entity.setGongHao(resultF.getGongHao()==null?"-1":resultF.getGongHao());
		entity.setGongHaoName(resultF.getGongHaoName()==null?"-1":resultF.getGongHaoName());
		entity.setGongHaoPwd(resultF.getGongHaoPwd()==null?"-1":resultF.getGongHaoPwd());
		entity.setCreateTime(new Date());
		this.fourHundredMapper.saveFourHundred(entity);
	}
	
	
	@Override
	public void taskAnsweredList() {
		try {
			logger.info("【=================进入方法taskAnsweredList()  start】");
			FourRecordClient fr=new FourRecordClient();
			List<Answered>  list=fr.answeredList(null, null);
			if(list==null || list.size()==0){
				return;
			}
			for(Answered temp:list){
				Map<String,Object> reMap=new HashMap<String,Object>();
				reMap.put("sjType","2");
				reMap.put("uuid",temp.getLsh());
				CallRecording  recordTable=this.loanMapper.findRecordByMap(reMap);
				if(recordTable ==null){
					//这条录音流水没有记录到表里，则匹配最近时间的一条记录安装上
					CallRecording lastEn=this.findRecently(temp.getCallerNo(), temp.getCalleeNo(),temp.getStartTime());
					String voice=fr.getRecordFileUrl(temp.getLsh(),temp.getStartTime());
					if(lastEn !=null){
						lastEn.setUuid(temp.getLsh());
						lastEn.setDuration(temp.getMinutes());
						if("0".equals(voice)){
							lastEn.setIfConnect("1");
						}else{
							lastEn.setVoice(voice);
							lastEn.setIfConnect("2");
						}
						this.loanMapper.updateCallRecordingById(lastEn);
					}
				}else{
					//uuid存在，但是录音为空，需要更新进去
					String vUrl=fr.getRecordFileUrl(temp.getLsh(),temp.getStartTime());
					if(StringUtils.isEmpty(recordTable.getVoice()) 
							&& StringUtils.isNotEmpty(vUrl) && !"0".equals(vUrl)){
						recordTable.setVoice(vUrl);
						recordTable.setIfConnect("2");
						this.loanMapper.updateCallRecordingById(recordTable);
					}
				}
			}
			logger.info("【=================进入方法taskAnsweredList()  end】");
		} catch (ParseException e) {
			e.printStackTrace();
		}
	}
	
	//查询表里最近一条没有关联上的录音
	public CallRecording findRecently(String ani,String dnis,String startTime){
		Map<String,Object> lastMap=new HashMap<String,Object>();
		lastMap.put("startTime",startTime);
		lastMap.put("ani",ani);
		if(StringUtils.isNotEmpty(dnis)){
			lastMap.put("dnis",dnis);//有一部分被叫未空的情况，只按主叫匹配
		}
		lastMap.put("sjType","2");
		lastMap.put("noUuid","noUuid");
		CallRecording  lastEn=this.loanMapper.findRecordByMap(lastMap);
		if(lastEn !=null && !"null".equals(lastEn)){
			return lastEn;
		}else{
			return null;
		}
	}
	
	
	@Override
	public void taskNoAnsweredList() {
		logger.info("【=================进入方法taskNoAnsweredList()  start】");
		try {
			FourRecordClient fr=new FourRecordClient();
			List<Answered>  list=fr.notAnswer(null, null,"1");
			if(list==null || list.size()==0){
				return;
			}
			logger.info("【查询到未拨通记录（"+list.size()+"）条,其中包括生产和测试的！】");
			if(list.size()==50){//一天最多200条记录
				List<Answered> itemList2=fr.notAnswer(null, null,"2");
				list.addAll(itemList2);
				if(itemList2.size()==50){
					List<Answered> itemList3=fr.notAnswer(null, null,"3");
					list.addAll(itemList3);
					if(itemList3.size()==50){
						List<Answered> itemList4=fr.notAnswer(null, null,"4");
						list.addAll(itemList4);
						if(itemList4.size()==50){
							List<Answered> itemList5=fr.notAnswer(null, null,"5");
							list.addAll(itemList5);
						}
					}
				}
			}
			for(Answered temp:list){
				Map<String,Object> reMap=new HashMap<String,Object>();
				reMap.put("sjType","2");
				reMap.put("uuid",temp.getLsh());
				CallRecording  recordTable=this.loanMapper.findRecordByMap(reMap);
				String beiJiaoTel=temp.getCalleeNo();
				if(recordTable ==null){
					//这条录音流水没有记录到表里，则匹配最近时间的一条记录安装上
					CallRecording lastEn=this.findRecently(temp.getCallerNo(), beiJiaoTel,temp.getStartTime());
					if(lastEn !=null){
						lastEn.setUuid(temp.getLsh());
						lastEn.setIfConnect("3");
						this.loanMapper.updateCallRecordingById(lastEn);
						//给联系人发一条未接通站内信
						if(StringUtils.isNotEmpty(beiJiaoTel)){
							Map<String,Object> userM=new HashMap<String,Object>();
							userM.put("phone", beiJiaoTel);//被叫
							UserApp  userApp=this.userMapper.selectPhone(userM);
							if(userApp !=null){
								this.newsService.sendTouchMsg("2", userApp.getId()+"", new HashMap<String,String>());
							}else{
								logger.info("被叫，联系人电话（"+temp.getCalleeNo()+"）未在前台注册过。所以无法发短信！");
							}
						}else{
							logger.info("被叫，电话（"+temp.getCalleeNo()+"）未在前台注册过。所以无法发短信！");
						}
					}
					
				}
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		logger.info("【=================进入方法taskNoAnsweredList()  end】");
	}
	
	
	
	/**
	 * 查找外显商客通导航按键
	 * @param linkPhone
	 * @return
	 */
	@Override
	public IvrKeyShow findIvrKeyShow(String linkPhone){
		IvrKeyShow show=new IvrKeyShow();
		show.setIvrType("1");
		show.setIvrPhone(FourCallClient.guPhone);
		show.setIvrAll(FourCallClient.guPhone);
		FourHundred  fh=this.fourHundredMapper.findEntityByLinkPhone(linkPhone);
		if(fh !=null && StringUtils.isNotEmpty(fh.getIvrKey())){
			String ivrAll=fh.getFourPhone()+"转"+fh.getIvrKey();
			show.setIvrType("2");
			show.setIvrPhone(fh.getFourPhone());
			show.setIvrKey(fh.getIvrKey());
			show.setIvrAll(ivrAll);
			return show;
		}
		return show;
	}
	
	
	@Override
	public void batchGuHuaToDept(){
		FourCallClient fc=new FourCallClient();
		fc.batchGuHuaToDept();
	}
	
	
	
	
}
