package com.up.zpb.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.up.zpb.annotation.Cacheable;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.BusinessAreaMapper;
import com.up.zpb.mapper.RegionsMapper;
import com.up.zpb.mapper.ShopBusinessTypeMapper;
import com.up.zpb.service.DictionaryService;
import com.up.zpb.service.HomeShopService;
import com.up.zpb.service.OfficeDicService;
import com.up.zpb.service.OfficeService;
import com.up.zpb.service.ShopNewAreaService;
import com.up.zpb.service.ShopPaperService;
import com.up.zpb.service.ShopService;
import com.up.zpb.service.ShopShopSupportingService;
import com.up.zpb.service.ShopTapService;
import com.up.zpb.service.ShowInfoService;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.vo.Areas;
import com.up.zpb.vo.CommissionEntity;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.Shop;
import com.up.zpb.vo.enums.OfficeEnum;

@Service
public class HomeShopServiceImpl implements HomeShopService {

    private static final Logger logger = LoggerFactory.getLogger(HomeShopServiceImpl.class);

    @Autowired
    private AreasMapper areasMapper;
    @Autowired
    private BusinessAreaMapper businessAreaMapper;
    @Autowired
    private DictionaryService dictionaryService;
    @Autowired
    private ShopBusinessTypeMapper shopBusinessTypeMapper;
    @Autowired
    private ShopService shopService;
    @Autowired
    private ShopShopSupportingService shopShopSupportingService;
    @Autowired
    private ShopTapService shopTapService;
    @Autowired
    private ShopPaperService shopPaperService;
    @Autowired
    private ShopNewAreaService shopNewAreaService;
    @Autowired
    private OfficeDicService officeDicService;
    @Autowired
    private ShowInfoService showInfoService;
    @Autowired
    private RegionsMapper regionsMapper;
    @Autowired
    private OfficeService officeService;

    /**
     * 设置商铺标题
     * 标题 title_sub 传到前台为name
     * 副标题1 title 字段
     * 副标题2 type 字段
     *
     * @param shop
     */
    public void setTile(Shop shop, String rentType) {
        String area = areasMapper.selectById(String.valueOf(shop.getAreaId()));
        String businessArea = businessAreaMapper.selectByIds(String.valueOf(shop.getBusinessAreaId()));
        List<String> type = Arrays.asList("商业街商铺", "社区商业", "写字楼配套", "市场", "百货购物中心", "学校", "村镇商铺", "档口摊位", "其他");
        List<String> license = Arrays.asList("不可办照", "可办照", "公司照可过户", "有照可增项", "大照/集体照", "个人照可用", "公司照可用", "个人照可过户");
        if (StringUtils.isNotBlank(rentType)) {
            shop.setTitle(area + businessArea + "|" + shop.getBuildArea() + "m²");
            shop.setTitleSub(type.get(shop.getType()) + rentType);
        } else {
            shop.setTitle(shop.getFloorName());
            shop.setTitleSub(area + businessArea);
        }
        //pc标题设置
        if (StringUtils.isNotBlank(rentType)) {
            if (rentType.equals("出租")) {
                if (shop.getManageStatus() == 0) {
                    shop.setTitlePc("经营中");//副标题1
                } else {
                    shop.setTitlePc("空置中");
                }
            } else {
                shop.setTitlePc(area + "-" + businessArea);
            }

            if (rentType.equals("出售")) {
                if (shop.getFrontage()) {
                    //主标题 前台取name字段
                    shop.setTitlePcSub(type.get(shop.getType()) + "/" + shop.getBuildArea() + "m²" + "/临街");
                } else {
                    shop.setTitlePcSub(type.get(shop.getType()) + "/" + shop.getBuildArea() + "m²");
                }
            } else {
                //出租
                if (shop.getFrontage()) {
                    shop.setTitlePcSub(area + "-" + businessArea + "/" + shop.getBuildArea() + "m²" + "/临街");
                } else {
                    shop.setTitlePcSub(area + "-" + businessArea + "/" + shop.getBuildArea() + "m²");
                }
            }

            //设置楼层
            String floor = StringUtils.EMPTY;
            if (shop.getFloor1()) {
                floor = floor + "一层";
            }
            if (shop.getFloor2()) {
                floor = floor + "二层";
            }
            if (shop.getFloor3()) {
                floor = floor + "三层";
            }
            if (shop.getFloor4()) {
                floor = floor + "四层";
            }
            if (shop.getFloorHigh()) {
                floor = floor + "高层";
            }
            if (shop.getFloorUnder()) {
                floor = floor + "半地下";
            }
            //三级标题
            if (rentType.equals("出售")) {
                //出售 楼层、商铺类型
                shop.setTitleThree(floor + "、" + type.get(shop.getType()));
            } else {
                //出租 楼层、证照类型
                shop.setTitleThree(floor + "、" + license.get(shop.getLicense()));
            }
        } else {
            //商铺新盘标题设置
            shop.setTitlePcSub(shop.getFloorName());//一级标题  楼盘名称
            shop.setTitlePc(area + "，" + businessArea);//二级标题 详细地址
            shop.setTitleThree(type.get(shop.getType()));//三级标题 商铺类型
        }

    }

    @Override
    public ResultObject submitShopNew(Map<String, Object> parameters, Shop shop) {
        ResultObject resultObject = new ResultObject();
        shop.setCreateTime(new Date());
//        setShop(shop);//经纪人发布商铺设置默认值
        //转换面积
        if (StringUtils.isNotBlank(shop.getBuildAreas())) {
            List<String> areas = Arrays.asList("0-100m²", "100-300m²", "300-500m²", "500-1000m²", "1000m²以上");
            String build = shop.getBuildAreas();
            String buildAreas = StringUtils.EMPTY;

            for (int i = 0; i < areas.size(); i++) {
                if (build.contains(String.valueOf(i))) {
                    buildAreas = buildAreas + areas.get(i) + "、";
                }
            }
            buildAreas = buildAreas.substring(0, buildAreas.length() - 1);
            shop.setBuildAreas(buildAreas);
        }
        //一级业态
        shop.setParentManageTypeId(shop.getParentManageTypeId());
        //均价
        if (Objects.nonNull(shop.getShopAverage())) {
            shop.setAvePrice(new BigDecimal(shop.getShopAverage()));
        }
        //设置出租转让
        if (shop.getRentType() == 0) {
            shop.setRentType(3);
        } else {
            shop.setRentType(4);
        }

        //计算月租
        //shop.setMonthlyRent(this.officeService.jsMonthRent(new BigDecimal(parameters.get("dailyRent")+""), new BigDecimal(parameters.get("buildArea")+"")));
        CommissionEntity commEn = this.officeService.jsonCommission(parameters.get("channel") + "", shop.getRentType() + "", parameters.get("commission") + "", parameters.get("commissionType") + "");
        if (commEn != null) {
            shop.setCommissionValue(commEn.getCommissionValue());
            shop.setCommission(commEn.getCommission());
        }
        shop.setOnlineStatus(0);
        shop.setShopName(this.jsonShopName(shop));
        shop.setShopNumber(this.showInfoService.getNextCustomerID("S"));
        if (shop.getImgs().contains(",")) {
            shop.setCover(shop.getImgs().substring(0, shop.getImgs().indexOf(",")));//设置封面图
        } else {
            shop.setCover(shop.getImgs());//设置封面图
        }

        this.setTile(shop, null);
        shopService.saveAll(shop);

        if (Objects.nonNull(parameters.get("floorArea"))) {
            //商铺面积
            List<String> floorArea = Arrays.asList(parameters.get("floorArea").toString().split(","));
            List<Map<String, Object>> floorAreaList = new ArrayList<>();
            floorArea.forEach(a -> {
                Map<String, Object> map = new HashMap<>();
                map.put("object_id", shop.getId());
                map.put("d_value", a);
                map.put("type", "1");
                map.put("dic_type", 534);
                floorAreaList.add(map);

            });
            officeDicService.saveAll(floorAreaList);
        }

        //特色标签 非必传
        if (Objects.nonNull(parameters.get("shopTags"))) {
            List<String> shopTags = Arrays.asList(parameters.get("shopTags").toString().split(","));
            List<Map<String, Object>> shopTagsList = new ArrayList<>();
            if (shopTags.size() > 0) {
                shopTags.forEach(a -> {
                    Map<String, Object> map = new HashMap<>();
                    map.put("object_id", shop.getId());
                    map.put("d_value", a);
                    map.put("type", "1");
                    map.put("dic_type", 410);
                    shopTagsList.add(map);
                });
                officeDicService.saveAll(shopTagsList);
            }
        }
        return resultObject;
    }

    public String jsonShopName(Shop shop) {
        Areas cityEn = this.areasMapper.selectProvinceIdByCityId(shop.getCityId() + "");
        String regionName = this.regionsMapper.findNameById(shop.getBusinessAreaId() + "");
        String shopName = cityEn.getAreaname() + "-" + regionName;
        return shopName;
    }


    @Override
    public ResultObject submitShopLease(Map<String, Object> parameters, Shop shop) {
        ResultObject resultObject = new ResultObject();
        try {
            shop.setCommission(shop.getCommission() + "个月的租金");
            shop.setCustomerId(Integer.valueOf(parameters.get("authentication").toString()));
            shop.setShopName(this.jsonShopName(shop));
            shop.setShopNumber(this.showInfoService.getNextCustomerID("S"));
//            setShop(shop);//经纪人发布商铺设置默认值
            if (shop.getImgs().contains(",")) {
                shop.setCover(shop.getImgs().substring(0, shop.getImgs().indexOf(",")));//设置封面图
            } else {
                shop.setCover(shop.getImgs());//设置封面图
            }
            shop.setCreateTime(new Date());
            shop.setCreateTime(new Date());
            //更改是否分割  前端 0为否 1为是 更改为 1为否 2为是
//            if (StringUtils.isNotBlank(shop.getSeparate())) {
//                if (shop.getSeparate().equals("0")) {
//                    shop.setSeparate("1");
//                } else if (shop.getSeparate().equals("1")) {
//                    shop.setSeparate("2");
//                }
//            }


            //商铺出租 按日租金计算月租金 月租=日租*面积*365/12，结果保留整数
            if (Objects.nonNull(shop.getDailyRent()) || String.valueOf(shop.getDailyRent()).equals("-2")) {
                BigDecimal dailyRent = shop.getDailyRent();
                BigDecimal buildArea = shop.getBuildArea();
                BigDecimal MonthlyRent = dailyRent.multiply(buildArea).multiply(new BigDecimal(365)).divide(new BigDecimal(12), BigDecimal.ROUND_HALF_UP);
                shop.setMonthlyRent(MonthlyRent);
            }

            //楼层
            List<String> floors = Arrays.asList(parameters.get("floor").toString().split(","));
            if (floors.contains("1")) {
                shop.setFloor1(true);
            }
            if (floors.contains("2")) {
                shop.setFloor2(true);
            }
            if (floors.contains("3")) {
                shop.setFloor3(true);
            }
            if (floors.contains("4")) {
                shop.setFloor4(true);
            }
            if (floors.contains("5")) {
                shop.setFloorHigh(true);
            }
            if (floors.contains("6")) {
                shop.setFloorUnder(true);
            }
           /* //月租=日租*面积*365/12
            if (Objects.nonNull(parameters.get("dailyRent")) && new BigDecimal(parameters.get("dailyRent") + "").compareTo(BigDecimal.ZERO) > 0) {
                BigDecimal mon = new BigDecimal(parameters.get("dailyRent") + "").multiply(new BigDecimal(parameters.get("buildArea") + "").multiply(new BigDecimal(365)).divide(new BigDecimal(12), 2, BigDecimal.ROUND_HALF_UP));
                logger.info("【月租=日租*面积*365/12     即    月租=" + parameters.get("dailyRent") + "*" + parameters.get("buildArea") + "*365/12=" + mon + "】");
                shop.setMonthlyRent(mon);
            } else if ("-2".equals(parameters.get("dailyRent") + "")) {
                shop.setMonthlyRent(new BigDecimal(-2));
            }*/
            //转让费转换为万元
            if (Objects.nonNull(parameters.get("transferFee"))) {
                shop.setTransferFee(ObjectHelpUtils.yuanToWanYuan(new BigDecimal(parameters.get("transferFee") + "")));
            }
            //转让费
            if (Objects.nonNull(parameters.get("transfer"))) {
                shop.setTransferFee(ObjectHelpUtils.yuanToWanYuan(new BigDecimal(parameters.get("transfer") + "")));
            }

            shop.setOnlineStatus(0);
            shop.setRentType(1);
            CommissionEntity commEn = this.officeService.jsonCommission(parameters.get("channel") + "", shop.getRentType() + "", parameters.get("commission") + "", parameters.get("commissionType") + "");
            if (commEn != null) {
                shop.setCommissionValue(commEn.getCommissionValue());
                shop.setCommission(commEn.getCommission());
            }
            this.setTile(shop, "出租");
            shopService.saveAll(shop);

            //配套
            List<String> shopSupporting = Arrays.asList(parameters.get("shopShopSupporting").toString().split(","));
            List<Map<String, Object>> shopTagsList = new ArrayList<>();
            shopSupporting.forEach(a -> {
                Map<String, Object> map = new HashMap<>();
                map.put("object_id", shop.getId());
                map.put("d_value", a);
                map.put("type", "1");
                map.put("dic_type", 135);
                shopTagsList.add(map);
            });
            officeDicService.saveAll(shopTagsList);

            //标签 非必传
            if (Objects.nonNull(parameters.get("shopAttrs"))) {
                List<Map<String, Object>> shopTagListMap = new ArrayList<>();
                List<String> shopTagList = Arrays.asList(parameters.get("shopAttrs").toString().split(","));
                if (shopTagList.size() > 0) {
                    shopTagList.forEach(a -> {
                        Map<String, Object> map = new HashMap<>();
                        map.put("object_id", shop.getId());
                        map.put("d_value", a);
                        map.put("type", "1");
                        map.put("dic_type", 136);
                        shopTagListMap.add(map);
                    });
                    officeDicService.saveAll(shopTagListMap);
                }
            }
            //已有证照
            List<Map<String, Object>> shopLicenseListMap = new ArrayList<>();
            List<String> shopLicenseList = Arrays.asList(parameters.get("mustLicense").toString().split(","));
            shopLicenseList.forEach(a -> {
                Map<String, Object> map = new HashMap<>();
                map.put("object_id", shop.getId());
                map.put("d_value", a);
                map.put("type", "1");
                map.put("dic_type", 137);
                shopLicenseListMap.add(map);
            });
            officeDicService.saveAll(shopLicenseListMap);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }

    @Override
    public ResultObject submitShop(Map<String, Object> parameters, Shop shop) {
        ResultObject resultObject = new ResultObject();
        shop.setCustomerId(Integer.valueOf(parameters.get("authentication").toString()));
        //shop.setCommissionValue(Double.valueOf(String.valueOf(parameters.get("commission_value"))));
        shop.setEntrustPaper(shop.getEntrustImg());//更换委托书字段
        shop.setCustomerPrice(new BigDecimal(shop.getPrice()));//设置商铺单价
//        setShop(shop);//经纪人发布商铺设置默认值
        if (shop.getImgs().contains(",")) {
            shop.setCover(shop.getImgs().substring(0, shop.getImgs().indexOf(",")));//设置封面图
        } else {
            shop.setCover(shop.getImgs());//设置封面图
        }
        shop.setShopNumber(this.showInfoService.getNextCustomerID("S"));
        //计算月租
        //shop.setMonthlyRent(this.officeService.jsMonthRent(new BigDecimal(parameters.get("dailyRent")+""), new BigDecimal(parameters.get("buildArea")+"")));
        CommissionEntity commEn = this.officeService.jsonCommission(parameters.get("channel") + "", shop.getRentType() + "", parameters.get("commission") + "", parameters.get("commissionType") + "");
        if (commEn != null) {
            shop.setCommissionValue(commEn.getCommissionValue());
            shop.setCommission(commEn.getCommission());
        }
        try {
            shop.setCreateTime(new Date());
            List<String> floors = Arrays.asList(parameters.get("floor").toString().split(","));
            if (floors.contains("1")) {
                shop.setFloor1(true);
            }
            if (floors.contains("2")) {
                shop.setFloor2(true);
            }
            if (floors.contains("3")) {
                shop.setFloor3(true);
            }
            if (floors.contains("4")) {
                shop.setFloor4(true);
            }
            if (floors.contains("5")) {
                shop.setFloorHigh(true);
            }
            if (floors.contains("6")) {
                shop.setFloorUnder(true);
            }
            shop.setRentType(2);
            shop.setOnlineStatus(0);
            shop.setShopName(this.jsonShopName(shop));
            this.setTile(shop, "出售");
            shopService.saveAll(shop);

            //配套
            List<String> floorArea = Arrays.asList(parameters.get("shopShopSupporting").toString().split(","));
            List<Map<String, Object>> floorAreaList = new ArrayList<>();
            floorArea.forEach(a -> {
                Map<String, Object> map = new HashMap<>();
                map.put("object_id", shop.getId());
                map.put("d_value", a);
                map.put("type", "1");
                map.put("dic_type", 135);
                floorAreaList.add(map);

            });
            officeDicService.saveAll(floorAreaList);

            // 标签 非必传
            if (Objects.nonNull(parameters.get("shopAttrs"))) {
                List<Map<String, Object>> shopTagListMap = new ArrayList<>();
                List<String> shopTagList = Arrays.asList(parameters.get("shopAttrs").toString().split(","));
                if (shopTagList.size() > 0) {
                    shopTagList.forEach(a -> {
                        Map<String, Object> map = new HashMap<>();
                        map.put("object_id", shop.getId());
                        map.put("d_value", a);
                        map.put("type", "1");
                        map.put("dic_type", 536);
                        shopTagListMap.add(map);
                    });
                    officeDicService.saveAll(shopTagListMap);
                }
            }
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }

    @Override
    @Cacheable(expireTime = 30 * 60)
    public ResultObject getShopDictionary(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            List<Map<?, ?>> areas = Lists.newArrayList();
            List<Map<String, Object>> cc = areasMapper.selectByParentId(parameters.get("cityId").toString());
            cc.forEach(a -> {
                Map<String, Object> c1 = Maps.newHashMap();
                c1.put("id", a.get("id"));
                c1.put("name", a.get("area_name"));
                List<Map<?, ?>> childList = Lists.newArrayList();
                businessAreaMapper.selectByAreaId(a.get("id").toString()).forEach(ba -> {
                    Map<String, Object> c2 = Maps.newHashMap();
                    c2.put("childId", ba.get("id"));
                    c2.put("childName", ba.get("name"));
                    if (!"全部".equals(ba.get("name") + "")) {
                        childList.add(c2);
                    }
                });
                c1.put("childList", childList);

                if (!"全部".equals(a.get("area_name") + "")) {
                    areas.add(c1);
                }
            });


            List<Map<?, ?>> shopBusinessTypes = Lists.newArrayList();
            shopBusinessTypeMapper.selectByPid("").forEach(b -> {
                Map<String, Object> c1 = Maps.newHashMap();
                c1.put("id", b.get("id"));
                c1.put("name", b.get("name"));
                List<Map<?, ?>> childList = Lists.newArrayList();
                shopBusinessTypeMapper.selectByPid(b.get("id").toString()).forEach(bb -> {
                    Map<String, Object> c2 = Maps.newHashMap();
                    c2.put("childId", bb.get("id"));
                    c2.put("childName", bb.get("name"));
                    if (!"全部".equals(bb.get("name") + "")) {
                        childList.add(c2);
                    }
                });
                c1.put("childList", childList);
                if (!"全部".equals(b.get("name") + "")) {
                    shopBusinessTypes.add(c1);
                }
            });
            //楼层
            resultObject.put("shopFloor", dictionaryService.selectMapByParentKey("535"));
            //配套
            resultObject.put("shopShopSupporting", dictionaryService.selectMapByParentKey("135"));
            //已有证件
            resultObject.put("paperList", dictionaryService.selectMapByParentKey("137"));
            //新盘面积
            resultObject.put("shopMeasure", dictionaryService.selectMapByParentKey("534"));
            //商铺出租特色标签
            resultObject.put("shopAttr", dictionaryService.selectMapByParentKey("536"));
            //证件类型
            resultObject.put("paper", dictionaryService.selectMapByParentKey("122"));
            //付款方式
            resultObject.put("payMethodList", dictionaryService.selectMapByParentKey("131"));
            //装修状况
            resultObject.put("decorateList", dictionaryService.selectMapByParentKey("530"));
            //总价
            resultObject.put("totalPrice", dictionaryService.selectMapByParentKey("540"));
            //商铺业态
            resultObject.put("shopBusinessTypes", shopBusinessTypes);
            resultObject.put("shopType", dictionaryService.selectMapByParentKey("133"));
            resultObject.put("shopAreas", areas);
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }
    }

    @Override
    //@Cacheable(expireTime = 30 * 60)
    public ResultObject getHomeDictionary(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            List<Map<?, ?>> areas = Lists.newArrayList();
            List<Map<String, Object>> cc = areasMapper.selectByParentId(parameters.get("cityId").toString());
            cc.forEach(a -> {
                Map<String, Object> c1 = Maps.newHashMap();
                c1.put("id", a.get("id"));
                c1.put("name", a.get("area_name"));
                List<Map<?, ?>> childList = Lists.newArrayList();
                businessAreaMapper.selectByAreaId(a.get("id").toString()).forEach(ba -> {
                    Map<String, Object> c2 = Maps.newHashMap();
                    c2.put("childId", ba.get("id"));
                    c2.put("childName", ba.get("name"));
                    if (!"全部".equals(ba.get("name") + "")) {
                        childList.add(c2);
                    }
                });
                c1.put("childList", childList);

                if (!"全部".equals(a.get("area_name") + "")) {
                    areas.add(c1);
                }
            });


            List<Map<?, ?>> shopBusinessTypes = Lists.newArrayList();
            shopBusinessTypeMapper.selectByPid("").forEach(b -> {
                Map<String, Object> c1 = Maps.newHashMap();
                c1.put("id", b.get("id"));
                c1.put("name", b.get("name"));
                List<Map<?, ?>> childList = Lists.newArrayList();
                shopBusinessTypeMapper.selectByPid(b.get("id").toString()).forEach(bb -> {
                    Map<String, Object> c2 = Maps.newHashMap();
                    c2.put("childId", bb.get("id"));
                    c2.put("childName", bb.get("name"));
                    if (!"全部".equals(bb.get("name") + "")) {
                        childList.add(c2);
                    }
                });
                c1.put("childList", childList);
                if (!"全部".equals(b.get("name") + "")) {
                    shopBusinessTypes.add(c1);
                }
            });

            resultObject.put("shopAreas", areas);
            //写字楼类型
            resultObject.put("officeTypeList", dictionaryService.selectMapByParentKey("510"));
            //付款方式
            resultObject.put("payMethodList", dictionaryService.selectMapByParentKey("538"));
            //业态
            resultObject.put("shopBusinessTypes", shopBusinessTypes);
            //配套-office
            resultObject.put("shopShopSupporting", dictionaryService.selectMapByParentKey(OfficeEnum.OFFICE_MATCHE_KEY));
            //标签-office
            resultObject.put("shopAttr", dictionaryService.selectMapByParentKey(OfficeEnum.OFFICE_LABEL_KEY));
            //装修状况
            resultObject.put("decorateList", dictionaryService.selectMapByParentKey("530"));
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }

        return resultObject;
    }


    /**
     * 经纪人发布设置默认值
     * @param shop
     * @return
     */
//    public void setShop(Shop shop){
//        //默认核实
////        shop.setShopVerify(2);//核实通过
////        shop.setVerifyTime(new Date());
////        shop.setVerifyAccountId(Long.valueOf(String.valueOf(shop.getAgentId())));
//        // 默认审核
////        shop.setShopAudit(1);//待审核
////        shop.setAuditTime(new Date());
////        shop.setAuditAccountId(Long.valueOf(String.valueOf(shop.getAgentId())));
//    }


}
