package com.up.zpb.service.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

import com.up.zpb.mapper.UserMapper;
import com.up.zpb.util.*;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.google.common.collect.Maps;
import com.up.zpb.mapper.CrmCustomerMapper;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.AsynSaveCrmService;
import com.up.zpb.service.InvitedRegistRecordsService;
import com.up.zpb.service.LoginService;
import com.up.zpb.service.MemberService;
import com.up.zpb.service.UserService;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;

import javax.servlet.http.HttpServletRequest;

@Service
@Transactional(propagation = Propagation.SUPPORTS)
public class LoginServiceImpl implements LoginService {

    private static final Logger logger = LoggerFactory.getLogger(LoginServiceImpl.class);
    public static final Integer MAXAGE = 3600 * 24 * 15;
    public final static String totalVIPNum = ConfigurationUtils.getStringValue("totalVIPNum");
    public final static String totalCommonNum = ConfigurationUtils.getStringValue("totalCommonNum");

    @Autowired
    RedisBaseDao redisBaseDao;

    @Autowired
    UserService userService;

    @Autowired
    InvitedRegistRecordsService invitedRegistRecordsService;

    @Autowired
    MemberService memberService;

    @Autowired
    CrmCustomerMapper crmCustomerMapper;

    @Autowired
    AsynSaveCrmService asynSaveCrmService;

    @Autowired
    private UserMapper userMapper;


    @Override
    public Map<String, Object> sendSms(String phoneNumber) {
        logger.info(" LoginServiceImpl sendSms mobile:{}", phoneNumber);
        String validCode = CodeGeneration.getCode(6);
        logger.info("validCode:{}", validCode);
        Map<String, String> result = AliSMS.sendVerificationCode(validCode, phoneNumber);
        Map<String, Object> map = Maps.newHashMap();
        map.put("code", validCode);
        if (result.get("Code") == null || !StringUtils.equalsIgnoreCase("OK", result.get("Code").toString())) {
            map.put("flag", false);
            return map;
        }
        redisBaseDao.set(Constant.MLS_REGISTER_VALIDCODE_KEY + phoneNumber, validCode);
        //指定过期时间
        redisBaseDao.expire(Constant.MLS_REGISTER_VALIDCODE_KEY + phoneNumber, 60 * 30);
        map.put("flag", true);
        return map;
    }


    @Override
    public ResultObject register(String account, String validCode, String password, String userAgent, String provinceId, String cityId, String channel) {
        ResultObject resultObject = new ResultObject();
        try {
            Map<String, Object> mapParam = Maps.newHashMap();
            mapParam.put("account", account);
            UserApp user = userService.selectUserByAccount(mapParam);
            if (null != user) {
                resultObject.setCode(Constant.ALREADY_ERROR);
                resultObject.setMessage("用户已注册，请前往登陆");
                return resultObject;
            }
            Object object = redisBaseDao.get(Constant.MLS_REGISTER_VALIDCODE_KEY + account);
            //为空则表示没有发送过验证码或者验证码已经过期被删除
            if (Objects.isNull(object)) {
                resultObject.setCode(Constant.VALIDCODE_ERROR);
                resultObject.setMessage("验证码过期，注册失败");
                return resultObject;
            }
            String code = String.valueOf(object);
            //验证码一致
            if (StringUtils.equals(validCode, code)) {
                //渠道 0 Android 1 IOS 2 M站 3 官网
                Integer plat = Integer.valueOf(channel);
                //保存用户信息
                UserApp userApp = new UserApp();
                userApp.setChannel(plat);
                userApp.setAccount(account);
                userApp.setCityId(cityId);
                userApp.setChannel(plat);
                userApp.setChannel(Integer.valueOf(provinceId));
                userApp.setCreateTime(new Date());
                userApp.setUpdateTime(new Date());
                userApp.setFirstTime(new Date());
                userApp.setLoginCount(1);
                //userApp.setUserType("1");
                userApp.setPassword(Md5Kit.getMd5(password));
                if (userAgent.contains("iOS")) {
                    userApp.setPlatForm(1);
                    userApp.setChannel(1);
                } else if (userAgent.contains("Android")) {
                    userApp.setChannel(0);
                    userApp.setPlatForm(0);
                } else {
                    userApp.setChannel(2);
                    userApp.setPlatForm(2);
                }
                userApp.setStatus(1);
                //检测并设置内外经纪人
                isOwn(userApp);
                userService.saveUser(userApp);
                String token = JWTUtil.sign(userApp, MAXAGE);
                resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
                resultObject.put("data", userApp);
                resultObject.setCode(Constant.CODE_SUCCESS);
                resultObject.setMessage("成功");
                return resultObject;
            } else {
                //验证码错误
                Long count = this.redisBaseDao.incr(Constant.LOGIN_VALIDCODE_KEY_ERROR + account);
                if (5 == count) {
                    resultObject.setCode(Constant.VALIDCODE_ERROR);
                    resultObject.setMessage("验证码5次输入错误，请重新获取。");
                    this.redisBaseDao.del(Constant.LOGIN_VALIDCODE_KEY + account);
                    this.redisBaseDao.del(Constant.LOGIN_VALIDCODE_KEY_ERROR + account);
                } else {
                    this.redisBaseDao.incr(Constant.LOGIN_VALIDCODE_KEY_ERROR + account);
                    resultObject.setCode(Constant.VALIDCODE_ERROR);
                    resultObject.setMessage("验证码输入错误，请确认后输入。");
                }
                return resultObject;
            }
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }

    }

    @Override
    public ResultObject loginCode(HttpServletRequest request, String account, String validCode, String cityId) {
        String userAgent = request.getHeader("user-agent");
        ResultObject resultObject = new ResultObject();
        Map<String, Object> mapParam = Maps.newHashMap();
        mapParam.put("account", account);
        try {
            if (account.equals("15010852935") && validCode.equals("000000")) {
                UserApp user = userService.selectUserByAccount(mapParam);
                String token = JWTUtil.sign(user, MAXAGE);
                resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
                resultObject.put("data", user);
                resultObject.setCode(Constant.CODE_SUCCESS);
                resultObject.setMessage("成功");
                return resultObject;
            }
            String code = String.valueOf(redisBaseDao.get(Constant.MLS_REGISTER_VALIDCODE_KEY + account));
            if (validCode.equals(code)) {
                UserApp user = userService.selectUserByAccount(mapParam);
                if (null == user) {
                    //新用户
                    UserApp userApp = new UserApp();
                    userApp.setAccount(account);
                    userApp.setCreateTime(new Date());
                    userApp.setUpdateTime(new Date());
                    userApp.setFirstTime(new Date());
                    userApp.setUserType("1");
                    userApp.setLoginCount(1);
                    userApp.setCityId(cityId);
                    if (userAgent.contains("iOS")) {
                        userApp.setChannel(1);
                        userApp.setPlatForm(1);
                    } else if (userAgent.contains("Android")) {
                        userApp.setChannel(0);
                        userApp.setPlatForm(0);
                    } else {
                        userApp.setChannel(2);
                        userApp.setPlatForm(2);
                    }
                    userApp.setStatus(1);
                    //检测并设置内外经纪人
                    isOwn(userApp);
                    userService.saveUser(userApp);
                    String token = JWTUtil.sign(userApp, MAXAGE);
                    resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
                    resultObject.put("data", userApp);
                    resultObject.setCode(Constant.CODE_SUCCESS);
                    resultObject.setMessage("成功");
                    return resultObject;
                } else if (user.getStatus() == 0) {
                    //冻结用户
                    resultObject.setCode(Constant.CODE_EXCEPTION);
                    resultObject.setMessage("您的账户已被冻结，请联系客服");
                    return resultObject;
                } else if (user != null) {
                    user.setUpdateTime(new Date());
                    if (userAgent.contains("iOS")) {
                        user.setChannel(1);
                        user.setPlatForm(1);
                    } else if (userAgent.contains("Android")) {
                        user.setChannel(0);
                        user.setPlatForm(0);
                    } else {
                        user.setChannel(2);
                        user.setPlatForm(2);
                    }
                    user.setLoginCount(user.getLoginCount() + 1);
                    userService.updateUser(user);
                    String token = JWTUtil.sign(user, MAXAGE);
                    resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
                    resultObject.put("data", user);
                    resultObject.setCode(Constant.CODE_SUCCESS);
                    resultObject.setMessage("成功");
                    return resultObject;
                }
            }
            resultObject.setCode(Constant.VALIDCODE_ERROR);
            resultObject.setMessage("验证码输入错误，请确认后输入。");
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }
    }

    @Override
    public ResultObject login(HttpServletRequest request, String account, String password) {
        String userAgent = request.getHeader("user-agent");
        ResultObject resultObject = new ResultObject();
        try {
            Map<String, Object> mapParam = Maps.newHashMap();
            mapParam.put("account", account);
            UserApp user = userService.selectUserByAccount(mapParam);
            if (null == user) {
                resultObject.setCode(Constant.RETRIEVE_ERROR);
                resultObject.setMessage("用户尚未注册，请前往注册");
                return resultObject;
            }
            if (StringUtils.isBlank(user.getPassword())) {
                resultObject.setCode(Constant.PASSWORD_ERROR);
                resultObject.setMessage("手机号与密码不匹配，请重新输入");
                return resultObject;
            }
            if (!user.getPassword().equals(Md5Kit.getMd5(password))) {
                resultObject.setCode(Constant.PASSWORD_ERROR);
                resultObject.setMessage("手机号与密码不匹配，请重新输入");
                return resultObject;
            }
            if (user.getStatus() == 0) {
                resultObject.setCode(Constant.FROZEN_ERROR);
                resultObject.setMessage("您的账户已被冻结，请联系客服");
                return resultObject;
            }
            if (userAgent.contains("iOS")) {
                user.setChannel(1);
                user.setPlatForm(1);
            } else if (userAgent.contains("Android")) {
                user.setChannel(0);
                user.setPlatForm(0);
            } else {
                user.setChannel(2);
                user.setPlatForm(2);
            }
            user.setUpdateTime(new Date());
            user.setLoginCount(user.getLoginCount() + 1);
            userService.updateUser(user);
            String token = JWTUtil.sign(user, MAXAGE);
            resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
            resultObject.put("data", user);
            resultObject.setCode(Constant.CODE_SUCCESS);
            resultObject.setMessage("成功");
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }


    @Override
    public ResultObject retrieve(HttpServletRequest request, String account, String password, String validCode) {
        String userAgent = request.getHeader("user-agent");
        ResultObject resultObject = new ResultObject();
        try {
            Map<String, Object> mapParam = Maps.newHashMap();
            mapParam.put("account", account);
            UserApp user = userService.selectUserByAccount(mapParam);
            if (null == user) {
                resultObject.setCode(Constant.RETRIEVE_ERROR);
                resultObject.setMessage("用户未注册，请前往注册");
                return resultObject;
            }
            if (user.getStatus() == 0) {
                resultObject.setCode(Constant.FROZEN_ERROR);
                resultObject.setMessage("您的账户已被冻结，请联系客服");
                return resultObject;
            }
            Object object = redisBaseDao.get(Constant.MLS_REGISTER_VALIDCODE_KEY + account);
            if (Objects.isNull(object) || !validCode.equals(String.valueOf(object))) {
                resultObject.setCode(Constant.VALIDCODE_ERROR);
                resultObject.setMessage("验证码输入错误，请确认后输入。");
                return resultObject;
            }
            if (validCode.equals(String.valueOf(object))) {
                user.setPassword(Md5Kit.getMd5(password));
                if (userAgent.contains("iOS")) {
                    user.setChannel(1);
                } else if (userAgent.contains("Android")) {
                    user.setChannel(0);
                } else {
                    user.setChannel(2);
                }
                user.setUpdateTime(new Date());
                userService.updateUser(user);
                String token = JWTUtil.sign(user, MAXAGE);
                resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
                resultObject.put("data", user);
                resultObject.setCode(Constant.CODE_SUCCESS);
                resultObject.setMessage("成功");
                return resultObject;
            }
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
        return resultObject;
    }


    @Override
    public ResultObject updateUserTypePeople(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            UserApp userApp = new UserApp();
            userApp.setAccount(String.valueOf(parameters.get("paramPhone")));
            userApp.setAccountName(String.valueOf(parameters.get("accountName")));
            userApp.setUserType(String.valueOf(parameters.get("userType")));
            userService.updateUser(userApp);
            Map<String, Object> map = new HashMap<>();
            map.put("account", userApp.getAccount());
            UserApp data = userService.selectUserByAccount(map);
            resultObject.put("data", data);
            resultObject.setCode(Constant.CODE_SUCCESS);
            resultObject.setMessage("成功");
            String token = JWTUtil.sign(data, MAXAGE);
            resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

    @Override
    public ResultObject updateUserTypeCorporate(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            UserApp userApp = new UserApp();
            userApp.setAccount(String.valueOf(parameters.get("paramPhone")));
            userApp.setAccountName(String.valueOf(parameters.get("accountName")));
            userApp.setCorporateCity(parameters.get("corporateCity").toString());
            userApp.setCorporateName(parameters.get("corporateName").toString());
            userApp.setCorporateImg(parameters.get("corporateImg").toString());
            userApp.setUserType(parameters.get("userType").toString());
            userService.updateUser(userApp);

            Map<String, Object> map = new HashMap<>();
            map.put("account", userApp.getAccount());
            UserApp data = userService.selectUserByAccount(map);

            resultObject.put("data", data);
            resultObject.setCode(Constant.CODE_SUCCESS);
            resultObject.setMessage("成功");
            String token = JWTUtil.sign(data, MAXAGE);
            resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            logger.error(e.getMessage(), e);
            return resultObject;
        }
    }

    @Override
    public ResultObject invitationRegister(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            String code = String.valueOf(redisBaseDao.get(Constant.MLS_REGISTER_VALIDCODE_KEY + parameters.get("account")));
            if (parameters.get("validCode").equals(code)) {
                Map<String, Object> mapParam = Maps.newHashMap();
                mapParam.put("account", parameters.get("account"));
                UserApp user = userService.selectUserByAccount(mapParam);
                if (null == user) {
                    //新用户
                    UserApp userApp = new UserApp();
                    Map<String, Object> map = userMapper.findAgentEntityById(parameters.get("parentId") + "");
                    if (String.valueOf(map.get("user_type")).equals("3")) {
                        userApp.setUserType("4");
                    } else {
                        userApp.setUserType("5");
                    }
                    userApp.setAccount(parameters.get("account") + "");
                    userApp.setCreateTime(new Date());
                    userApp.setUpdateTime(new Date());
                    userApp.setFirstTime(new Date());
                    userApp.setLoginCount(1);
                    userApp.setCityId(parameters.get("cityId") + "");
                    userApp.setChannel(2);
                    userApp.setAccountName(parameters.get("name") + "");
                    userApp.setParentId(Integer.valueOf(parameters.get("parentId") + ""));
                    userApp.setStatus(1);
                    userService.saveUser(userApp);
                    String token = JWTUtil.sign(userApp, MAXAGE);
                    resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
                    resultObject.put("data", userApp);
                    resultObject.setCode(Constant.CODE_SUCCESS);
                    resultObject.setMessage("成功");
                    return resultObject;
                } else if (user.getStatus() == 0) {
                    //冻结用户
                    resultObject.setCode(Constant.CODE_EXCEPTION);
                    resultObject.setMessage("您的账户已被冻结，请联系客服");
                    return resultObject;
                } else if (user != null) {
                    user.setChannel(2);
                    userService.updateUser(user);
                    String token = JWTUtil.sign(user, MAXAGE);
                    resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
                    resultObject.put("data", user);
                    resultObject.setCode(Constant.CODE_SUCCESS);
                    resultObject.setMessage("成功");
                    return resultObject;
                }
            }
            resultObject.setCode(Constant.VALIDCODE_ERROR);
            resultObject.setMessage("验证码输入错误，请确认后输入。");
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }
    }

    @Override
    public ResultObject updatePassword(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            Map<String, Object> mapParam = Maps.newHashMap();
            mapParam.put("account", parameters.get("account"));
            UserApp user = userService.selectUserByAccount(mapParam);
            if (null == user) {
                resultObject.setCode(Constant.FROZEN_CAOZUO_ERROR);
                resultObject.setMessage("无此用户");
                return resultObject;
            }
            if (!user.getPassword().equals(Md5Kit.getMd5(parameters.get("oldPassword") + ""))) {
                resultObject.setCode(Constant.FROZEN_CAOZUO_ERROR);
                resultObject.setMessage("输入的旧密码错误");
                return resultObject;
            }
            user.setPassword(Md5Kit.getMd5(String.valueOf(parameters.get("newPassword"))));
            userService.updateUser(user);
            resultObject.setMessage("修改密码成功");
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }
    }

    @Override
    public ResultObject addPassword(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            if (!parameters.get("newPassword1").equals(parameters.get("newPassword2"))) {
                resultObject.setCode(Constant.FROZEN_CAOZUO_ERROR);
                resultObject.setMessage("两次输入的密码不一致");
                return resultObject;
            }
            Map<String, Object> mapParam = Maps.newHashMap();
            mapParam.put("account", parameters.get("account"));
            UserApp user = userService.selectUserByAccount(mapParam);
            user.setPassword(Md5Kit.getMd5(String.valueOf(parameters.get("newPassword1"))));
            userService.updateUser(user);
            resultObject.setMessage("新增密码成功");
            return resultObject;
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }
    }

    @Override
    public ResultObject wxLogin(String account, String validCode, String openId, String s1, String provinceId, String cityId, String source, String userAgent) {
        logger.info("LoginServiceImpl login in...");
        ResultObject resultObject = new ResultObject();
        String code = StringUtils.EMPTY;
        if (!StringUtils.equals(account, "15010852935")) {
            Object object = redisBaseDao.get(Constant.MLS_REGISTER_VALIDCODE_KEY + account);
            //判空
            if (Objects.isNull(object)) {
                resultObject.setCode(Constant.VALIDCODE_ERROR);
                resultObject.setMessage("验证码过期，登录失败");
                return resultObject;
            }
            code = String.valueOf(object);
        } else {
            code = "000000";
        }
        if (StringUtils.equals(validCode, code)) {
            //验证码一致
            Map<String, Object> map = Maps.newHashMap();
            //根据手机号查询用户对象
            map.put("account", account);
            UserApp userApp = userService.selectUserByAccount(map);
            if (Objects.isNull(userApp)) {
                userApp = new UserApp();
                userApp.setAccount(account);
                userApp.setProvinceId(provinceId);
                userApp.setCityId(cityId);
                userApp.setCreateTime(new Date());
                userApp.setStatus(1);
                userApp.setWxOpenId(openId);
                userApp.setLoginCount(1);
                userService.saveUser(userApp);
            }
            userApp.setAccount(account);
            userApp.setWxOpenId(openId);
            //最新登录时间
            userApp.setUpdateTime(new Date());
            //累加登录次数
            Integer loginCount = userApp.getLoginCount();
            if (0 == loginCount) {
                userApp.setLoginCount(1);
                userApp.setProvinceId(provinceId);
                userApp.setCityId(cityId);
            } else {
                userApp.setLoginCount(userApp.getLoginCount() + 1);
            }
            // platForm 0-PC_WEB;1-IOS;2-Android;3-M_WEB
            //渠道 0 Android 1 IOS 2 M站 3 官网
            userApp.setChannel(Integer.valueOf(source));
            if (Objects.isNull(userApp.getFirstTime())) {
                userApp.setCreateTime(new Date());
                userApp.setFirstTime(new Date());
                if (userAgent.contains("1")) {
                    userApp.setPlatForm(1);
                    userApp.setChannel(1);
                } else if (userAgent.contains("0")) {
                    userApp.setPlatForm(0);
                    userApp.setChannel(0);
                } else {
                    userApp.setPlatForm(0);
                    userApp.setChannel(0);
                }
                userApp.setStatus(1);
                isOwn(userApp);
                resultObject.put("loginFlag", false);//首次登录
            } else {
                resultObject.put("loginFlag", true);
                if (userApp.getStatus() == 0) {
                    resultObject.setCode(Constant.CODE_EXCEPTION);
                    resultObject.setMessage("您的账户已被冻结，请联系客服");
                    return resultObject;
                }
            }
            userService.updateUser(userApp);
            resultObject.put("data", userApp);
            //正确，生成token
            String token = JWTUtil.sign(userApp, MAXAGE);
            resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
        } else {
            Long count = this.redisBaseDao.incr(Constant.MLS_REGISTER_VALIDCODE_KEY + account);
            if (5 == count) {
                resultObject.setCode(Constant.VALIDCODE_ERROR);
                resultObject.setMessage("验证码5次输入错误，请重新获取。");
                this.redisBaseDao.del(Constant.MLS_REGISTER_VALIDCODE_KEY + account);
                this.redisBaseDao.del(Constant.MLS_REGISTER_VALIDCODE_KEY + account);
            } else {
                this.redisBaseDao.incr(Constant.MLS_REGISTER_VALIDCODE_KEY + account);
                resultObject.setCode(Constant.VALIDCODE_ERROR);
                resultObject.setMessage("验证码输入错误，请确认后输入。");
            }
            return resultObject;
        }
        return resultObject;
    }

    /**
     * 根据手机号判断新注册用户是否为内部经纪人
     */
    public UserApp isOwn(UserApp user) {
        if (userMapper.selectSysUserByAccount(user.getAccount()) > 0) {
            user.setOwn(1);    //内部经纪人
        } else {
            user.setOwn(0);    //外部经纪人
        }
        return user;
    }
}

