package com.up.zpb.service.impl;

import com.up.zpb.mapper.MsgMapper;
import com.up.zpb.service.MsgService;
import com.up.zpb.util.Constant;
import com.up.zpb.vo.ResultObject;
import org.apache.commons.lang.StringUtils;
import org.jsoup.Jsoup;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.function.Supplier;
import java.util.stream.Collectors;

@Service
public class MsgServiceImpl implements MsgService {

    private static final Logger logger = LoggerFactory.getLogger(MsgServiceImpl.class);

    @Autowired
    private MsgMapper msgMapper;

    @Override
    public ResultObject selectList(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            List<Map<String, Object>> list = msgMapper.selectList(parameters);
            //处理内容
            for (int i = 0; i < list.size(); i++) {
                if (String.valueOf(list.get(i).get("status")).equals("2")) {
                    String content = Jsoup.parse(String.valueOf(list.get(i).get("content"))).text();
                    if (content.length() > 50) {
                        list.get(i).put("content", content.substring(0, 50));
                    } else {
                        list.get(i).put("content", content);
                    }
                }
            }

            //处理时间
            editDate(list);
            resultObject.put("data", list);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }


    @Override
    public ResultObject alreadyRead(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            String type = String.valueOf(parameters.get("type"));
            if (type.equals("2")) {
                //全部已读
                msgMapper.updateReads(parameters);
            } else if (type.equals("4")) {
                //全部删除
                msgMapper.updateDeletes(parameters);
            } else if (type.equals("1")) {
                // 单条已读
                msgMapper.updateRead(parameters);
            } else if (type.equals("3")) {
                // 单条删除
                msgMapper.updateDelete(parameters);
            }


        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

    @Override
    public ResultObject selectCount(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            resultObject.put("count", msgMapper.selectCount(parameters));
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

    @Override
    public ResultObject selectDetail(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            List<Map<String, Object>> map = new ArrayList<>();
            if ((parameters.get("type") + "").equals("1")) {
                map = msgMapper.selectDetail(parameters);
            } else {
                map = msgMapper.selectPublicDetail(parameters);
            }
            resultObject.put("data", map);
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统异常");
            logger.error(e.getMessage(), e);
        }
        return resultObject;
    }

    /**
     * 消息时间处理
     *
     * @param list
     */
    private void editDate(List<Map<String, Object>> list) {
        SimpleDateFormat fm = new SimpleDateFormat("HH:mm:ss");
        SimpleDateFormat fmt = new SimpleDateFormat("yyyy-MM-dd");
        for (int i = 0; i < list.size(); i++) {
            if (fmt.format(StringToDate(String.valueOf(list.get(i).get("create_time")))).equals(fmt.format(new Date()))) {
                //格式化为相同格式
                list.get(i).put("create_time", fm.format(StringToDate(String.valueOf(list.get(i).get("create_time")))));
            } else {
                list.get(i).put("create_time", fmt.format(StringToDate(String.valueOf(list.get(i).get("create_time")))));
            }
        }
    }

    private static Date StringToDate(String datetime) {
        SimpleDateFormat sdFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date date = new Date();
        try {
            date = sdFormat.parse(datetime);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return date;
    }

}
