package com.up.zpb.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.up.zpb.mapper.LoanMapper;
import com.up.zpb.mapper.NewsMapper;
import com.up.zpb.mapper.UserMapper;
import com.up.zpb.service.ChuangNanService;
import com.up.zpb.service.NewsService;
import com.up.zpb.service.OfficeService;
import com.up.zpb.umeng.UmengUtils;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.vo.AgentEntity;
import com.up.zpb.vo.CallRecording;
import com.up.zpb.vo.News;
import com.up.zpb.vo.NewsUser;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;
import com.up.zpb.vo.enums.CallEnum;
import com.up.zpb.vo.qn.MessagePo;


@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class NewsServiceImpl implements NewsService {
	
	private static final Logger logger = LoggerFactory.getLogger(NewsServiceImpl.class);
	
	public static final String aniText = "您联系的房/客源联系人可能正忙，建议您5分钟后再试。";
	public static final String dnisText="刚刚您已拒绝或遗漏接听来⾃优铺平台的客户或经纪⼈的来电，可将未接来电保存为【优铺平台中继号码】防⽌再次漏接。";

	@Autowired
	private NewsMapper newsMapper;
	@Autowired
	private OfficeService officeService;
	@Autowired
	private LoanMapper loanMapper;
	@Autowired
	private ChuangNanService chuangNanService;
	@Autowired
	private UserMapper userMapper;
	
	
	@Override
	public News findEntityByTouchType(String touchType){
		Map<String,Object> parameters=new HashMap<String, Object>();
		parameters.put("touchType", touchType);
		News entity=this.newsMapper.findEntityByMap(parameters);
		return entity;
	}
	
	@Override
	public  ResultObject lianXiMsg(String loginUserId, String projectName,String shopNumber,String projectType){
		ResultObject resultObject=new ResultObject();
		try {
			Map<String,String> dyParam=new HashMap<String,String>();
			dyParam.put("projectName", projectName);
			dyParam.put("shopNumber", shopNumber);
			dyParam.put("projectType", projectType);
			//1)给联系人-发“站内信”  ;touchType=8
			//您刚刚联系了让佣人，房源名称： ${projectName},编号【${shopNumber}】，如果您接下来是带客户看房，请您到访时⼀定要让其签署到访确认单并上传。如有不清楚，请拨打优铺客服电话4008988808咨询。
			Map<String, Object>  mapRes=this.userMapper.findAgentEntityById(loginUserId);
			String userType=mapRes.get("user_type")+"";
			if(!"1".equals(userType)){
				resultObject=this.sendTouchMsg("8", loginUserId, dyParam);
			}else{
				logger.info("【普通用户，不发短信！touchType=8】");
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	/**
	 * 签到等流程发消息
	 * @param touchType 节点
	 * @param appUserId 发给的用户id
	 * @param userName 发给的用户名称
	 * @param dyParam 动态参数
	 */
	@Override
	public ResultObject sendTouchMsg(String touchType,String appUserId,Map<String,String> dyParam){
		ResultObject resultObject=new ResultObject();
		News msgEn=this.findEntityByTouchType(touchType);
		if(msgEn==null){
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("消息模板touchType="+touchType+"有误，查无数据");
			return resultObject;
		}
		String content=msgEn.getContent();
		//替换动态参数
		if(content.contains("${appTitle}")){
			content=content.replace("${appTitle}", dyParam.get("appTitle")==null?"无":dyParam.get("appTitle"));
		}
		if(content.contains("${projectName}")){
			content=content.replace("${projectName}",dyParam.get("projectName")==null?"无":dyParam.get("projectName") );
		}
		if(content.contains("${shopNumber}")){
			content=content.replace("${shopNumber}",dyParam.get("shopNumber")==null?"无":dyParam.get("shopNumber") );
		}
		if(content.contains("${phone}")){
			content=content.replace("${phone}",dyParam.get("phone")==null?"无":dyParam.get("phone") );
		}
		if(dyParam.containsKey("projectType") && StringUtils.isNotEmpty(dyParam.get("projectType"))){
			if(content.contains("房/客源")){
				if("1".equals(dyParam.get("projectType")) || "2".equals(dyParam.get("projectType"))){
					content=content.replace("房/客源","房源");
				}else if("3".equals(dyParam.get("projectType"))){
					content=content.replace("房/客源","客源");
				}
			}
			if(content.contains("房源") && "3".equals(dyParam.get("projectType"))){
					content=content.replace("房源","客源");
			}
		}
		resultObject=this.insertToUser(msgEn.getTitle(), content,appUserId,ObjectHelpUtils.getIcon(touchType));
		try {
			//推送友盟通知
			UmengUtils umeng=new UmengUtils();
			List<Integer>  uList=new ArrayList<Integer>();
			uList.add(Integer.valueOf(appUserId));
			umeng.sendIOSGroupcast(msgEn.getTitle(), content, "1", 1, uList);
			umeng.sendAndroidGroupcast(msgEn.getTitle(), content, uList,"1", 2);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return resultObject;
	}
	
	
	
	/**
	 * 发送消息给用户-前台
	 * @param title
	 * @param content
	 * @param appUserId
	 * @param userName
	 * @return
	 */
	public ResultObject insertToUser(String title,String content,String appUserId,String iconType){
		ResultObject resultObject = new ResultObject();
		try {
			NewsUser entity=new NewsUser();
			entity.setTitle(title);
			entity.setContent(content);
			entity.setIfSee("1");
			entity.setTypes("1");//用户类型：1-前台用户（对应app_user）；2-后台用户（对应sys_user表）
			entity.setUserId(Integer.valueOf(appUserId));
			AgentEntity agentEn=this.officeService.findAgentEntity(appUserId);
			String name="你是谁";
			if(agentEn!=null && !ObjectHelpUtils.isMyNull(agentEn.getName())){
				name=agentEn.getName();
			}
			entity.setUserName(name);
			entity.setCreateTime(new Date());
			entity.setIconType(iconType);
			entity.setStatus("1");
			entity.setCreateName("系统发送");
			this.newsMapper.sendTouchMsg(entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public ResultObject insertNews(Map<String,Object> parameters){
		ResultObject resultObject = new ResultObject();
		try {
			News entity=(News)ObjectHelpUtils.setValToObj2(new News(), parameters);
			entity.setCreateTime(new Date());
			this.newsMapper.insertNews(entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	@Override
	public ResultObject qnCallBack(MessagePo   msgEntity){
		ResultObject resultObject = new ResultObject();
		logger.info("========================青牛回调 处理业务 start");
		try {
			CallRecording  record=this.loanMapper.findCallRecordingEntityById(msgEntity.getSessionId());
			if(record !=null ){
				if(Integer.valueOf(msgEntity.getDuration())>0){
					record.setIfConnect("2");
					record.setEndReason("已接通");
				}else{
					record.setIfConnect("1");
					record.setEndReason(CallEnum.EndReason.codeOf(msgEntity.getCallEndreason()).getName());
				}
				record.setDuration(msgEntity.getDuration()==null?"0":msgEntity.getDuration());
				this.loanMapper.updateCallRecording(record);
				
				if("1".equals(record.getIfConnect())){
					//给主叫人发短信
					this.chuangNanService.sendCnMsg(aniText, record.getAni());
					//给被叫人(发布人)发短信；
					this.chuangNanService.sendCnMsg(dnisText, record.getDnis());
				}else{
					logger.info("提示：已接通，不用发短信。("+msgEntity.getSessionId()+")");
				}
			}else{
				logger.info("消息发送失败，sessionId("+msgEntity.getSessionId()+")有误，查无数据");
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("========================青牛回调 处理业务 end");
		return resultObject;
	}
	
	
}
