package com.up.zpb.service.impl;

import com.google.common.collect.Maps;
import com.up.zpb.mapper.RecommendUserMapper;
import com.up.zpb.mapper.UserMapper;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.RecommendUserService;
import com.up.zpb.service.UserService;
import com.up.zpb.util.Constant;
import com.up.zpb.util.JWTUtil;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.UserApp;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;

@Service
public class RecommendUserServiceImpl implements RecommendUserService {

    public static final Integer MAXAGE = 3600 * 24 * 15;

    @Autowired
    UserService userService;
    @Autowired
    RedisBaseDao redisBaseDao;
    @Autowired
    private UserMapper userMapper;
    @Autowired
    private RecommendUserMapper recommendUserMapper;

    @Override
    public ResultObject friendRegister(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            Map<String, Object> mapParam = Maps.newHashMap();
            mapParam.put("phone", parameters.get("phone"));
            UserApp user = userService.selectPhone(mapParam);
            if (null != user) {
                resultObject.setCode(Constant.ALREADY_ERROR);
                resultObject.setMessage("用户已注册，请前往登陆");
                return resultObject;
            }
            Object object = redisBaseDao.get(Constant.MLS_REGISTER_VALIDCODE_KEY + parameters.get("phone"));
            //为空则表示没有发送过验证码或者验证码已经过期被删除
            if (Objects.isNull(object)) {
                resultObject.setCode(Constant.VALIDCODE_ERROR);
                resultObject.setMessage("验证码过期，推荐失败");
                return resultObject;
            }
            String code = String.valueOf(object);
            if (code.equals(parameters.get("validCode"))) {
                // platForm 0-PC_WEB;1-IOS;2-Android;3-M_WEB
                Integer plat = Integer.valueOf(parameters.get("platForm")+"");
                UserApp userApp = new UserApp();
                userApp.setPlatForm(plat);
                userApp.setChannel(plat);
                userApp.setAccount(parameters.get("phone")+"");
                userApp.setRecommendId(Integer.valueOf(parameters.get("userId")+""));
                userApp.setCityId(parameters.get("cityId")+"");
                userApp.setStatus(1);
                userApp.setCreateTime(new Date());
                //判断内外经纪人
                isOwn(userApp);
                userService.saveUser(userApp);
                String token = JWTUtil.sign(userApp, MAXAGE);
                resultObject.put(Constant.APP_HEADER_ACCESS_TOKEN, token);
                resultObject.put("data", userApp);
                resultObject.setCode(Constant.CODE_SUCCESS);
                resultObject.setMessage("成功");
                return resultObject;
            } else {
                //验证码错误
                Long count = this.redisBaseDao.incr(Constant.LOGIN_VALIDCODE_KEY_ERROR + parameters.get("phone"));
                if (5 == count) {
                    resultObject.setCode(Constant.VALIDCODE_ERROR);
                    resultObject.setMessage("验证码5次输入错误，请重新获取。");
                    this.redisBaseDao.del(Constant.LOGIN_VALIDCODE_KEY + parameters.get("phone"));
                    this.redisBaseDao.del(Constant.LOGIN_VALIDCODE_KEY_ERROR + parameters.get("phone"));
                } else {
                    this.redisBaseDao.incr(Constant.LOGIN_VALIDCODE_KEY_ERROR + parameters.get("phone"));
                    resultObject.setCode(Constant.VALIDCODE_ERROR);
                    resultObject.setMessage("验证码输入错误，请确认后输入。");
                }
                return resultObject;
            }
        } catch (Exception e) {
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }
    }

    @Override
    public ResultObject friendList(Map<String, Object> parameters) {
        ResultObject resultObject = new ResultObject();
        try {
            List<Map<String,Object>> list = recommendUserMapper.friendList(parameters);
            resultObject.setMessage("成功");
            resultObject.put("data",list);
            return resultObject;
        }catch (Exception e){
            resultObject.setCode(Constant.CODE_EXCEPTION);
            resultObject.setMessage("系统错误");
            return resultObject;
        }
    }


    /**
     * 根据手机号判断新注册用户是否为内部经纪人
     */
    public UserApp isOwn(UserApp user) {
        if(userMapper.selectSysUserByAccount(user.getAccount()) >0) {
            user.setOwn(1);	//内部经纪人
        }else {
            user.setOwn(0);	//外部经纪人
        }
        return user;
    }
}
