package com.up.zpb.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.LoanMapper;
import com.up.zpb.mapper.LookOfficeMapper;
import com.up.zpb.mapper.LookShopMapper;
import com.up.zpb.mapper.OfficeAssessMapper;
import com.up.zpb.mapper.RegionsMapper;
import com.up.zpb.mapper.ShopAssessMapper;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.OfficeService;
import com.up.zpb.service.ShopAssessService;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.vo.Areas;
import com.up.zpb.vo.Loan;
import com.up.zpb.vo.LookOffice;
import com.up.zpb.vo.LookShop;
import com.up.zpb.vo.OfficeAssess;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.ShopAssess;


@Service
@Transactional(propagation=Propagation.SUPPORTS)
public class ShopAssessServiceImpl implements ShopAssessService {
	
	private static final Logger logger = LoggerFactory.getLogger(ShopAssessServiceImpl.class);

	@Autowired
	private ShopAssessMapper shopAssessMapper;
	@Autowired
	private OfficeAssessMapper officeAssessMapper;
	@Autowired
	private AreasMapper areasMapper;
	@Autowired
	private RegionsMapper regionsMapper;
	@Autowired
	private LoanMapper loanMapper;
	@Autowired
	private LookOfficeMapper lookOfficeMapper;
	@Autowired
	private LookShopMapper lookShopMapper;
	@Autowired
	private OfficeService officeService;
	@Autowired
	private RedisBaseDao redisBaseDao;
	
	@Override
	public ResultObject selectPage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<Map<String,Object>> list= this.shopAssessMapper.selectPage(paraMap);
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public ResultObject findEntityById(String id){
		ResultObject resultObject=new ResultObject();
		try {
			ShopAssess entity=this.shopAssessMapper.findEntityById(id);
			resultObject.put("data", entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public ResultObject saveShopAssess(ShopAssess entity,Map<String,Object> parameters){
		ResultObject resultObject = new ResultObject();
		try {
			String code = String.valueOf(redisBaseDao.get(Constant.MLS_REGISTER_VALIDCODE_KEY + parameters.get("telephone")+""));
	        if ( !code.equals(parameters.get("vcode")+"")) {
	        	 resultObject.setCode(Constant.VALIDCODE_ERROR);
	             resultObject.setMessage("验证码输入错误，请确认后输入。");
	             return resultObject;
	        }
			Areas areasEn=this.areasMapper.selectProvinceIdByCityId(entity.getAreaId()+"");
			Loan loanEn=this.loanMapper.findEntityById(entity.getLoadId());
			Areas cityEn=this.areasMapper.selectProvinceIdByCityId(entity.getCityId()+"");
			entity.setCityName(cityEn.getAreaname());
			entity.setAreaName(areasEn==null?"":areasEn.getAreaname());
			entity.setRegionsName(this.regionsMapper.findNameById(entity.getRegionsId()+""));
			entity.setLoadName(loanEn==null?"":loanEn.getName());
			entity.setCreateTime(new Date());
			entity.setName(parameters.get("linkman")+"");
			this.shopAssessMapper.saveShopAssess(entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	

	@Override
	public ResultObject saveOfficeAssess(OfficeAssess entity,Map<String,Object> parameters){
		ResultObject resultObject = new ResultObject();
		try {
			String code = String.valueOf(redisBaseDao.get(Constant.MLS_REGISTER_VALIDCODE_KEY + parameters.get("telephone")+""));
	        if ( !code.equals(parameters.get("vcode")+"")) {
	        	 resultObject.setCode(Constant.VALIDCODE_ERROR);
	             resultObject.setMessage("验证码输入错误，请确认后输入。");
	             return resultObject;
	        }
	        
			Areas areasEn=this.areasMapper.selectProvinceIdByCityId(entity.getAreaId()+"");
			Loan loanEn=this.loanMapper.findEntityById(entity.getLoadId());
			Areas cityEn=this.areasMapper.selectProvinceIdByCityId(entity.getCityId()+"");
			entity.setCityName(cityEn.getAreaname());
			entity.setAreaName(areasEn==null?"":areasEn.getAreaname());
			entity.setRegionsName(this.regionsMapper.findNameById(entity.getRegionsId()+""));
			entity.setLoadName(loanEn==null?"":loanEn.getName());
			entity.setCreateTime(new Date());
			entity.setName(parameters.get("linkman")+"");
			entity.setFloor(parameters.get("name")+"");
			this.officeAssessMapper.saveOfficeAssess(entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	
	@Override
	public ResultObject updateShopAssess(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			ShopAssess entity=this.shopAssessMapper.findEntityById(paraMap.get("id")+"");
			if(entity!=null){
				this.shopAssessMapper.updateShopAssess((ShopAssess)ObjectHelpUtils.setValToObj2(entity, paraMap));
			}else{
				resultObject.setCode(Constant.CODE_PARAM_ERROR);
				resultObject.setMessage("上送参数有误");
			}
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	@Override
	public ResultObject saveLookOffice(LookOffice entity){
		ResultObject resultObject = new ResultObject();
		try {
			Areas areasEn=this.areasMapper.selectProvinceIdByCityId(entity.getAreaId()+"");
			entity.setAreaName(areasEn==null?"":areasEn.getAreaname());
			entity.setRegionsName(this.regionsMapper.findNameById(entity.getRegionsId()+""));
			entity.setCreateTime(new Date());
			this.lookOfficeMapper.saveLookOffice(entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public ResultObject saveLookShop(LookShop entity){
		ResultObject resultObject = new ResultObject();
		try {
			Areas areasEn=this.areasMapper.selectProvinceIdByCityId(entity.getAreaId()+"");
			entity.setAreaName(areasEn==null?"":areasEn.getAreaname());
			entity.setRegionsName(this.regionsMapper.findNameById(entity.getRegionsId()+""));
			entity.setCreateTime(new Date());
			this.lookShopMapper.saveLookShop(entity);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	@Override
	public ResultObject findLookShopPage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<Map<String,Object>> list= this.lookShopMapper.selectPage(paraMap);
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	@Override
	public ResultObject findLookOfficePage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<Map<String,Object>> list= this.lookOfficeMapper.selectPage(paraMap);
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	@Override
	public ResultObject findMyLookAllPage(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			Integer pageNum = Integer.valueOf((String)paraMap.get("pageNum"));
			Integer pageSize = Integer.valueOf((String)paraMap.get("pageSize"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<Map<String,Object>> list= this.lookShopMapper.findMyLookAllPage(paraMap);
			resultObject.put("list", list);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	public List<Map<String,Object>> jsonChildrentList(){
		List<Map<String,Object>> childrentList=new ArrayList<Map<String,Object>>();
		Map<String,Object> chil1=new HashMap<String,Object>();
		chil1.put("value", "1");
		chil1.put("name", "求租");
		childrentList.add(chil1);
		Map<String,Object> chil2=new HashMap<String,Object>();
		chil2.put("value", "2");
		chil2.put("name", "求购");
		childrentList.add(chil2);
		return childrentList;
	}
	
	
	
	/**
	 * projectType：1-商铺 2-写字楼
	 * 
	 */
	@Override
	public ResultObject findAppLookJson(Map<String, Object> paraMap) {
		ResultObject resultObject = new ResultObject();
		try {
			if("1".equals(paraMap.get("helpType")+"")){
				 resultObject=this.helpLook();//帮我找铺
			}else{
				resultObject=this.helpRent();//帮我出租
			}
			resultObject.put("areaList", this.officeService.findAreaAndRegions(paraMap.get("cityId")+""));
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	//帮我找铺
	public ResultObject helpLook() throws Exception{
		ResultObject resultObject = new ResultObject();
		List<Map<String,Object>> list=new ArrayList<Map<String,Object>>();
		Map<String,Object> d1=new HashMap<String, Object>();
		d1.put("value", "1");
		d1.put("name","商铺");
		d1.put("childrent", this.jsonChildrentList());
		list.add(d1);
		Map<String,Object> d2=new HashMap<String, Object>();
		d2.put("value", "2");
		d2.put("name","写字楼");
		d2.put("childrent", this.jsonChildrentList());
		list.add(d2);
		Map<String,Object> d3=new HashMap<String, Object>();
		d3.put("value", "3");
		d3.put("name","商业新盘");
		d3.put("childrent", this.jsonChildrentList());
		list.add(d3);
		Map<String,Object> d4=new HashMap<String, Object>();
		d4.put("value", "4");
		d4.put("name","写字楼新盘");
		d4.put("childrent", this.jsonChildrentList());
		list.add(d4);
		resultObject.put("list", list);
		return resultObject;
	}
	
	//帮我出租
	public ResultObject helpRent()throws Exception{
		ResultObject resultObject = new ResultObject();
		List<Map<String,Object>> listParent=new ArrayList<Map<String,Object>>();
		Map<String,Object> pShop=new HashMap<String,Object>();
		pShop.put("value", "1");
		pShop.put("name", "商铺");
		listParent.add(pShop);
		Map<String,Object> pOffice=new HashMap<String,Object>();
		pOffice.put("value", "2");
		pOffice.put("name", "写字楼");
		listParent.add(pOffice);
		
		//子1
		List<Map<String,Object>> shopChild=new ArrayList<Map<String,Object>>();
		Map<String,Object> mapA=new HashMap<String,Object>();
		mapA.put("value", "1");
		mapA.put("name", "出租");
		shopChild.add(mapA);
		//子2
		Map<String,Object> mapB=new HashMap<String,Object>();
		mapB.put("value", "2");
		mapB.put("name", "出售");
		shopChild.add(mapB);
		//子3
		Map<String,Object> map3=new HashMap<String,Object>();
		map3.put("value", "3");
		map3.put("name", "转让");
		shopChild.add(map3);
		pShop.put("childrent", shopChild);
				
		//=====================start
		List<Map<String,Object>> officeChild=new ArrayList<Map<String,Object>>();
		Map<String,Object> map1=new HashMap<String,Object>();
		map1.put("value", "1");
		map1.put("name", "出租");
		officeChild.add(map1);
		//子2
		Map<String,Object> map2=new HashMap<String,Object>();
		map2.put("value", "2");
		map2.put("name", "出售");
		officeChild.add(map2);
		pOffice.put("childrent", officeChild);
		//=====================end
		resultObject.put("list", listParent);
		return resultObject;
	}
	
	
}
