package com.up.zpb.service.impl;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.up.zpb.annotation.Cacheable;
import com.up.zpb.mapper.AppDataMapper;
import com.up.zpb.mapper.AppUpgradeMapper;
import com.up.zpb.mapper.AreasMapper;
import com.up.zpb.mapper.ArticleMapper;
import com.up.zpb.mapper.BannerMapper;
import com.up.zpb.mapper.BrandContactsErrorMapper;
import com.up.zpb.mapper.BrandMapper;
import com.up.zpb.mapper.CrmCreateRecordMapper;
import com.up.zpb.mapper.CrmCustomerMapper;
import com.up.zpb.mapper.CrmNotifyMapper;
import com.up.zpb.mapper.CustomerMapper1;
import com.up.zpb.mapper.DictionaryMapper;
import com.up.zpb.mapper.MemberMapper;
import com.up.zpb.mapper.MogulMapper;
import com.up.zpb.mapper.OfficeMapper;
import com.up.zpb.mapper.PhoneRecordMapper;
import com.up.zpb.mapper.ShopBusinessTypeMapper;
import com.up.zpb.mapper.ShopConditionMapper;
import com.up.zpb.mapper.ShopMapper;
import com.up.zpb.mapper.SysCompanyMapper;
import com.up.zpb.redis.RedisBaseDao;
import com.up.zpb.service.AreasService;
import com.up.zpb.service.ArticleService;
import com.up.zpb.service.OfficeService;
import com.up.zpb.service.ShopAcreageService;
import com.up.zpb.service.ShopAreaExponentialService;
import com.up.zpb.service.ShopDailyRentExponentialService;
import com.up.zpb.service.ShopDealCountExponentialService;
import com.up.zpb.service.ShowInfoService;
import com.up.zpb.util.ConfigurationUtils;
import com.up.zpb.util.Constant;
import com.up.zpb.util.ObjectHelpUtils;
import com.up.zpb.util.UpzlUtils;
import com.up.zpb.vo.BrandContactsError;
import com.up.zpb.vo.CrmCreateRecord;
import com.up.zpb.vo.CrmCustomer;
import com.up.zpb.vo.CrmNotify;
import com.up.zpb.vo.PhoneRecord;
import com.up.zpb.vo.ResultObject;
import com.up.zpb.vo.Shop;
import com.up.zpb.vo.ShopAcreage;
import com.up.zpb.vo.ShopAreaExponential;
import com.up.zpb.vo.ShopDailyRentExponential;
import com.up.zpb.vo.enums.OfficeEnum;
import com.up.zpb.vo.enums.ProjectEnum;
import com.up.zpb.vo.enums.ShopEnum;

@Service
@Transactional(propagation = Propagation.SUPPORTS)
public class ShowInfoServiceImpl implements ShowInfoService {

	//private final String default_shop_img = "https://youpu-global.oss-cn-beijing.aliyuncs.com/shop_default.jpg";
	@Autowired
	BannerMapper bannerMapper;
	
	@Autowired
	SysCompanyMapper sysCompanyMapper;

	@Autowired
	AppUpgradeMapper appUpgradeMapper;

	@Autowired
	ShopDailyRentExponentialService shopDailyRentExponentialService;

	@Autowired
	ShopDealCountExponentialService shopDealCountExponentialService;

	@Autowired
	ShopAreaExponentialService shopAreaExponentialService;

	@Autowired
	ShopAcreageService shopAcreageService;
	
	@Autowired
	ArticleMapper articleMapper;
	
	@Autowired
	AppDataMapper appDataMapper;
	
	@Autowired
	BrandMapper brandMapper;
	
	@Autowired
	MogulMapper mogulMapper;
	
	@Autowired
	CustomerMapper1 customerMapper;
	
	@Autowired
	ShopConditionMapper shopConditionMapper;
	
	@Autowired
	AreasMapper areasMapper;
	
	@Autowired
	ShopMapper shopMapper;
	
	@Autowired
	RedisBaseDao redisBaseDao;
	
	@Autowired
	private CrmCustomerMapper crmCustomerMapper;
	
	@Autowired
	CrmCreateRecordMapper crmCreateRecordMapper;
	
	@Autowired
	DictionaryMapper dictionaryMapper;
	
	@Autowired
	CrmNotifyMapper crmNotifyMapper;
	
	@Autowired
	private OfficeMapper officeMapper;
	
	//@Autowired
	//private BusinessAreaMapper businessAreaMapper;
	
	@Autowired
	private AreasService areasService;
	@Autowired
	private ShopBusinessTypeMapper shopBusinessTypeMapper;
	@Autowired
	private PhoneRecordMapper phoneRecordMapper;
	@Autowired
	private OfficeService officeService;
	@Autowired
	private MemberMapper memberMapper;
	@Autowired
	private ArticleService articleService;
	@Autowired
	private BrandContactsErrorMapper brandContactsErrorMapper;
	
	

	private static final Logger logger = LoggerFactory.getLogger(ShowInfoServiceImpl.class);

	public final static String img = ConfigurationUtils.getStringValue("img_domain");

	@Override
	public Map<String, Object> getShowInfo(Map<String, Object> parameters) {
		logger.info("getShowInfo parameters:{}", parameters.get("cityId"));
		    Map<String, Object> map = Maps.newHashMap();
			/*parameters.put("img", img);
			map.put("imgUrl", bannerMapper.selectBannerMapper(parameters));// banner图
			//租金均价
			// 获取当年年份和月份
			SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
			Date date = new Date();
			String years = format.format(date).substring(0, 4);
			String monthly = format.format(date).substring(5, 7);
			parameters.put("years", years);
			parameters.put("monthly", monthly);
			// 获取最新的商铺日租金指数
			List<ShopDailyRentExponential> lists = shopDailyRentExponentialService.getNewestData(parameters);
			// 当月没有取上个月的值
			if (Objects.isNull(lists) || 0 == lists.size()) {
				parameters.put("monthly", getLastMonth());
				lists = shopDailyRentExponentialService.getNewestData(parameters);
			}
			ShopDailyRentExponential newestData = lists.get(0);
			map.put("dailyRent", newestData.getDailyRent());// 商铺指数
			BigDecimal setScale = convertToPercentage(newestData.getRingRate());
			if(setScale.toString().startsWith("-")) {
				map.put("shopRate", setScale.toString() + "%");// 商铺指数
			}else {
				map.put("shopRate", "+" + setScale.toString() + "%");// 商铺指数
			}
			
			//3条轮播资讯
			map.put("title", articleMapper.selectLimit3(parameters));
			Map<String, Object> appData = appDataMapper.selectDataByCityId(parameters);
			map.put("url", appData.get("url"));// 资讯链接地址
			map.put("zpUrl", appData.get("zpUrl"));// 找铺地址
			map.put("zhpUrl", appData.get("zhpUrl"));// 转铺地址
			map.put("serviceTel", appData.get("service_tel"));//咨询服务热线
			//品牌列表
			map.put("getBrandLogoList",getBrandLogoList(parameters).get("getBrandLogoList"));
			//大咖推荐列表
			map.put("higherlist",getBrandLogoList(parameters).get("higherlist"));
			//基数
			int count1 = shopMapper.select24NewShop(parameters);
			int count2 = shopMapper.select24FindShop(parameters);
			int count3 = shopMapper.select24ShopLineNum(parameters);
			map.put("shopNewNum", Integer.valueOf(appData.get("shopNewNum").toString()) + count1);//24小时新上
			map.put("peopleNum", Integer.valueOf(appData.get("peopleNum").toString()) + count2);//正在找铺
			map.put("shopLineNum", Integer.valueOf(appData.get("shopLineNum").toString())+count3);//在转商铺
			List<String> cities = areasMapper.selectByCityId(parameters.get("cityId").toString());
			map.put("cityName", cities.get(0).replace("市", ""));
			//独家实勘商铺列表
			map.put("djskList", createShop(djsk(parameters),"0","1"));
			redisBaseDao.hMSet(Constant.SYXQ + parameters.get("cityId").toString(), map);
			//指定过期时间
			redisBaseDao.expire(Constant.SYXQ + parameters.get("cityId").toString(), 60*5);	*/
		    return map;
	}

	@Override
	public ResultObject changeCity(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		List<Map<String, String>> list = sysCompanyMapper.changeCity(parameters.get("cityName").toString());
		logger.info("changeCity list-->" + list.size());
		if (Objects.isNull(list) || list.size() == 0) {
			List<Map<String, String>> defaultList = sysCompanyMapper.changeCity("北京市");
			Map<String, String> map = defaultList.get(0);
			resultObject.put("status", false);
			resultObject.put("cityId", map.get("city_id"));
			resultObject.put("provinceId", map.get("province_id"));
			resultObject.put("url", map.get("web_url"));
			resultObject.put("m_url", map.get("m_url"));
		} else {
			Map<String, String> map = list.get(0);
			resultObject.put("status", true);
			resultObject.put("cityId", map.get("city_id"));
			resultObject.put("provinceId", map.get("province_id"));
			resultObject.put("url", map.get("web_url"));
			resultObject.put("m_url", map.get("m_url"));
		}
		return resultObject;
	}

	@Override
	public ResultObject getUpgradeVersionInfo(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		String platform = parameters.get("platform")+"";
		 Map<String, Object> map = appUpgradeMapper.getUpgradeVersion(platform);
        resultObject.put("versionNum",  map.get("version_num"));
		 resultObject.put("versionName",  map.get("version_name"));
		 resultObject.put("updateDesc",  map.get("upgrade_desc"));
		 resultObject.put("download",  map.get("download_site"));
		 resultObject.put("forcedUpdating",  map.get("forced_updating"));
		 resultObject.put("isAudit",  map.get("is_audit"));
		return resultObject;
	}

	@Override
	public ResultObject getShopExponential(Map<String, Object> parameters) {
		logger.info("getShopExponential parameters:{}", parameters);
		ResultObject resultObject = new ResultObject();
		Map<String, Object> data = Maps.newHashMap();
			// 获取当年年份和月份
			SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
			Date date = new Date();
			String years = format.format(date).substring(0, 4);
			String monthly = format.format(date).substring(5, 7);
			Map<String, Object> mapParams = Maps.newHashMap();
			mapParams.put("years", years);
			mapParams.put("monthly", monthly);
			mapParams.put("cityId", parameters.get("cityId"));
			List<String> cities = areasMapper.selectByCityId(parameters.get("cityId").toString());
			// 获取最新的商铺日租金指数
			if(Objects.isNull(parameters.get("area"))) {
				parameters.put("area", "全" + cities.get(0).replace("市", ""));
			}
			List<ShopDailyRentExponential> lists = shopDailyRentExponentialService.getNewestData(mapParams);
			// 当月没有取上个月的值
			if (Objects.isNull(lists) || 0 == lists.size()) {
				mapParams.put("monthly", getLastMonth());
				lists = shopDailyRentExponentialService.getNewestData(mapParams);
			}
			ShopDailyRentExponential newestData = lists.get(0);
			data.put("dailyRent", newestData.getDailyRent());// 商铺指数
			BigDecimal setScale = convertToPercentage(newestData.getRingRate());
			if(setScale.toString().startsWith("-")) {
				data.put("shopRate", setScale.toString() + "%");// 商铺指数
			}else {
				data.put("shopRate", "+" + setScale.toString() + "%");// 商铺指数
			}
			//data.put("shopRate", "+" + setScale.toString() + "%");// 商铺指数
			// 构建返回参数
			List<Map<String, Object>> lm = new ArrayList<Map<String, Object>>();
			for (ShopDailyRentExponential sd : lists) {
				Map<String, Object> m = Maps.newHashMap();
				m.put("area", sd.getArea());
				m.put("dailyRent", sd.getDailyRent());
				lm.add(m);
			}
			// 根据区域查询最新的12条记录
			List<Map<String, Object>> dailyRentList = shopDailyRentExponentialService.selectByAreaName(parameters);
			List<Map<String, Object>> dailyList = new ArrayList<Map<String, Object>>();
			for (Map<String, Object> ma : dailyRentList) {
				Map<String, Object> m = Maps.newHashMap();
				String month = ma.get("monthly").toString();
				m.put("monthly", turnMonth(month));
				m.put("dailyRent", ma.get("dailyRent"));
				dailyList.add(m);
			}
			// 查询成交指数
			List<Map<String, Object>> dealCountList = shopDealCountExponentialService.selectByAreaName(parameters);
			List<Map<String, Object>> dealList = new ArrayList<Map<String, Object>>();
			for (Map<String, Object> deal : dealCountList) {
				Map<String, Object> m1 = Maps.newHashMap();
				String month = deal.get("monthly").toString();
				m1.put("monthly", turnMonth(month));
				m1.put("dealCount", deal.get("dealCount"));
				dealList.add(m1);
			}
			// 查询区域指数（商铺指数页面后三个图表）
			List<ShopAreaExponential> areaExponentialList = shopAreaExponentialService.selectByCityId(parameters);
			List<Map<String, Object>> shopRateList = new ArrayList<Map<String, Object>>();
			List<Map<String, Object>> dealRateList = new ArrayList<Map<String, Object>>();
			for (ShopAreaExponential area : areaExponentialList) {
				Map<String, Object> mapNew = Maps.newHashMap();
				Map<String, Object> mapNew2 = Maps.newHashMap();
				BigDecimal scale = convertToPercentage(area.getShopRate());
				mapNew.put("area", area.getArea());
				mapNew2.put("area", area.getArea());
				mapNew.put("shopRate", scale.toString() + "%");
				mapNew2.put("shopDealCount", area.getShopDealRate());
				shopRateList.add(mapNew);
				dealRateList.add(mapNew2);
			}
			List<ShopAcreage> shopAcreageLists = shopAcreageService.selectByCityId(parameters);
			List<Map<String, Object>> shopAcreageList = new ArrayList<Map<String, Object>>();
			for (ShopAcreage acreage : shopAcreageLists) {
				Map<String, Object> map = Maps.newHashMap();
				BigDecimal scale = convertToPercentage(acreage.getAcreageRate());
				map.put("acreageRate", scale.toString() + "%");
				map.put("acreage", acreage.getAcreage());
				shopAcreageList.add(map);
			}
			Collections.reverse(dealList);
			Collections.reverse(dailyList);
			data.put("dailyRentList", dailyList);
			data.put("dealCountList", dealList);
			data.put("list", lm);
			data.put("shopRateList", shopRateList);
			data.put("dealRateList", dealRateList);
			data.put("shopAcreageList", shopAcreageList);
			data.put("cityName", cities.get(0).replace("市", ""));
		resultObject.put("data", data);
		return resultObject;
	}

	private static String turnMonth(String month) {
		switch (month) {
		case "01":
			month = "1月";
			break;
		case "02":
			month = "2月";
			break;
		case "03":
			month = "3月";
			break;
		case "04":
			month = "4月";
			break;
		case "05":
			month = "5月";
			break;
		case "06":
			month = "6月";
			break;
		case "07":
			month = "7月";
			break;
		case "08":
			month = "8月";
			break;
		case "09":
			month = "9月";
			break;
		case "10":
			month = "10月";
			break;
		case "11":
			month = "11月";
			break;
		case "12":
			month = "12月";
			break;
		}
		return month;
	}

	/**
	 * 获取上一个月
	 * 
	 * @return
	 */
	public static String getLastMonth() {
		Calendar cal = Calendar.getInstance();
		cal.add(Calendar.MONTH, -1);
		SimpleDateFormat dft = new SimpleDateFormat("MM");
		String lastMonth = dft.format(cal.getTime());
		return lastMonth;
	}

	public static BigDecimal convertToPercentage(BigDecimal num) {
		BigDecimal setScale = num.multiply(new BigDecimal(100)).setScale(2, BigDecimal.ROUND_UP);
		return setScale;
	}
	
	
	private Map<String,Object> getBrandLogoList(Map<String,Object> map){
		Map<String,Object> result = Maps.newHashMap();
		map.put("img", img);
		if(Objects.nonNull(map.get("type")) && StringUtils.equals("pc", map.get("type").toString())) {
			map.put("limit", 5);
		}else {
			map.put("limit", 20);
		}
		result.put("getBrandLogoList", brandMapper.selectBrandLogo(map));
		result.put("higherlist",mogulMapper.selectMogulList(map));
		return result;
	}

	@Override
	@Cacheable(expireTime=60*60)
	public ResultObject getBrandList(Map<String, Object> parameters) {
		logger.info("【=======================getBrandList()开始："+parameters+"】");
		ResultObject resultObject = new ResultObject();
		try {
			this.officeService.analysisLeftRight(parameters);//解析搜索条件id为区间
			Integer pageSize = Integer.valueOf((String)parameters.get("pageSize"));
			Integer pageNum = Integer.valueOf((String)parameters.get("pageNum"));
			Page<Object> startPage = PageHelper.startPage(pageNum, pageSize, true);
			List<Map<String, Object>> brandList = brandMapper.getBrandList(parameters);
			resultObject.put("brandList", brandList);
			resultObject.put("totalCount", startPage.getTotal());
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【=======================getBrandList()结束："+resultObject+"】");
		return resultObject;
	}

	

	
	
	
	
	/**
	 * 格式化面积
	 * eg：需求面积：80-150㎡   
	 * @param areaLower
	 * @param areaUpper
	 * @return
	 */
	public String formatMianJi(Object areaLower,Object areaUpper){
		String area="";
		if((Objects.nonNull(areaLower) && Objects.nonNull(areaUpper))) {
			Integer lower = Integer.valueOf(areaLower.toString());
			Integer upper = Integer.valueOf(areaUpper.toString());
			if(lower==upper) {
				area =areaLower+"㎡";
			}else {
				area =areaLower+"-" + areaUpper+"㎡";
			}
		}else if(Objects.nonNull(areaLower) && Objects.isNull(areaUpper)) {
			 area =areaLower+"㎡";
		}else if(Objects.isNull(areaLower) && Objects.nonNull(areaUpper)) {
			 area =areaUpper+"㎡";
		}else {
			area ="不限";
		}
		return area;
	}
	
	
	/**
	 * 格式化合作期限
	 * eg：合作期限：5年   
	 * @param cooperationLower
	 * @param cooperationUpper
	 * @return
	 */
	public String formatCooperation(Object cooperationLower,Object cooperationUpper){
		String cooperation="";
		if(Objects.nonNull(cooperationLower) && Objects.nonNull(cooperationUpper)) {
			Integer lower = Integer.valueOf(cooperationLower.toString());
			Integer upper = Integer.valueOf(cooperationUpper.toString());
			if(lower==upper) {
				cooperation =cooperationLower+"年";
			}else {
				cooperation= cooperationLower+"-" +cooperationUpper+"年"; 
			}
		}else if(Objects.nonNull(cooperationLower) && Objects.isNull(cooperationUpper)) {
			cooperation= cooperationLower+"年"; 
		}else if(Objects.isNull(cooperationLower) && Objects.nonNull(cooperationUpper)) {
			cooperation= cooperationLower+"年"; 
		}else {
			cooperation="不限";
		}
		return cooperation;
	}

	

	@Override
	public ResultObject addCutomer(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
//		String msg = StringUtils.EMPTY;
//		try {
//			int count = customerMapper.getCount(parameters);
//			if(0==count) {
//				Customer customer = new Customer();
//				customer.setCityId(Integer.valueOf(parameters.get("cityId").toString()));
//				customer.setProvinceId(Integer.valueOf(parameters.get("provinceId").toString()));
//				customer.setCreateTime(new Date());
//				customer.setUpdateTime(new Date());
//				Integer channel =0;
//				String source = parameters.get("source").toString();
//				customer.setPlatform(Integer.valueOf(source));
//				 if(StringUtils.equals("0",source)) {
//			          	channel= 0;
//			        }
//			        if(StringUtils.equals("1",source)) {
//			          	channel= 0;
//			        }
//			        if(StringUtils.equals("2",source)) {
//			          	channel= 1;
//			        }
//			        if(StringUtils.equals("3",source)) {
//			          	channel= 2;
//			        }
//				customer.setChannel(channel);
//				customer.setPhone(parameters.get("account").toString());
//				customer.setType(Integer.valueOf(parameters.get("type").toString()));
//				customerMapper.insert(customer);
//				msg="委托成功，优铺客服会在24小时内与您联系，请保持手机畅通!";
//				// 0 委托找铺 1 委托转铺 去重后进入客源
//				addCrmCustomer(parameters);
//				if(StringUtils.equals("1", parameters.get("type").toString())) {
//				addShop(parameters);
//				}
//			}else {
//				int hCount = customerMapper.get24HCount(parameters);
//				if(0!=hCount) {
//					customerMapper.update(parameters);
//					msg="委托成功，优铺客服会在24小时内与您联系，请保持手机畅通!";
//				}else {
//					msg="已委托，请勿重复提交!";
//				}
//			}
//		} catch (NumberFormatException e) {
//			e.printStackTrace();
//			msg="暂时无法提交!";
//			resultObject.put("msg", msg);
//			return resultObject;
//		}
//		resultObject.put("msg", msg);
		return resultObject;
	}

	@Override
	public ResultObject showInfoPC(Map<String, Object> parameters,String indexKey) {
		ResultObject resultObj = new ResultObject();
		logger.info("【================showInfoPC入参:{}", ObjectHelpUtils.MapToString(parameters)+"】");
		parameters.put("ifIndex","2");
		
		//商业资讯
		parameters.put("adress","0");
		ResultObject   articleInfo=this.articleService.findArticleIndex(parameters);
		resultObj.put("articleInfo",articleInfo);
		
		//banner列表
		parameters.put("type", "0");
		resultObj.put("bannerList", bannerMapper.selectBannerMapperPC(parameters));
		//商铺出售  areaId
		resultObj.put("shopSaleList", this.findShopList(parameters.get("cityId")+"", ShopEnum.RentType.SALE.getValue()));		
		//商铺出租
		resultObj.put("shopRentList", this.findShopList(parameters.get("cityId")+"", ShopEnum.RentType.RENT.getValue()));
		//商业新盘
		resultObj.put("shopNewList", this.findShopList(parameters.get("cityId")+"", ShopEnum.RentType.NEWS_SALE.getValue()));
		
		
		//写字楼出售
		resultObj.put("officeSaleList", this.findOfficeList(parameters.get("cityId")+"",OfficeEnum.TypeSale.SALE.getValue()));
		//写字楼出租
		resultObj.put("officeRentList", this.findOfficeList(parameters.get("cityId")+"",OfficeEnum.TypeSale.RENT.getValue()));
		//写字楼新盘
		resultObj.put("officeNewList", this.findOfficeList(parameters.get("cityId")+"",OfficeEnum.TypeSale.NEWS_SALE.getValue()));
		
		//存入缓存，并且指定过期时间
		redisBaseDao.hMSet(indexKey, resultObj);
		redisBaseDao.expire(indexKey,Constant.CACHE_EXP_ONE_HOUR);	
		return resultObj;
	}
	
	
	
	@Override
	public List<Map<String,Object>> findShopList(String cityId,String rentType){
		Map<String, Object> paraMap=new HashMap<String, Object>();
		paraMap.put("cityId", cityId);
		if("-1".equals(rentType)){
			paraMap.put("news", rentType);
			paraMap.put("limit", 4);
		}else if("4".equals(rentType)){
			paraMap.put("rentType", rentType);
			paraMap.put("limit", 5);//app首页新盘5条
		}else{
			paraMap.put("rentType", rentType);
			paraMap.put("limit", 4);
		}
		paraMap.put("ifIndex","2");
		List<Map<String,Object>> list=shopMapper.selectShopList(paraMap);
		if(list!=null && list.size()>0){
			for(Map<String,Object> temp:list){
				List<String> labelArr=this.findLabelByObjId(temp.get("id")+"", ProjectEnum.ProjectType.SHOP.getValue(),ShopEnum.SHOP_LABEL_KEY);
				temp.put("label", labelArr);
			}
		}
		return list;
	}
	
	
	/**
	 * 查找标签，只返回name
	 * objectId:shopId或者officeId
	 * type：1-商铺 2-写字楼
	 * @param objectId
	 * @param type
	 * @return
	 */
	@Override
	public List<String> findLabelByObjId(String objectId,String type,String parentKey){
		Map<String,Object> map = Maps.newHashMap();
		map.put("objectId", objectId);
		map.put("type", type);
		map.put("dicType", parentKey);
		String label= this.officeMapper.findLabelStr(map);
		if(Objects.nonNull(label)){
			return 	Arrays.asList(label.split(","));
		}else{
			return  new ArrayList<String>();
		}
	}
	
	/**
	 * 标签，返回id，name 
	 * @param objectId
	 * @param type
	 * @param parentKey
	 * @return
	 */
	@Override
	public List<Map<String,Object>> findLabelByOid2(String objectId,String type,String parentKey){
		Map<String,Object> map = Maps.newHashMap();
		map.put("objectId", objectId);
		map.put("type", type);
		map.put("dicType", parentKey);
		List<Map<String,Object>> resMap= this.officeMapper.findLabelByOid2(map);
		if(Objects.nonNull(resMap)){
			return 	resMap;
		}else{
			return  new ArrayList<Map<String,Object>>();
		}
	}
	
	
	
	@Override
	public  List<Map<String,Object>> findOfficeList(String cityId,String rentType){
		Map<String,Object> officeSaleMap=new HashMap<String, Object>();
		officeSaleMap.put("onlineStatus", "1");
		officeSaleMap.put("cityId", cityId);
		if("-1".equals(rentType)){
			officeSaleMap.put("news", rentType);
			officeSaleMap.put("limit", 4);
		}else if("4".equals(rentType)){
			officeSaleMap.put("rentType", rentType);
			officeSaleMap.put("limit", 5);//app首页新盘5条
		}else{
			officeSaleMap.put("rentType", rentType);
			officeSaleMap.put("limit", 4);
		}
		officeSaleMap.put("ifIndex","2");
		List<Map<String,Object>>  list=this.officeMapper.findList(officeSaleMap);
		if(list!=null && list.size()>0){
			for(Map<String,Object> temp:list){
				List<String> labelArr=this.findLabelByObjId(temp.get("id")+"", ProjectEnum.ProjectType.OFFICE.getValue(),OfficeEnum.OFFICE_LABEL_KEY);
				temp.put("label", labelArr);
			}
		}
		return list;
	}

	/**
	 * 独家实勘
	 * @param parameters
	 * @return
	 */
	private List<Map<String,Object>> djsk(Map<String, Object> parameters){
		List<Map<String,Object>> list = Lists.newArrayList();
		/*Map<String, Object> appData = appDataMapper.selectDataByCityId(parameters);
		String cityId = parameters.get("cityId").toString();
		String djsk = appData.get("djskArea").toString();
		String[] split = djsk.split(",");
		List<Map<String, Object>> top1 = shopMapper.selectShopList(cityId,split[0],3,"","");
		List<Map<String, Object>> top2 = shopMapper.selectShopList(cityId,split[1],2,"","");
		List<Map<String, Object>> top3 = shopMapper.selectShopList(cityId,split[2],2,"","");
		List<Map<String, Object>> top4 = shopMapper.selectShopList(cityId,split[3],1,"","");
		List<Map<String, Object>> top5 = shopMapper.selectShopList(cityId,split[4],1,"","");
		List<Map<String, Object>> top6 = shopMapper.selectShopList(cityId,split[5],1,"","");
		if (CollectionUtils.isEmpty(top1)) {

		} else {
			int add = 0;
			if (top1.size() >= 3) {
				list.addAll(top1.subList(0, 3));
				add = 2;
			} else {
				add = top1.size() - 1;
				list.addAll(top1.subList(0, top1.size() - 1));
			}
			int diffTz = 2 - top2.size();
			if (diffTz > 0) {
				for (int i = 0; i < diffTz; i++) {
					add += 1;
					if (top1.size() > add) {
						top2.add(top1.get(add));
					}
				}
			}

			int diffDx = 2 - top3.size();
			if (diffDx > 0) {
				for (int i = 0; i < diffDx; i++) {
					add += 1;
					if (top1.size() > add) {
						top3.add(top1.get(add));
					}

				}
			}

			int diffFt = 1 - top4.size();
			if (diffFt > 0) {
				for (int i = 0; i < diffFt; i++) {
					add += 1;
					if (top1.size() > add) {
						top4.add(top1.get(add));
					}

				}
			}
			int diffCp = 1 - top5.size();
			if (diffCp > 0) {
				for (int i = 0; i < diffCp; i++) {
					add += 1;
					if (top1.size() > add) {
						top5.add(top1.get(add));
					}

				}
			}
			
			int diffHd = 1 - top6.size();
			if (diffHd > 0) {
				for (int i = 0; i < diffHd; i++) {
					add += 1;
					if (top1.size() > add) {
						top6.add(top1.get(add));
					}

				}
			}
		}
		list.addAll(top2);
		list.addAll(top3);
		list.addAll(top4);
		list.addAll(top5);
		list.addAll(top6);*/
		return list;
	}
	
	public List<Map<String,Object>> createShop(List<Map<String,Object>> list,String type,String source){
		List<Map<String,Object>> shop = Lists.newArrayList();
		/*// 1代表要插入广告标识
		if (StringUtils.equals(type, "1") && StringUtils.equals(source, "1")) {
			Map<String,Object> map = Maps.newHashMap();
			map.put("remark", "0");
			if (list.size() >= 4 && list.size() <= 9) {
				list.add(3, map);
			} else if (list.size() >= 9) {
				list.add(3, map);
				list.add(9, map);
			}
		}
		List<String> shopTags = new ArrayList<String>();
		for(Map<String,Object> map :list) {
			if(Objects.isNull(map.get("remark")) || !StringUtils.equals("0", map.get("remark").toString())) {
				// 商铺图片
			    String img = StringUtils.EMPTY;
			   // 租金单位 （元、万元）
				String unit = StringUtils.EMPTY;
				 map.put("remark", "1");
				 if(Objects.nonNull(map.get("video")) && StringUtils.isNotBlank(map.get("video").toString())) {
					 String video = map.get("video").toString(); 
					 img =video.concat("?x-oss-process=video/snapshot,t_7000,f_jpg,w_500,h_300,m_fast");
				 }else {
					 if (Objects.nonNull(map.get("cover")) && StringUtils.isNotBlank(map.get("cover").toString())) {
						 img = map.get("cover").toString();
						 if (img.contains("x-oss-process")) {
							 img = img.replace("style/watermark", "style/thumbnail");
							} else {
								img = img + "?x-oss-process=style/thumbnail";
							}
					 }else if (Objects.nonNull(map.get("imgs"))) {
						String imgStr = map.get("imgs").toString();
						String[] split = imgStr.split(",");
						img = split[0].replace("style/watermark", "style/thumbnail");
					 }else {
						 img = default_shop_img;
					 } 
				 }
					// 月租金
					if (Objects.nonNull(map.get("monthly_rent"))) {
						BigDecimal monthlyRent = new BigDecimal(map.get("monthly_rent").toString());
						if (monthlyRent.intValue() == -2) {
							map.put("monthlyRent", "面议");
						} else {
							if (Objects.nonNull(monthlyRent) && monthlyRent.longValue() > 9999) {
								unit = "万/月";
								monthlyRent = monthlyRent.divide(new BigDecimal(10000)).setScale(2,
										BigDecimal.ROUND_HALF_UP);
							} else {
								unit = "元/月";
							}
							map.put("monthlyRent", monthlyRent.toString().replace(".00", ""));
						}
					} else if ((Objects.isNull(map.get("monthly_rent"))) && (Objects.nonNull(map.get("turnover_share")))) {
						unit = "";
						map.put("monthlyRent", "营业额分成");
					} else {
						map.put("monthlyRent", StringUtils.EMPTY);
					}
					// 月租金单位
					map.put("unit", unit);
					// 新增转让费字段
					
					String transferFee = StringUtils.EMPTY;
					String unitTransFerfee = StringUtils.EMPTY;
					if (Objects.nonNull(map.get("transfer_fee"))) {
						BigDecimal fee =new BigDecimal(map.get("transfer_fee").toString());
						if (fee.intValue() == -1) {
							transferFee = "无";
						} else if (fee.intValue() == -2) {
							transferFee = "面议";
						} else {
							transferFee = fee.setScale(2, BigDecimal.ROUND_HALF_UP).toString().replace(".00", "");
							unitTransFerfee = "万元";
							map.put("unitTransFerfee", unitTransFerfee);
						}
					} else {
						transferFee = "无";
					}
					if(Objects.nonNull(map.get("tag")) && StringUtils.isNotBlank(map.get("tag").toString())) {
						String tags = map.get("tag").toString();
						map.put("shopTags",Arrays.asList(tags.split(",")));
					}else {
						map.put("shopTags", shopTags);
					}
					String labe=StringUtils.EMPTY;
					if(Objects.nonNull(map.get("type")) && StringUtils.isNotBlank(map.get("type").toString())) {
						if(map.get("type").toString().contains("4")) {
							labe="4";
						}else if(map.get("type").toString().contains("3") && !map.get("type").toString().contains("4")) {
							labe="3";
						}else if(map.get("type").toString().contains("2") && !map.get("type").toString().contains("3")
							&& !map.get("type").toString().contains("4")) {
							labe="2";
						}else if(Arrays.asList(map.get("type").toString()).contains("1") && !map.get("type").toString().contains("3")
								&& !map.get("type").toString().contains("4") && !map.get("type").toString().contains("2")) {
							labe="1";
							}
					}
					if(Objects.nonNull(map.get("topStatus")) && StringUtils.equals("1", map.get("topStatus").toString())) {
						labe="4";
					}
					map.put("transferFee", transferFee);
					map.put("img", img);
					map.put("type", labe);
					map.remove("cover");
					map.remove("imgs");
					map.remove("transfer_fee");
					map.remove("turnover_share");
					map.remove("monthly_rent");
					map.remove("tag");
			}else {
				map.put("unitTransFerfee", "");
				map.put("transferFee", "");
				map.put("monthlyRent", "");
				map.put("title", "");
				map.put("shopName", "");
				map.put("shopTags", shopTags);
				map.put("unit", "");
				map.put("id", "");
				map.put("img", "");
				map.put("topStatus", "");
				map.put("type", "");
			}
			shop.add(map);
		}*/
		return shop;
		
	}

	@Override
	public ResultObject selectNumber(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		Map<String, Object> data = appDataMapper.selectDataByCityId(parameters);
		int count2 = shopMapper.select24FindShop(parameters);
		int count3 = shopMapper.select24ShopLineNum(parameters);
		resultObject.put("peopleNum", Integer.valueOf(data.get("peopleNum").toString()) + count2);//正在找铺
		resultObject.put("shopLineNum", Integer.valueOf(data.get("shopLineNum").toString())+count3);//在转商铺
		return resultObject;
	}
	
	/**
	 * 同步委托找铺数据到 客源系统
	 */
	public synchronized void addCrmCustomer(Map<String,Object> map) {
		//去重并保存
		map.put("paramPhone", map.get("account"));
		int count = crmCustomerMapper.selectByPhone(map);
		if(0==count) {
			CrmCustomer customerNew = new CrmCustomer();
			customerNew.setPhone(map.get("account").toString());
			// 0 官网,1  M站, 2 APP
			Integer createType =0;
			//0 Android 1 IOS 2 官网 3 M站
			if(StringUtils.equals("0", map.get("source").toString()) || StringUtils.equals("1", map.get("source").toString())) {
				createType= 4;
			}else if(StringUtils.equals("2", map.get("source").toString())) {
				createType= 5;
			}else {
				createType= 3;
			}
			customerNew.setCreateTime(new Date());
			customerNew.setUpdateTime(new Date());
			customerNew.setCreateType(createType);
			customerNew.setFollowStatus(0);	//全部客户类别
			customerNew.setNodeStatus(0);//全部客户
			customerNew.setCityId(Integer.valueOf(map.get("cityId").toString()));
			customerNew.setCusId(getNextCustomerID("C"));
			crmCustomerMapper.save(customerNew);
			saveNotify(map,createType);
			createCrmCreateRecord(map,createType);
		}
		
	}
	
	/**
	 * 新增委托转铺待认领店铺
	 * 
	 * @param account
	 */
	public void addShop(Map<String,Object> map) {
		int count = shopMapper.selectByPhone(map);
		if(0==count) {
			Shop shop = new Shop();
			shop.setPhone(map.get("account").toString());
			shop.setCreateType(8);
			shop.setShopFlow(0);
			shop.setOnlineStatus(0);
			shop.setIsImport(0);
			shop.setCity(Integer.valueOf(map.get("cityId").toString()));
			shop.setCreateTime(new Date());
			shopMapper.save(shop);
		}
	} 

	public void createCrmCreateRecord(Map<String,Object> map,Integer createType) {
		int selectCount = crmCreateRecordMapper.selectCount(map);
		if(0== selectCount) {
			CrmCreateRecord ccr = new CrmCreateRecord();
			ccr.setCityId(Integer.valueOf(map.get("cityId").toString()));
			ccr.setCreateTime(new Date());
			ccr.setMobile(map.get("account").toString());
			ccr.setCreateType(createType);
			crmCreateRecordMapper.saveCreateRecord(ccr);	
		  }
	  }
	
	public void saveNotify(Map<String,Object> map,Integer createType) {
		 CrmNotify notify = new CrmNotify();
		 map.put("key", "191");
		 map.put("createType", createType);
		 String name = dictionaryMapper.selectByDValue(map);
		 String type="找铺客户";//0 委托找铺 1 委托转铺
		 if(Objects.nonNull(map.get("type"))) {
			if(StringUtils.equals("1", map.get("type").toString())) {
				type="转铺客户";
			}else {
				type="找铺客户";
			}
		 }
		 notify.setTitle(name+type+"【"+map.get("account")+"】");
		 notify.setContent(name+type+"【"+map.get("account")+"】");
		 notify.setType(0);	//0:新增数据类
		 notify.setStatus(0);
		 notify.setCreateType(createType);
		 notify.setCreateTime(new Date());
		 notify.setCityId(Integer.valueOf(map.get("cityId").toString()));
		 crmNotifyMapper.insert(notify);
	  }

	@Override
	public String getNextCustomerID(String pre) {
		/*String cusId = crmCustomerMapper.selectMaxCusId();
		if (StringUtils.isEmpty(cusId)) {
			cusId= "110000";
		} else {
			DecimalFormat df = new DecimalFormat("000000");
			cusId = df.format(Long.valueOf(cusId) + 1);
			logger.info("系统生成商铺编号: "+cusId);
		}*/
		int rd = (int) ((Math.random() * 9 + 1) * 10000000);//前缀+8位随机数
		return pre+rd;
	}
	
	

	@Override
	public ResultObject findBrandDetail(Map<String, Object> parameters) {
		logger.info("【=======================findBrandDetail()开始："+parameters+"】");
		String brandId=parameters.get("brandId")+"";
		ResultObject resultObject = new ResultObject();
		try {
			Map<String, Object> entity = brandMapper.findBrandDetail(brandId);
			entity.put("brandType", this.brandMapper.findBrandYeTaiNameById(entity.get("brand_type_id")+""));
			if( !ObjectHelpUtils.isMyNull(entity.get("imgs")+"")){
				String pre="https://up-sell.oss-cn-beijing.aliyuncs.com";
				String[] imgArr=String.valueOf(entity.get("imgs")).split(",");
				List<String> imgList=new ArrayList<String>();
				for(String item:imgArr){
					String urlAll=pre+item;
					if(item.contains("http")){
						urlAll=item;
					}
					imgList.add(urlAll);
				}
				entity.put("imgsList",imgList);
			}else{
				if( !ObjectHelpUtils.isMyNull(entity.get("img")+"")){
					//如果详情列表没有图，把logo图放到list里
					entity.put("imgsList",Arrays.asList(String.valueOf(entity.get("img")).split(",")));
				}else{
					entity.put("imgsList",new ArrayList<String>());
				}
			}
			entity.put("brand_id", brandId);
			resultObject.put("entity", entity);
			
			List<Map<String, Object>> userList =brandMapper.findUserListByBId(brandId);
			if(userList !=null && userList.size()>0){
				for(Map<String, Object> temp:userList){
					//true-显示电话号码；false-不显示
					temp.put("show", "false");
					if(temp.get("phone")!=null){
						parameters.put("phone", temp.get("phone"));
						PhoneRecord en=this.phoneRecordMapper.findEntity(parameters);//userId
						if(en!=null){
							temp.put("show", "true");//查看过，显示
						}
					}
					//被纠错的经纪人，是否在审核中(1-待审核；2-已审核；3-未通过审核)
					BrandContactsError errEn=this.brandContactsErrorMapper.findNearBrandStatus(temp.get("linkmanId")+"");
					if(errEn!=null && 1==errEn.getFlag()){
						temp.put("isError", "1");
					}else{
						temp.put("isError", "0");
					}
					
				}
			}
			resultObject.put("userList", userList);

			//存入缓存，并且指定过期时间
			//redisBaseDao.hMSet(Constant.BRAND_DETAIL + parameters.get("brandId").toString(), resultObject);
			//redisBaseDao.expire(Constant.BRAND_DETAIL + parameters.get("brandId").toString(), Constant.CACHE_EXP_ONE_HOUR);	
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【=======================findBrandDetail()结束："+resultObject+"】");
		return resultObject;
	}
	
	
	
	@Override
	public ResultObject findBrandSearch(Map<String, Object> parameters) {
		logger.info("【=======================findBrandSearch()开始："+parameters+"】");
		ResultObject resultObject = new ResultObject();
		try {
			parameters.put("type", Constant.CONDITION_TYPE_AREA);
			resultObject.put("mianjiList", shopConditionMapper.selectByCityId(parameters));
			resultObject.put("regionList", this.areasService.findRegionsListApp());
			if(Constant.CHANNEL_IOS.equals(parameters.get("channel")+"") || Constant.CHANNEL_ANDROID.equals(parameters.get("channel")+"") ){
				resultObject.put("yeTaiList", this.areasService.findBrandYeTaiListApp());
			}else{
				//resultObject.put("regionList", this.areasService.findRegionsList());
				resultObject.put("yeTaiList", this.areasService.findBrandYeTaiList());
			}
			List<Map<String,Object>> brandNatureList=new ArrayList<Map<String,Object>>();
			Map<String,Object> map1=new HashMap<String,Object>();
			map1.put("id", "1");
			map1.put("name", "直营");
			brandNatureList.add(map1);
			Map<String,Object> map2=new HashMap<String,Object>();
			map2.put("id", "2");
			map2.put("name", "加盟");
			brandNatureList.add(map2);
			resultObject.put("brandNatureList", brandNatureList);
			
			//存入缓存，并且指定过期时间
			redisBaseDao.hMSet(Constant.FIIND_BRAND_SEARCH + parameters.get("cityId").toString(), resultObject);
			redisBaseDao.expire(Constant.FIIND_BRAND_SEARCH + parameters.get("cityId").toString(), Constant.CACHE_EXP_DAY);	
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		logger.info("【=======================findBrandSearch()结束："+resultObject+"】");
		return resultObject;
	}
	
	
	
	@Override
	public ResultObject savePhoneRecord(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		try {
			
			//查看是否是VIP无限查看
			parameters.put("id", parameters.get("userId"));
			int userCount=this.memberMapper.findByUserId(parameters);
			if(userCount >=1){
				resultObject.put("warnCode", "");
				return resultObject;
			}
			
			//已经拨打过可以再次打，不记录次数
			Map<String,Object> phoneMap=new HashMap<String, Object>();
			phoneMap.put("userId", parameters.get("userId"));
			phoneMap.put("phone", parameters.get("phone"));
			phoneMap.put("startDay",UpzlUtils.getDayStart(new Date()));
			phoneMap.put("endDay", UpzlUtils.getDayEnd(new Date()));
			PhoneRecord phoneEntity=this.phoneRecordMapper.findEntity(phoneMap);
			if(phoneEntity!=null){
				resultObject.put("warnCode", "");
				return resultObject;
			}
			
			if(Constant.CHANNEL_IOS.equals(parameters.get("channel"))){
				return this.savePhoneRecordIOS(parameters);
			}
			parameters.put("startDay",UpzlUtils.getDayStart(new Date()));
			parameters.put("endDay", UpzlUtils.getDayEnd(new Date()));
			int num=this.phoneRecordMapper.sumNumber(parameters);
			if(num>=3){
				resultObject.setCode(666666);
				resultObject.setMessage("今日访问已达3次！");
				return resultObject;
			}
			PhoneRecord newEn=new PhoneRecord();
			newEn.setUserId(Integer.valueOf(parameters.get("userId")+""));
			newEn.setBrandId(Integer.valueOf(parameters.get("brandId")+""));
			newEn.setPhone(parameters.get("phone")+"");
			newEn.setCreateTime(new Date());
			this.phoneRecordMapper.savePhoneRecord(newEn);
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	public ResultObject savePhoneRecordIOS(Map<String, Object> parameters) {
		ResultObject resultObject = new ResultObject();
		try {
			parameters.put("startDay",UpzlUtils.getDayStart(new Date()));
			parameters.put("endDay", UpzlUtils.getDayEnd(new Date()));
			int num=this.phoneRecordMapper.sumNumber(parameters);
			if(num>=3){
				resultObject.put("warnCode", 666666);
				return resultObject;
			}
			PhoneRecord newEn=new PhoneRecord();
			newEn.setUserId(Integer.valueOf(parameters.get("userId")+""));
			newEn.setBrandId(Integer.valueOf(parameters.get("brandId")+""));
			newEn.setPhone(parameters.get("phone")+"");
			newEn.setCreateTime(new Date());
			this.phoneRecordMapper.savePhoneRecord(newEn);
			resultObject.put("warnCode", "");
		} catch (Exception e) {
			resultObject.setCode(Constant.CODE_EXCEPTION);
			resultObject.setMessage("系统异常");
			logger.error(e.getMessage(), e);
		}
		return resultObject;
	}
	
	
	
	
	
	
	
}

	
