package com.up.zpb.util;

import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.up.zpb.mapper.MemberMapper;
import com.up.zpb.mapper.ProjectOrderMapper;
import com.up.zpb.mapper.ShopMapper;
import com.up.zpb.mapper.UserOperRecordsMapper;
import com.up.zpb.vo.Member;
import com.up.zpb.vo.MemberOrder;
import com.up.zpb.vo.ProjectOrder;
import com.up.zpb.vo.Shop;
import com.up.zpb.vo.UserOperRecords;

public class PayUtils {
	
	private static final Logger log = LoggerFactory.getLogger(PayUtils.class);
	
	
	/**
	 * 创建会员相关信息
	 * @param order
	 * @param memberMapper
	 */
	public static void createMember(MemberOrder order,MemberMapper memberMapper,ShopMapper shopMapper,Integer dura,UserOperRecordsMapper userOperRecordsMapper) {
		//查看是否已购买同类型的会员
		Map<String,Object> map = new HashMap<String,Object>();
		map.put("userId", order.getUserId());
		map.put("type", order.getOrderType());
		map.put("cityId", order.getCityId());
		log.info("PayUtils createMember  map:{}",map);
		List<Member> members = memberMapper.selectByType(map);
		if(Objects.nonNull(members) && members.size()>0) {
		 Member member = members.get(0);
		 log.info("PayUtils createMember  member type--->" + member.getType());
		//0 优铺会员 3 置顶服务 4 转铺会员
		if(0 ==member.getType() || 3 ==member.getType() || 4 ==member.getType()) {
			member.setUpdateTime(new Date());
			member.setOrderId(order.getId());//订单id
			member.setProductId(order.getProductId());//产品id
			member.setEndDate(getEndDate(member.getEndDate(),dura));
			memberMapper.updateByPrimaryKey(member);
			log.info("PayUtils createMember  member update success--->" + member.getType());
		}else if(order.getProductId() == member.getProductId()){
			member.setUpdateTime(new Date());
			member.setOrderId(order.getId());//订单id
			member.setProductId(order.getProductId());//产品id
			member.setEndDate(getEndDate(member.getEndDate(),dura));
			memberMapper.updateByPrimaryKey(member);
			log.info("PayUtils createMember  member update success--->" + member.getType());
		}else {
			//创建会员记录
			Member m = new Member();
			Integer userId = order.getUserId();
			m.setUserId(userId);
			m.setOrderId(order.getId());//订单id
			m.setStatus(1); // 0 无效 1 有效
			m.setProductId(order.getProductId());//产品id
			m.setType(order.getOrderType());//会员类型
			m.setCityId(order.getCityId());//城市id
			m.setCreateTime(new Date());//创建时间
			m.setUpdateTime(new Date());//更新时间
			m.setEndDate(getEndDate(new Date(),dura));//到期日期
			memberMapper.insert(m);
			log.info("PayUtils createMember  member insert success--->" + member.getType());
			}
		}else {
			//创建会员记录
			Member member = new Member();
			Integer userId = order.getUserId();
			member.setUserId(userId);
			member.setOrderId(order.getId());//订单id
			member.setStatus(1); // 0 无效 1 有效
			member.setProductId(order.getProductId());//产品id
			member.setType(order.getOrderType());//会员类型
			member.setCityId(order.getCityId());//城市id
			member.setCreateTime(new Date());//创建时间
			member.setUpdateTime(new Date());//更新时间
			member.setEndDate(getEndDate(new Date(),dura));//到期日期
			memberMapper.insert(member);
			log.info("PayUtils createMember  member insert success--->" + member.getType());
		}
		if(4 == order.getOrderType()) {
			List<Shop> shops = shopMapper.selectShopByUserId(map);
			for(Shop s : shops) {
				if(Objects.isNull(s.getTopStatus()) || 0 ==s.getTopStatus()) {
					topShop(s,dura,shopMapper,0);
				}else {
					topShop(s,dura,shopMapper,1);
				}
			}
		}
		//创建看铺次数记录
		UserOperRecords uor = new UserOperRecords();
		uor.setCityId(order.getCityId());
		uor.setCount("+25");
		uor.setCreateTime(new Date());
		uor.setType(2);
		uor.setUserId(order.getUserId());
		userOperRecordsMapper.insert(uor);
	}
	
	/**
	 * 获取服务结束日期
	 * @param date
	 * @param type
	 * @return
	 */
	public static Date getEndDate(Date date,Integer status) {
		Calendar calendar = Calendar.getInstance();
		calendar.setTime(date);
		calendar.add(Calendar.MONTH, status);
		calendar.add(Calendar.DAY_OF_MONTH, -1);
		return calendar.getTime();
	}
	
	 public static void topShop(Shop s,Integer dura,ShopMapper shopMapper,Integer type){
		 if(0==type) {
			 s.setTopBeginTime(new Date());
			 s.setTopEndTime(getEndDate(new Date(),dura));
			 s.setTopStatus(1);
			 s.setShopAttr(4);
			 shopMapper.insertShopType(s.getId());
		 }else {
			 s.setTopEndTime(getEndDate(s.getTopEndTime(),dura)); 
		 }
		 shopMapper.updateShop(s);
	 }
	 
	 //修改项目订单（project-order）状态为‘已完成’
	 public static void updateProjectOrderForSuccess(String orderNo,ProjectOrderMapper projectOrderMapper) {
		 ProjectOrder projectEn = new ProjectOrder();
		 projectEn.setOrderNo(orderNo);
		 projectEn.setOrderStatus("7");
		 projectOrderMapper.updateProject(projectEn);
	 } 
	
}
